%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG1_maze_schematic_and_photos small function to make Fig. 1
% Figure 1 contains photos of the mazes and schematics
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,842]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 820, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 610, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Room layout diagram
    ax_A = axes('Units','pixels','Position',[20 660 290 160]);      
        csiz = [30 20 15];
        dd = DrawCuboid(csiz);
        dd.FaceAlpha = 0.1;
        dd.FaceColor = 'k';
        hold on
        patch([-6 -6 6 6],[9.9 9.9 9.9 9.9],[-5 4 4 -5],rgb('Brown'),'FaceAlpha',0.1)
        patch([14.9 14.9 14.9 14.9],[5 5 -5 -5],[-5 4 4 -5],'y','FaceAlpha',0.4)

        t = deg2rad(135); t2 = deg2rad(0); t3 = deg2rad(45);
        r1 = [1 0 0;0 cos(t) -sin(t);0 sin(t) cos(t)] * [cos(t2) 0 sin(t2);0 1 0;-sin(t2) 0 cos(t2)] * [cos(t3) -sin(t3) 0;sin(t3) cos(t3) 0;0 0 1];
        p1 = plotCamera('Location',[-csiz(1)/2 -csiz(2)/2 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.7);

        t = deg2rad(135); t2 = deg2rad(0); t3 = deg2rad(135);
        r1 = [1 0 0;0 cos(t) -sin(t);0 sin(t) cos(t)] * [cos(t2) 0 sin(t2);0 1 0;-sin(t2) 0 cos(t2)] * [cos(t3) -sin(t3) 0;sin(t3) cos(t3) 0;0 0 1];
        p2 = plotCamera('Location',[-csiz(1)/2 csiz(2)/2 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.7);

        t = deg2rad(-135); t2 = deg2rad(0); t3 = deg2rad(45);
        r1 = [1 0 0;0 cos(t) -sin(t);0 sin(t) cos(t)] * [cos(t2) 0 sin(t2);0 1 0;-sin(t2) 0 cos(t2)] * [cos(t3) -sin(t3) 0;sin(t3) cos(t3) 0;0 0 1];
        p3 = plotCamera('Location',[csiz(1)/2 csiz(2)/2 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.7);    

        t = deg2rad(135); t2 = deg2rad(0); t3 = deg2rad(-45);
        r1 = [1 0 0;0 cos(t) -sin(t);0 sin(t) cos(t)] * [cos(t2) 0 sin(t2);0 1 0;-sin(t2) 0 cos(t2)] * [cos(t3) -sin(t3) 0;sin(t3) cos(t3) 0;0 0 1];
        p3 = plotCamera('Location',[csiz(1)/2 -csiz(2)/2 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.7);    

        t = deg2rad(180); t2 = deg2rad(0); t3 = deg2rad(0);
        r1 = [1 0 0;0 cos(t) -sin(t);0 sin(t) cos(t)] * [cos(t2) 0 sin(t2);0 1 0;-sin(t2) 0 cos(t2)] * [cos(t3) -sin(t3) 0;sin(t3) cos(t3) 0;0 0 1];
        p3 = plotCamera('Location',[0 0 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.7);     

        load('lattice_frame.mat');
        ldata = [lx ly lz]/130;
        ldata = ldata-nanmean(ldata,1);
        ldata(:,3) = ldata(:,3)-1;
        line(ldata(:,1),ldata(:,2),ldata(:,3),'Color','r','LineWidth',0.8);    
        plot3(ldata(:,1),ldata(:,2),ldata(:,3),'k.','MarkerSize',3)

        xlabel('x');
        ylabel('y');
        zlabel('z');

        line([-2.487 -2.487],[-2.487 -2.487],[-4.731 -csiz(3)/2],'Color','k','LineWidth',2)
        line([-2.487 -2.487],[2.487 2.487],[-4.731 -csiz(3)/2],'Color','k','LineWidth',2)
        line([2.487 2.487],[-2.487 -2.487],[-4.731 -csiz(3)/2],'Color','k','LineWidth',2)
        line([2.487 2.487],[2.487 2.487],[-4.731 -csiz(3)/2],'Color','k','LineWidth',2)

        view(-20,12)
        daspect([1 1 1])
        axis tight off
        lighting phong
        camproj perspective

    % camera key symbol    
    ax_Ainset = axes('Units','pixels','Position',get(ax_A,'Position')+[250 -10 -270 -140]);      
        p2 = plotCamera('Location',[-csiz(1)/2 csiz(2)/2 csiz(3)/2],'Orientation',r1,'Color','k','Opacity',1,'Size',0.2);
        view(-20,12)
        daspect([1 1 1])    
        lighting phong
        camproj perspective    
        axis tight off
        annotation('textbox','Units','pixels','Position',[290, 650, 300, 20],'string','= camera','FontSize',8,'LineStyle','none','interpreter','none'); 

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% lattice maze
    ax_B = axes('Units','pixels','Position',[320 660 280 150]);    
        hold on
        line(ldata(:,1),ldata(:,2),ldata(:,3),'Color','r','LineWidth',1.2);    
        plot3(ldata(:,1),ldata(:,2),ldata(:,3),'k.','MarkerSize',5)
        view(-110,6)
        daspect([1 1 1])
        axis tight off
        lighting phong
        camproj perspective
        title('Side length = 970mm','FontWeight','normal','FontSize',fsiz);

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Maze photos  
    ynow = 420;
    ax_p1a = axes('Units','pixels','Position',[0 ynow 200 170]); 
        fname = [sdir '\IMG_1383-2.jpg'];
        pnow = imread(fname);
        image(pnow);
        axis ij off
        daspect([1 1 1])

    ax_p1b = axes('Units','pixels','Position',[140 ynow 200 170]); 
        fname = [sdir '\IMG_1385-2.jpg'];
        pnow = imread(fname);
        image(pnow);
        axis ij off
        daspect([1 1 1])

    ax_p1c = axes('Units','pixels','Position',[140 ynow 600 170]); 
        fname = [sdir '\IMG_1358-2.jpg'];
        pnow = imread(fname);
        image(pnow);
        axis ij off
        daspect([1 1 1])    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
    
    
    
    
    
    
    



