%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG2_behaviour_dwell_time small function to make Fig. 2
% Figure 2 contains main behaviour results and dwell time spheres
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,650]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 610, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 310, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 

    annotation('textbox','Units','pixels','Position',[70, 600, 300, 20],'string','Arena','FontSize',fsiz+2,'LineStyle','none','interpreter','none','HorizontalAlignment','left'); 
    annotation('textbox','Units','pixels','Position',[250, 600, 300, 20],'string','Aligned','FontSize',fsiz+2,'LineStyle','none','interpreter','none','HorizontalAlignment','left'); 
    annotation('textbox','Units','pixels','Position',[430, 600, 300, 20],'string','Tilted','FontSize',fsiz+2,'LineStyle','none','interpreter','none','HorizontalAlignment','left'); 
    
    annotation('textbox','Units','pixels','Position',[25, 540, 300, 20],'string','All sessions','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[65, 345, 300, 20],'string','Single session','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Dwell time maps
%% #################### Arena 3d map  
    plot_views = [30 22];
    ax_sq_dw = axes('Units','pixels','Position',[-10 370 220 220]);       
        map2 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(pb_idx_sq1));
        for i = 1:length(pb_idx_sq1)
            if pb_idx_sq1(i)
                map2(:,:,i) = dtdata(i).dmaps;
            end
        end
        rats = unique(bdata.rat(pb_idx_sq1));
        map3 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(rats));
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr);
            map3(:,:,rr) = nanmean(map2(:,:,idx),3);
        end
        mmap2 = nanmean(map3,3);
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])   

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        l1 = normr([-970 0 0]); l2 = normr([970 0 0]); l3 = normr([0 970 0]); l4 = normr([0 -970 0]); l5 = normr([0 0 970]); l6 = normr([0 0 -970]); l7 = normr([0 660 466.69]); l8 = normr([0 -660 -466.69]); l9 = normr([571.6 -330 466.69]); l10 = normr([-571.6 330 -466.69]);  l11 = normr([-571.55 -330 466.69]); l12 = normr([571.55 330 -466.69]);   
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};    
        orig = [0 0 0];
        clear lnow;
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d 
    
%% #################### Arena schematic
    ax_sq1_ma = axes('Units','pixels','Position',[ax_sq_dw.Position(1)+120 ax_sq_dw.Position(2)+140 120 120]);   
        plotMAZE(gcf,ax_sq1_ma,1,1:6)     
        camproj perspective
        rotate3d on
        axis xy tight off    
    
        sfact = 1.5;
        sfact2 = 1.2;
        text(2.5.*sfact2,4.*sfact2,7.5.*sfact2,'Z','FontSize',6,'HorizontalAlignment','center')
        text(-3.5.*sfact,2.5.*sfact,0.3.*sfact,'X','FontSize',6,'HorizontalAlignment','center')
        text(2.8.*sfact,-4.*sfact,0.5.*sfact,'Y','FontSize',6,'HorizontalAlignment','center')
        
%% #################### Example single arena session
    ratz1 = [896];
    datz1 = [9012018];
    ax_sq1_single = axes('Units','pixels','Position',[ax_sq_dw.Position(1)+110 ax_sq_dw.Position(2)-40 120 120]);   
        idx = pb_idx_sq1 & bdata.rat==ratz1(1) & bdata.date==datz1(1);
%         idx = bdata.rat==ratz1(1) & bdata.date==datz1(1);
        mmap2 = dtdata(idx).dmaps;
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])   

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};    
        orig = [0 0 0];
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d 
         
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% aligned 3d map  
    ax_la1_dw = axes('Units','pixels','Position',ax_sq_dw.Position+[180 0 0 0]);     
        map2 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(pb_idx_la1));
        for i = 1:length(pb_idx_la1)
            if pb_idx_la1(i)
                map2(:,:,i) = dtdata(i).dmaps;
            end
        end

        rats = unique(bdata.rat(pb_idx_la1));
        map3 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(rats));
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr);
            map3(:,:,rr) = nanmean(map2(:,:,idx),3);
        end
        mmap2 = nanmean(map3,3);
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [0 0 0];
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d 
        
%% #################### %% Aligned schematic       
    ax_la1_ma = axes('Units','pixels','Position',[ax_la1_dw.Position(1)+120 ax_la1_dw.Position(2)+140 120 120]);   
        plotMAZE(gcf,ax_la1_ma,2,1:6)     
        camproj perspective
        rotate3d on
        axis xy tight off        
        
        sfact = 1.2;
        sfact2 = 1.2;        
        text(-3.5.*sfact2,3.5.*sfact2,3.6.*sfact2,'X','FontSize',6,'HorizontalAlignment','center')
        text(3.9.*sfact,-5.5.*sfact,4.*sfact,'Y','FontSize',6,'HorizontalAlignment','center')
        text(3.5.*sfact,4.*sfact,10.5.*sfact,'Z','FontSize',6,'HorizontalAlignment','center')
 
%% #################### %% Example single aligned session
    ratz2 = [896];
    datz2 = [19012018];
    ax_la1_single = axes('Units','pixels','Position',[ax_la1_dw.Position(1)+110 ax_la1_dw.Position(2)-40 120 120]);   
        idx = pb_idx_la1 & bdata.rat==ratz2(1) & bdata.date==datz2(1);
        mmap2 = dtdata(idx).dmaps;
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])   

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};    
        orig = [0 0 0];
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d         
        
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% tilted 3d map  
    ax_la2_dw = axes('Units','pixels','Position',ax_la1_dw.Position+[205 30 -60 -60]);    
        map2 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(pb_idx_la2));
        for i = 1:length(pb_idx_la2)
            if pb_idx_la2(i)
                map2(:,:,i) = dtdata(i).dmaps;
            end
        end
        rats = unique(bdata.rat(pb_idx_la2));
        map3 = NaN(size(dtdata(1).dmaps,1),size(dtdata(1).dmaps,2),length(rats));
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr);
            map3(:,:,rr) = nanmean(map2(:,:,idx),3);
        end
        mmap2 = nanmean(map3,3);
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-','-','-','-','-','-','-'};        
        orig = [0 0 0];
        for ll = 7:12
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d 

%% #################### %% Tilted schematic    
    ax_la2_ma = axes('Units','pixels','Position',[ax_la2_dw.Position(1)+110 ax_la2_dw.Position(2)+125 90 90]);   
        plotMAZE(gcf,ax_la2_ma,3,7:12)     
        camproj perspective
        rotate3d on
        axis xy tight off 
        
        sfact = 1.5;
        sfact2 = 1.1;        
        text(-4.95.*sfact2,-2.858.*sfact2,9.5.*sfact2,'A','FontSize',6,'HorizontalAlignment','center')
        text(0.*sfact2,5.715.*sfact2,10.97.*sfact2,'B','FontSize',6,'HorizontalAlignment','center')
        text(4.95.*sfact2,-2.858.*sfact2,10.97.*sfact2,'C','FontSize',6,'HorizontalAlignment','center')
        view(18,22)

%% #################### %% Example single tilted session
    ratz3 = 926;
    datz3 = 13042018;
    ax_la2_single = axes('Units','pixels','Position',[ax_la2_dw.Position(1)+110 ax_la2_dw.Position(2)-55 90 90]);   
        idx = pb_idx_la2 & bdata.rat==ratz3(1) & bdata.date==datz3(1);
        mmap2 = dtdata(idx).dmaps;
        mx = nanmax(mmap2(:));
        F1 = mmap2 ./ mx;
        F1 = imresize(F1,4);
        [X,Y,Z] = sphere(259);  
        s = surf(X,Y,Z,F1);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        rotate3d on;
        view(plot_views); 
        daspect([1 1 1]); 
        colormap(gca,jet(256));
        caxis([0 nanmax(F1(:))])   

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-','-','-','-','-','-','-'};    
        orig = [0 0 0];
        for ll = 7:12
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off vis3d          
        
%% #################### %% colorbar for 3d spheres        
    axc = axes('Units','pixels','Position',[ax_la2_dw.Position(1)+195 ax_la2_dw.Position(1)+55 10 100]);
        imagesc(((1:256)'));
        colormap(axc,'jet')
        axis xy off
        text(0.5,-0.08,'0s','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Time in every axis
%% #################### %% square maze
    ax_sq_gr = axes('Units','pixels','Position',[ax_sq_dw.Position(1)+60 ax_sq_dw.Position(2)-210 140 110]); 
        % get data
        rats = unique(bdata.rat(pb_idx_sq1)); % all rats in this maze
        tdat = NaN(length(rats),6); % prepare matrix
        for rr = 1:length(rats) % for every rat
            idx = bdata.rat==rats(rr) & pb_idx_sq1; % get the index for this rats & environment
            % collect the mean proportion of time spent moving along each axis (XYZ and ABC)
            tdat(rr,:) = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);
        end    
        % plot boxplot
        [ds,gs] = vectorDATAGROUP([],tdat(:,1),tdat(:,2),tdat(:,3),tdat(:,4),tdat(:,5),tdat(:,6));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz,cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz,cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'X','Y','Z','A','B','C'};    
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .3];
        y1 = ax.YLim;
        ylabel('Proportion of total time');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places    
        text(0.05,0.1,sprintf('N = %d',size(tdat,1)),'FontSize',fsiz,'Units','normalized')

            [p,a,sts] = friedman(tdat(:,1:2),1,'off');
            disp('Time per axis square:')    
            disp(sprintf('\tX2(%d) = %.3f, p = %.4f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(tdat(:)))))
            disp(sprintf('\tmedians: %s',mat2str(nanmedian(tdat,1),4) ))   

            % add significance cutoff line
            [prc,arc,pr,ar,cr,idcs] = sphereCHANCE(1000,1000);  
            prcs = prc([3 4 5]);        
            hold on;
            x = 0.5:0.5:6.5;
            y = repmat(prcs(2),length(x),1);
            b = [repmat(prcs(2)-prcs(1),length(x),1) repmat(prcs(3)-prcs(2),length(x),1)];
            boundedline(x,y,b,'r','alpha')         
            disp(sprintf('\tchance mean: %.2f, upper 95: %.2f, lower 95: %.2f',prc(2),prc(1),prc(3)))  

%% inset distribution probability, correlations
    ax_sq1_density = axes('Units','pixels','Position',[ax_sq_gr.Position(1)+70 ax_sq_gr.Position(2)+100 80 50]);         
        psR = prctile(ar(:),[0.5 50 99.5]);
        aro = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio

        xi = 0:0.05:2.5;
        bw = 0.1;
        [~,~,~,f] = histDENSITY(ar(:),xi,bw);
        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 0.2];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        idx = bdata.rat==ratz1(1) & bdata.date==datz1(1) & pb_idx_sq1; % get the index for this rats & environment
        tdat = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);        
        ars = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');
        
        box off
        ax = gca;
        ax.XTick = 0:0.5:2.5;   
        ax.XLim = [0.5 2.5];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
       
        p = ax.Position;
        ax.Position = p;
        [~,o] = legendflex([a1,l1 l2 l3], {'shuffle','shuffle 99%',sprintf('animal average'),sprintf('single session')}, 'ref', gca, 'xscale', 0.4, 'anchor', [3 8], 'buffer', [-2 -10], 'box', 'off');
                
%% #################### %% lattice maze
    ax_la1_gr = axes('Units','pixels','Position',[ax_la1_dw.Position(1)+60 ax_sq_gr.Position(2) 140 110]); 
        % get data
        rats = unique(bdata.rat(pb_idx_la1)); % all rats in this maze
        tdat = NaN(length(rats),6); % prepare matrix
        for rr = 1:length(rats) % for every rat
            idx = bdata.rat==rats(rr) & pb_idx_la1; % get the index for this rats & environment
            % collect the mean proportion of time spent moving along each axis (XYZ and ABC)
            tdat(rr,:) = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);
        end    
        % plot boxplot
        [ds,gs] = vectorDATAGROUP([],tdat(:,1),tdat(:,2),tdat(:,3),tdat(:,4),tdat(:,5),tdat(:,6));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz,cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz,cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'X','Y','Z','A','B','C'};    
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .3];
        ax.YTick = [];
        y1 = ax.YLim;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        xlabel('Maze axis')
        text(0.05,0.1,sprintf('N = %d',size(tdat,1)),'FontSize',fsiz,'Units','normalized')

            % add significance cutoff line
            hold on;
            boundedline(x,y,b,'r','alpha')  
            disp('Time per axis lattice:')         
            [p,a,sts] = friedman(tdat(:,1:2),1,'off');
            comp = multcompare(sts,'display','off','ctype','bonferroni');        
            disp(sprintf('\tX2(%d) = %.3f, p = %.4f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(tdat(:,1:3))))))        

%% inset distribution probability, correlations
    ax_la1_density = axes('Units','pixels','Position',[ax_la1_gr.Position(1)+85 ax_sq1_density.Position(2) 80 50]);         
        psR = prctile(ar(:),[0.5 50 99.5]);
        aro = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio

        xi = 0:0.05:2.5;
        bw = 0.1;
        [~,~,~,f] = histDENSITY(ar(:),xi,bw);
        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 0.2];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        idx = bdata.rat==ratz2(1) & bdata.date==datz2(1) & pb_idx_la1; % get the index for this rats & environment
        tdat = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);        
        ars = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');        
        
        box off
        ax = gca;
        ax.XTick = 0:0.5:2.5;   
        ax.XLim = [0.5 1.5];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
               
        
%% #################### %% diagonal maze
    ax_la2_gr = axes('Units','pixels','Position',[ax_la2_dw.Position(1)+35 ax_sq_gr.Position(2) 140 110]); 
        % get data
        rats = unique(bdata.rat(pb_idx_la2)); % all rats in this maze
        tdat = NaN(length(rats),6); % prepare matrix
        for rr = 1:length(rats) % for every rat
            idx = bdata.rat==rats(rr) & pb_idx_la2; % get the index for this rats & environment
            % collect the mean proportion of time spent moving along each axis (XYZ and ABC)
            tdat(rr,:) = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);
        end    
        % plot boxplot
        [ds,gs] = vectorDATAGROUP([],tdat(:,1),tdat(:,2),tdat(:,3),tdat(:,4),tdat(:,5),tdat(:,6));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz,cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz,cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'X','Y','Z','A','B','C'};    
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .3];
        ax.YTick = [];
        y1 = ax.YLim;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        text(1.02,0.42,sprintf('Chance'),'FontSize',fsiz,'Units','normalized','HorizontalAlignment','left','Color','r');
        text(0.05,0.1,sprintf('N = %d',size(tdat,1)),'FontSize',fsiz,'Units','normalized')

            % add significance cutoff line
            hold on;
            boundedline(x,y,b,'r','alpha')      

            [p,a,sts] = friedman(tdat(:,4:6),1,'off');
            comp = multcompare(sts,'display','off','ctype','bonferroni');        
            disp('Time per axis diagonal:')     
            disp(sprintf('\tX2(%d) = %.3f, p = %.4f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(tdat(:,4:6))))))
            disp(sprintf('\tmedians: %s',mat2str(nanmedian(tdat,1),4) ))    

%% inset distribution probability, correlations
    ax_la2_density = axes('Units','pixels','Position',[ax_la2_gr.Position(1)+80 ax_sq1_density.Position(2) 80 50]);         
        psR = prctile(ar(:),[0.5 50 99.5]);
        aro = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio

        xi = 0:0.05:2.5;
        bw = 0.1;
        [~,~,~,f] = histDENSITY(ar(:),xi,bw);
        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 0.2];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        idx = bdata.rat==ratz3(1) & bdata.date==datz3(1) & pb_idx_la2; % get the index for this rats & environment
        tdat = nanmean([nansum(bdata.dwell_time_X(idx,:),2) nansum(bdata.dwell_time_Y(idx,:),2) nansum(bdata.dwell_time_Z(idx,:),2) nansum(bdata.dwell_time_A(idx,:),2) nansum(bdata.dwell_time_B(idx,:),2) nansum(bdata.dwell_time_C(idx,:),2)],1);        
        ars = median(sum(tdat(:,1:3),2)./sum(tdat(:,4:6),2)); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');         
        
        box off
        ax = gca;
        ax.XTick = 0:0.5:2.5;   
        ax.XLim = [0.5 1.5];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    














