%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG3_main_example_cells small function to make Fig. 3
% Figure 3 contains main example cells (3 aligned, 2 tilted)
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,800,900]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    part_now3 = 'lattice_3d';
%     dirs = {'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\850_P1_16_HPC\170313_kk_kt_ll_k3\klustest3\kwiktint',5,4,850,170313;...
%     'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\852_P3_16_HPC\170320_kk_kt_ll_k3\klustest3\kwiktint',7,2,852,170320;...
%     'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\775_K2_36_HPC\161025_kk_kt_ll_k3\klustest3\kwiktint',9,1,775,161025;...
%     'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Diagonal\926_P16k_32_HPC\180416\klustest3\kwiktint',12,5,926,180416;...
%     'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Diagonal\951_P23_32_HPC\180920\klustest3\kwiktint',16,1,951,180920};
    dirs = {[sdir '\850_13032017.mat'],5,4,850,170313;...
            [sdir '\852_20032017.mat'],7,2,852,170320;...
            [sdir '\775_25102016.mat'],9,1,775,161025;...
            [sdir '\926_16042018.mat'],12,5,926,180416;...
            [sdir '\951_20092018.mat'],16,1,951,180920};
    diag = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Plot example cells
    xs = [50,170,320,480,550,620];
    ys = [710,560,410,260,110];
    for dd = 1:length(ys)
        if dd>3
            diag = 1;
        end
        disp(sprintf('\t...cell: %d',dd));
        cd(sdir);
        load(dirs{dd,1},'-mat','sdata');

        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dirs{dd,2}) '_c' num2str(dirs{dd,3})]; 
        dat_now = sdata.(uci);    

%% ##################################### %% plot spikes
        if diag
            ax_1 = axes('Units','pixels','Position',[xs(1)-20 ys(dd)-20 190 190]);           
        else
            ax_1 = axes('Units','pixels','Position',[xs(1) ys(dd) 140 140]);   
        end
            pox = sdata.(part_now3).pox;
            poy = sdata.(part_now3).poy;
            poz = sdata.(part_now3).poz;
            spx = sdata.(uci).(part_now3).spx;
            spy = sdata.(uci).(part_now3).spy;
            spz = sdata.(uci).(part_now3).spz;
            lx = sdata.(part_now3).lx;
            ly = sdata.(part_now3).ly;
            lz = sdata.(part_now3).lz;

            anstr = sprintf('%s, %s, t%s, c%s, %d spikes, %.1f mins',sdata.rat_num, sdata.date, num2str(dirs{dd,2}), num2str(dirs{dd,3}), numel(spx), numel(pox)*(1/50)/60);
            annotation('textbox','Units','pixels','Position',[60, ys(dd)+130, 300, 20],'string',anstr,'FontSize',6,'LineStyle','none','interpreter','none');     

            traj = line(pox,poy,poz,'Color',[0.5 0.5 0.5 0.5]);
            hold on
            spike_size_3 = 8;
            spike_alpha_3 = 0.3;
            spiks = scatter3(spx,spy,spz,spike_size_3,'r','filled','MarkerFaceAlpha',spike_alpha_3); hold on;
            hold on
            h = line(lx,ly,lz);
            set(h,'Color',[0.5 0.5 0.5 0.2],'LineWidth',1,'LineStyle','-');
            axis off
            axis([min(pox)-12,max(pox)+12,min(poy)-12,max(poy)+12,min(poz)-12,max(poz)+12]);
            view(3)
            daspect([1 1 1])
            xlabel('X (mm)');
            ylabel('Y (mm)');
            zlabel('Z (mm)');
            axis vis3d
            rotate3d on      
            caxis([0.5 1])
            colormap(ax_1,flipud(jet(256)))

%% ##################################### %% plot ratemap
        if diag
            ax_2 = axes('Units','pixels','Position',[xs(2)-20 ys(dd)-30 210 210]); 
        else
            ax_2 = axes('Units','pixels','Position',[xs(2) ys(dd)-5 160 160]);         
        end
            ratemap = sdata.(uci).(part_now3).ratemap;
            lx2 = sdata.(part_now3).lxrm;
            ly2 = sdata.(part_now3).lyrm;
            lz2 = sdata.(part_now3).lzrm;

            ratemap(ratemap < 0.2*nanmax(ratemap(:))) = NaN;
            vol3d('cdata',ratemap,'texture','3D');
            alphamap('rampup');
            colormap(ax_2,'jet');
            caxis([0.2*nanmax(ratemap(:)) nanmax(ratemap(:))]);
            hold on

        if diag
            plotOUTLINE;
        else
            edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
            ori = [min(lx2), min(ly2), min(lz2)]; 
            plotcube(edg,ori,0,0,0.3);
        end   
            axis off tight
            ax = gca;
            view(3)
            daspect([1 1 1])
            axis vis3d
            camproj perspective
            rotate3d on

%% ##################################### %% plot place field convexhulls
        if diag
            ax_3 = axes('Units','pixels','Position',[xs(3)-30 ys(dd)-20 190 190]);    
        else
            ax_3 = axes('Units','pixels','Position',[xs(3) ys(dd)+5 130 130]);            
        end
            dwellmap = sdata.(part_now3).dwellmap;
            fields = sdata.(uci).(part_now3).nfields;
            fddata = sdata.(uci).(part_now3).field_data;

            % plot overall position data outline
            dwellmap2 = dwellmap;
            dwellmap2(dwellmap < 1) = NaN; % remove voxels with a coverage less than 1 second (the minimum when generating ratemap)
            [p2,p1,p3] = ind2sub(size(dwellmap2),find(~isnan(dwellmap2))); % find the subscript indices of these elements
            K = convhull(p1,p2,p3); % find the convexhull of these points
            tri = trisurf(K,p1,p2,p3); % plot it
            set(tri,'FaceColor','k','EdgeAlpha',0.1)
            alpha(.1)
            hold on

            map = zeros(size(dwellmap));
            cols = {'r','b','g','k'};
            nfield = 0;
            for ff = 1:fields % for every detected place field
                ps = fddata(ff).voxel_index;
                if fddata(ff).volume_voxels>fvol_thresh(1) & fddata(ff).field_visits>fv_thresh
                    emap = zeros(size(dwellmap));
                    emap(sub2ind(size(emap),ps(:,1),ps(:,2),ps(:,3))) = 1;
                    hiso = patch(isosurface(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5); hold on;
                    hiso2 = patch(isocaps(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5);       
                    nfield = nfield+1;
                    map = map+emap;
                end
            end
            if sum(emap(:))>0
                lighting phong;
                isonormals(map,hiso);
                camlight;
            end    
            
            if diag
                plotOUTLINE;
            else
                edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
                ori = [min(lx2), min(ly2), min(lz2)]; 
                plotcube(edg,ori,0,0,0.3);
            end    
            axis off tight
            view(3)
            daspect([1 1 1])
            axis vis3d
            camproj perspective
            rotate3d on  

            
%% ##################################### %% 2D projections
            annotation('textbox','Units','pixels','Position',[xs(4)+25, ys(dd)+120, 8, 20],'string','XY','FontSize',6,'LineStyle','none','interpreter','none','HorizontalAlignment','center');     
            annotation('textbox','Units','pixels','Position',[xs(5)+25, ys(dd)+120, 8, 20],'string','XZ','FontSize',6,'LineStyle','none','interpreter','none','HorizontalAlignment','center');     
            annotation('textbox','Units','pixels','Position',[xs(6)+25, ys(dd)+120, 8, 20],'string','YZ','FontSize',6,'LineStyle','none','interpreter','none','HorizontalAlignment','center');     

            ratemap = sdata.(uci).(part_now3).ratemap;
            scat_size = 2;
            spc = 10;
            
%% #################### %% XY spikes            
            ax_xy_proj = axes('Units','pixels','Position',[xs(4) ys(dd)+60 60 60]);
                line(pox,poy,'Color',[0.5 0.5 0.5 .5])
                hold on
                scatter(spx,spy,scat_size,'MarkerFaceColor','r','MarkerFaceAlpha',0.2,'MarkerEdgeColor','r','MarkerEdgeAlpha',0.2)    
                daspect([1 1 1])
                axis([min(lx)-spc max(lx)+spc min(ly)-spc max(ly)+spc]);
                axis off

                xlim=get(gca,'XLim');
                ylim=get(gca,'YLim');
                ht = text(xlim(1)-(0.2*diff(xlim)),mean(ylim),'Spike map','HorizontalAlignment','center');
                set(ht,'Rotation',90)
                set(ht,'FontSize',6)    

%% #################### %% XY map                            
            ax_xy_map = axes('Units','pixels','Position',[xs(4) ys(dd) 60 60]);
                config.rmethod          = 'gaussian'; % (default 'nearest') the mapping approach to use, either 'nearest','gaussian','adaptive','KDE'
                config.map_padd         = 2; % (default 2) the number of bins to pad spatial maps with
                config.bin_size         = 2; % (default 2) bin size in cm for calculating the rate map (make sure data is in cm or pm/sm values are given)
                config.map_sigma        = 1.5; % (default 1.5) used by nearest and KDE method, sigma of gaussian to use when smoothing traditional dwell and spike maps, or used as bandwidth of KDE
                config.smethod          = 1; % (default 1) used by nearest method, when set to 1 the dwell and spike maps are smoothed before dividing, 2 means the smoothing is applied after dividing, 3 means no smoothing
                config.min_dwell        = 0.01; % (default 0.1) total number of seconds that rat has to be in a bin for it to be filled, for adaptive method this controls how big the bins will be expanded
                config.g_sigma          = 5; % (default 10) only used by gaussian method - sigma of gaussian used to weight position point and spike point distances, bigger means smoother maps
                config.min_dist         = 5; % (default 1) used by adaptive and gaussian method, only bins within this distance of some position data will be filled, bigger means more filled (blue) bins
                config.max_dist         = 20; % (default 1) used by adaptive and gaussian method, only bins within this distance of some position data will be filled, bigger means more filled (blue) bins
                config.srate            = 50; % (default 50) sampling rate of data in Hz, used to calculate time
                [mnow,~,~,~,~] = mapDATA([pox poy]./10,[spx spy]./10,config);
                mnow = flipud(mnow);
                im = imagesc(mnow);
                set(im,'alphadata',~isnan(mnow));    
                daspect([1 1 1])
                axis off
                caxis([0 nanmax(mnow(:))]);

                xlim=get(gca,'XLim');
                ylim=get(gca,'YLim');
                ht = text(xlim(1)-(0.2*diff(xlim)),mean(ylim),'Rate map','HorizontalAlignment','center');
                set(ht,'Rotation',90)
                set(ht,'FontSize',6)   

%% #################### %% XZ spikes            
            ax_xz_proj = axes('Units','pixels','Position',[xs(5) ys(dd)+60 60 60]);
                plot(pox,poz,'Color',[0.5 0.5 0.5 .5])
                hold on
                scatter(spx,spz,scat_size,'MarkerFaceColor','r','MarkerFaceAlpha',0.2,'MarkerEdgeColor','r','MarkerEdgeAlpha',0.2)    
                daspect([1 1 1])
                axis([min(lx)-spc max(lx)+spc min(lz)-spc max(lz)+spc]);
                axis off

%% #################### %% XZ map                            
            ax_xz_map = axes('Units','pixels','Position',[xs(5) ys(dd) 60 60]);
                [mnow,~,~,~,~] = mapDATA([pox poz]./10,[spx spz]./10,config);  
                mnow = flipud(mnow);        
                im = imagesc(mnow);
                set(im,'alphadata',~isnan(mnow));    
                daspect([1 1 1])
                axis off 
                caxis([0 nanmax(mnow(:))]);

%% #################### %% YZ spikes            
            ax_yz_proj = axes('Units','pixels','Position',[xs(6) ys(dd)+60 60 60]);
                plot(poy,poz,'Color',[0.5 0.5 0.5 .5])
                hold on
                scatter(spy,spz,scat_size,'MarkerFaceColor','r','MarkerFaceAlpha',0.2,'MarkerEdgeColor','r','MarkerEdgeAlpha',0.2)    
                daspect([1 1 1])
                axis([min(ly)-spc max(ly)+spc min(lz)-spc max(lz)+spc]);
                axis off

%% #################### %% YZ map                          
            ax_yz_map = axes('Units','pixels','Position',[xs(6) ys(dd) 60 60]);
                [mnow,~,~,~,~] = mapDATA([poy poz]./10,[spy spz]./10,config);  
                mnow = flipud(mnow);        
                im = imagesc(mnow);
                set(im,'alphadata',~isnan(mnow));
                daspect([1 1 1])
                axis off    
                caxis([0 nanmax(mnow(:))]);      
    end

%% ##################################### %% legend for 3D spikes and path
    legendflex([traj,spiks],{'Path','Spikes'}, 'ref', ax_1, 'anchor', {'n','n'}, 'buffer',[-30 -165], 'nrow',2,  'fontsize',8, 'box', 'off');

%% ##################################### %% colorbar for 3D ratemap
    axc_cmap = axes('Units','pixels','Position',[ax_2.Position(1)+60 ax_2.Position(2)+20 90 10]);
        cmap = repmat(1:100,1,1,2);
        cmap(cmap < 0.2*nanmax(cmap(:))) = NaN;
        vol3d('cdata',cmap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0.2*nanmax(cmap(:)) nanmax(cmap(:))]);
        axis xy on tight
        box on
        ax = gca;
        ax.YTick = [];
        ax.XTick = [20];
        ax.XTickLabel = {'20%'};
        text(-0.2,.5,'0 Hz','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(1.2,.5,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
%         paper_FIG_savefig(print_now,2400,gcf,sdir,dbstack);
    












