%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG4_field_per_cell_and_volume small function to make Fig. 4
% Figure 4 contains stats on the number of fields per cell and volume etc
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,900,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 860, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none');         
    annotation('textbox','Units','pixels','Position',[5, 690, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[5, 490, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[240, 490, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[440, 490, 300, 20],'string','e','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[630, 490, 300, 20],'string','f','FontSize',18,'LineStyle','none','interpreter','none');     

    annotation('textbox','Units','pixels','Position',[85, 840, 300, 20],'string','Firing rate map','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[285, 840, 300, 20],'string','Place field','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[460, 840, 300, 20],'string','Convex hull','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[640, 840, 300, 20],'string','Centroids','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textarrow',[.27 .32],[.85 .85]);
    annotation('textarrow',[.47 .52],[.85 .85]);
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Top schematic - extracting fields
    ax_rmap = axes('Units','pixels','Position',[70 680 200 200]);       
%         dir = {'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\770_K1_36_HPC\170314_kk_kt_ll_k3\klustest3\kwiktint',14,1,770,170314};    
        dir = {[sdir '\770_14032017.mat'],14,1,770,170314};    
        cd(sdir);
        load(dir{1},'-mat','sdata');

        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dir{2}) '_c' num2str(dir{3})]; 
        dat_now = sdata.(uci);     
    
        part_now3 = 'lattice_3d';
        ratemap = sdata.(uci).(part_now3).ratemap;
        dwellmap = sdata.(part_now3).dwellmap;
        lx2 = sdata.(part_now3).lxrm;
        ly2 = sdata.(part_now3).lyrm;
        lz2 = sdata.(part_now3).lzrm;

        ratemap(ratemap < 0.2*nanmax(ratemap(:))) = NaN;
        vol3d('cdata',ratemap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(ratemap(:))]);

        hold on
        edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
        ori = [min(lx2), min(ly2), min(lz2)]; 
        plotcube(edg,ori,0,0,0.3);

        axis off
        pad_valr = 6;
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on   

%% colorbar for 3D ratemap
    axc_cmap = axes('Units','pixels','Position',[ax_rmap.Position(1)+0 ax_rmap.Position(2)+60 10 90]);
        cmap = repmat(reshape(1:100,[],1),1,1,2);
        cmap(cmap < 0.2*nanmax(cmap(:))) = NaN;
        vol3d('cdata',cmap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0.2*nanmax(cmap(:)) nanmax(cmap(:))]);
        axis xy on tight
        box on
        ax = gca;
        ax.XTick = [];
        ax.YTick = [20];
        ax.YTickLabel = {'20%'};
        text(0.5,-0.08,'0 Hz','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%% ##################################### %% Top schematic - convex hull of place field        
    ax_chull = axes('Units','pixels','Position',ax_rmap.Position+[180 0 0 0]);       
        % plot overall position data outline
        fields = sdata.(uci).(part_now3).nfields;
        fddata = sdata.(uci).(part_now3).field_data;
        hold on
        
        nfield = 0;
        if ~fields<1
            cols = {'r','k','k','k'};
            map = zeros(size(dwellmap));
            fidx = fdata.tetrode==num2str(dir{2}) & fdata.cluster==num2str(dir{3}) & fdata.part==2;
            fdata2 = fdata(fidx,:);
            for ff = 1:fields % for every detected place field
                ps = fddata(ff).voxel_index;
                if fddata(ff).volume_voxels>fvol_thresh(1) & fddata(ff).field_visits>fv_thresh
                    emap = zeros(size(dwellmap));
                    emap(sub2ind(size(emap),ps(:,1),ps(:,2),ps(:,3))) = 1;
                    hiso = patch(isosurface(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5); hold on;
                    hiso2 = patch(isocaps(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5);       
                    nfield = nfield+1;
                    map = map+emap;
                end
            end
            if sum(emap(:))>0
                lighting phong;
                isonormals(map,hiso);
                camlight;
            end

            hold on
                edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
                ori = [min(lx2), min(ly2), min(lz2)]; 
                plotcube(edg,ori,0,0,0.3);
            axis off
            axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
            view(-240,22)
            daspect([1 1 1])
            camproj perspective
            rotate3d on  
        end        
        
%% ##################################### %% Top schematic - convex hull with principal axes        
    ax_chull2 = axes('Units','pixels','Position',ax_chull.Position+[180 0 0 0]);       
        % plot overall position data outline
        fddata = sdata.(uci).(part_now3).field_data;
        nfields = sdata.(uci).(part_now3).nfields;
        
        cols = {'r','k','k','k'};
        map = zeros(size(dwellmap));

        for ff = 1:nfields % for every detected place field
            if ~isfield(fddata(ff),'voxel_index')
                continue
            end   
            ps = fddata(ff).voxel_index;
            K = convhull(ps(:,2),ps(:,1),ps(:,3));
            tri = trisurf(K,ps(:,2),ps(:,1),ps(:,3)); hold on;
            set(tri,'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5);
        end   

        lighting phong;
        camlight;
        edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
        ori = [min(lx2), min(ly2), min(lz2)]; 
        plotcube(edg,ori,0,0,0.3);
        axis off
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on   
                
%% ##################################### %% Top schematic - centroids    
    ax_sphere = axes('Units','pixels','Position',ax_chull2.Position+[180 0 0 0]);          
        % plot overall position data outline
        fddata = sdata.(uci).(part_now3).field_data;
        nfields = sdata.(uci).(part_now3).nfields;
        
        cols = {'r','k','k','k'};
        map = zeros(size(dwellmap));

        for ff = 1:nfields % for every detected place field
            if ~isfield(fddata(ff),'voxel_index')
                continue
            end   
            ps = fddata(ff).voxel_index;
            K = convhull(ps(:,2),ps(:,1),ps(:,3));
            tri = trisurf(K,ps(:,2),ps(:,1),ps(:,3)); hold on;
            set(tri,'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.2);
            
            ce = fddata(ff).centroid;
            scatter3(ce(1),ce(2),ce(3),20,ce(3),'filled','MarkerFaceAlpha',1,'MarkerEdgeColor','k','MarkerEdgeAlpha',.5);
            colormap(gca,parula);
            caxis([min(lz2),max(lz2)]);
        end   

        lighting phong;
        camlight;
        edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
        ori = [min(lx2), min(ly2), min(lz2)]; 
        plotcube(edg,ori,0,0,0.3);
        axis off
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% lattice schematic and examples top
    if 1
    ynow = 520;
%% ##################################### %% lattice schamtic    
        ax_c1 = axes('Units','pixels','Position',[0 ynow-50 250 250]);    
            l1 = normr([-970 0 0]); 
            l2 = normr([970 0 0]); 
            l3 = normr([0 970 0]); 
            l4 = normr([0 -970 0]); 
            l5 = normr([0 0 970]); 
            l6 = normr([0 0 -970]); 
            l7 = normr([0 660 466.69]); 
            l8 = normr([0 -660 -466.69]); 
            l9 = normr([571.6 -330 466.69]); 
            l10 = normr([-571.6 330 -466.69]); 
            l11 = normr([-571.55 -330 466.69]); 
            l12 = normr([571.55 330 -466.69]);  

            [v1] = meshgrid(1:7);
            surf(v1,v1',ones(size(v1))); hold on;
            surf(v1,v1',ones(size(v1)).*7);
            surf(v1,ones(size(v1)),v1');
            surf(v1,ones(size(v1)).*7,v1',v1);
            surf(ones(size(v1)),v1,v1');
            surf(ones(size(v1)).*7,v1,v1');
            daspect([1 1 1])
            colormap(gca,parula)
            view(3);    
            camproj perspective
            rotate3d on

            adj = 7;
            lcol = 'k';
            lwid = 1;
            hold on;
            lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
            lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};
            orig = [4 4 4];
            for ll = 1:length(lins)
                lnow = lins{ll};
                line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
            end
            axis xy tight off

%% ##################################### %% example cells
%         dirs = {'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\852_P3_16_HPC\170320_kk_kt_ll_k3\klustest3\kwiktint',7,2,852,170320;... % nice round
%         'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\851_P2_16_HPC\170413_kk_kt_ll_k3\klustest3\kwiktint',5,2,851,170411;...
%         'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\894_P9_32_HPC\180118\klustest3\kwiktint',12,3,894,180118;... % 3 fields
%         'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\896_P11_32_HPC\180111\klustest3\kwiktint',13,8,896,180111}; % 4 fields
        dirs = {[sdir '\852_20032017.mat'],7,2,852,170320;... % nice round
                [sdir '\851_13042017.mat'],5,2,851,170413;...
                [sdir '\894_18012018.mat'],12,3,894,180118;... % 3 fields
                [sdir '\896_11012018.mat'],13,8,896,180111}; % 4 fields
    
        axpos = {[200 ynow 150 150],[350 ynow 150 150],[500 ynow 150 150],[650 ynow 150 150]};
        for cc = 1:size(dirs,1)
            ax_c1 = axes('Units','pixels','Position',axpos{cc});      
                cd(sdir);
                load(dirs{cc,1},'-mat','sdata');

                uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dirs{cc,2}) '_c' num2str(dirs{cc,3})]; 
                part_now3 = 'lattice_3d';
                lx2 = sdata.(part_now3).lxrm;
                ly2 = sdata.(part_now3).lyrm;
                lz2 = sdata.(part_now3).lzrm;             
                r2 = sdata.(uci).(part_now3).ratemap;      
                dwellmap = sdata.(part_now3).dwellmap;
                fields = sdata.(uci).(part_now3).nfields;
                fddata = sdata.(uci).(part_now3).field_data;

                % plot overall position data outline
                dwellmap2 = dwellmap;
                dwellmap2(dwellmap < 1) = NaN; % remove voxels with a coverage less than 1 second (the minimum when generating ratemap)
                [p2,p1,p3] = ind2sub(size(dwellmap2),find(~isnan(dwellmap2))); % find the subscript indices of these elements
                K = convhull(p1,p2,p3); % find the convexhull of these points
                tri = trisurf(K,p1,p2,p3); % plot it
                set(tri,'FaceColor','k','EdgeAlpha',0.1)
                alpha(.1)
                hold on
                cols = {'r','b','g','m','c','k','y','r','g','b','m','c','k','y'};
                for ff = 1:fields % for every detected place field
                    % plot outline of this place field
                    ps = fddata(ff).voxel_index;
                    K = convhull(ps(:,2),ps(:,1),ps(:,3));
                    tri = trisurf(K,ps(:,2),ps(:,1),ps(:,3));
                    set(tri,'FaceColor',cols{ff},'EdgeAlpha',0.5);
                    alpha(.1);                
                end
                view(3)
                daspect([1 1 1])
                axis vis3d off tight xy
                camproj perspective
                rotate3d on       

                title(sprintf('Rat %d, %d, %d fields',dirs{cc,4},dirs{cc,5},fields),'FontWeight','normal','HorizontalAlignment','center','FontSize',6)
        end
        cd(sdir);
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Further plots on fields per cell stats
ynow = 310;
%% ##################################### %% fields per cell
    ax_D = axes('Units','pixels','Position',[50 ynow 170 150]);  
        % list square fields
        fvec_sq1 = tdata.num_fields(pc_idx_sq1);
        fds_sq1 = sum(fvec_sq1==0:10);  
        fds_sq1(5) = sum(fds_sq1(5:end));
        hist_fds_sq1 = fds_sq1 ./ nansum(fds_sq1) .* 100;
        
        % list aligned fields
        fvec_la1 = tdata.num_fields(pc_idx_la1);
        fds_la1 = sum(fvec_la1==0:10);  
        fds_la1(5) = sum(fds_la1(5:end));
        hist_fds_la1 = fds_la1 ./ nansum(fds_la1) .* 100;
        
        % list tilted fields
        fvec_la2 = tdata.num_fields(pc_idx_la2);
        fds_la2 = sum(fvec_la2==0:10);  
        fds_la2(5) = sum(fds_la2(5:end));
        hist_fds_la2 = fds_la2 ./ nansum(fds_la2) .* 100;

        % plot results
        msize = 5;
        p1 = plot(0:4,hist_fds_sq1(1:5),'Color',colsq,'Marker','o','MarkerSize',msize,'LineWidth',flnw); hold on
        p2 = plot(0:4,hist_fds_la1(1:5),'Color',collt,'Marker','o','MarkerSize',msize,'LineWidth',flnw);
        p3 = plot(0:4,hist_fds_la2(1:5),'Color',coldi,'Marker','o','MarkerSize',msize,'LineWidth',flnw);

        xlabel('Fields per cell');
        ylabel('% Place cells');
        ax = gca;
        ax.XTickLabel = {'0','1','2','3','>3'};
        ax.YLim = [0 60];
        ax.XLim = [0 4.5];
        box off
        nsq1 = sum(pc_idx_sq1);
        nla1 = sum(pc_idx_la1);
        nla2 = sum(pc_idx_la2);        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Fields per cell inset
    ax_D = axes('Units','pixels','Position',[160 ynow+80 70 90]);  
        [ds,gs] = vectorDATAGROUP([],fvec_sq1,fvec_la1,fvec_la2);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',7,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        ylabel('Fields per cell')
        hold on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
            
            disp(sprintf('fields per cells:'))
            stats_and_bars(ds,gs,[],flnw,fsiz);

%             totc = length(unique(tdata.uci));
%             disp(sprintf('Cells:'))
%             disp(sprintf('\tClusters: %d',totc))
%             pysq = sum(tdata.part==1 & tdata.cell_type<3);
%             pyla1 = sum(tdata.part==2 & tdata.lat_type==1 & tdata.cell_type<3);
%             pyla2 = sum(tdata.part==2 & tdata.lat_type==2 & tdata.cell_type<3);
%             disp(sprintf('\tPyramidal cells square: %d (%.2f)',pysq,pysq))
%             disp(sprintf('\tPyramidal cells lattice: %d (%.2f)',pyla1,pyla1))
%             disp(sprintf('\tPyramidal cells diagonal: %d (%.2f)',pyla2,pyla2))
%             pcsq = sum(pc_idx_sq1);
%             pcla1 = sum(pc_idx_la1);
%             pcla2 = sum(pc_idx_la2);
%             disp(sprintf('\tPlace cells square: %d (%.2f)',pcsq,pcsq/pysq*100))
%             disp(sprintf('\tPlace cells lattice: %d (%.2f)',pcla1,pcla1/pyla1*100))
%             disp(sprintf('\tPlace cells diagonal: %d (%.2f)',pcla2,pcla2/pyla2*100))
% 
%             disp(sprintf('\tPlace cells with field square: %d / %d (%.2f)',length(unique(fdata.uci(pf_idx_sq1))),pcsq,length(unique(fdata.uci(pf_idx_sq1)))/pcsq*100))
%             disp(sprintf('\tPlace cells with field lattice: %d / %d (%.2f)',length(unique(fdata.uci(pf_idx_la1))),pcla1,length(unique(fdata.uci(pf_idx_la1)))/pcla1*100))
%             disp(sprintf('\tPlace cells with field diagonal: %d / %d (%.2f)',length(unique(fdata.uci(pf_idx_la2))),pcla2,length(unique(fdata.uci(pf_idx_la2)))/pcla2*100))    
% 
%             disp(sprintf('\tPlace fields square: %d (%.2f)',sum(pf_idx_sq1)))
%             disp(sprintf('\tPlace fields lattice: %d (%.2f)',sum(pf_idx_la1)))
%             disp(sprintf('\tPlace fields diagonal: %d (%.2f)',sum(pf_idx_la2)))    
%             return

%% ##################################### fields per m3
    ax_E = axes('Units','pixels','Position',[270 ynow 140 150],'YAxisLocation','left');  
        % get the mean volume of each maze
        vsq1 = nanmean(bdata.path_volume(pb_idx_sq1))/1000000000; % convert path volumke which is in mm3 to metres cubed
        vla1 = nanmean(bdata.path_volume(pb_idx_la1))/1000000000;
        vla2 = nanmean(bdata.path_volume(pb_idx_la2))/1000000000;

        % fields per m3
        fpv_sq1 = fvec_sq1 ./ vsq1;
        fpv_la1 = fvec_la1 ./ vla1;
        fpv_la2 = fvec_la2 ./ vla2;

        [ds,gs] = vectorDATAGROUP([],fpv_sq1,fpv_la1,fpv_la2);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        ylabel('Fields per m^{3}')
        hold on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            % significance bridges
            [p,a,sts] = kruskalwallis(ds,gs,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');
            pindx = c(:,end);
            pvals = c(pindx<=.05,end);
            gvals = c(pindx<=.05,1:2);
            gvals = mat2cell(gvals,ones(size(gvals,1),1),2);
            lh = addSIGBARS(cell2mat(gvals),[max(ds(gs==1)) max(ds(gs==2)) max(ds(gs==3))],pvals,0.1,flnw,fsiz);    

            disp('Maze volumes:')    
            disp(sprintf('\tSquare = %.2f, Lattice = %.2f, Diagonal = %.2f',vsq1,vla1,vla2))
            disp('Fields per volume:')    
            disp(sprintf('\tX2(%d) = %.3f, p = %.3f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(ds)))))
            disp(sprintf('\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(fpv_sq1),nanmedian(fpv_la1),nanmedian(fpv_la2)))
 
%% ##################################### %% place field volumes in the different environments
    ax_F = axes('Units','pixels','Position',[470 ynow 150 150]);     
        fv_sq1 = fdata.field_convex_volume(pf_idx_sq1)*5*1e-6;
        fv_la1 = fdata.field_convex_volume(pf_idx_la1)*5*1e-6;
        fv_la2 = fdata.field_convex_volume(pf_idx_la2)*5*1e-6;

        [ds,gs] = vectorDATAGROUP([],fv_sq1,fv_la1,fv_la2);
        [p,s] = boxplot3(ds,'xdata',gs,'kernbw',0.0003,'buffer',0.01,'dotsize',5,'gap',0.1,'dotcols',{colsq,collt,coldi},'kerncols',{colsq,collt,coldi},'kernsupport',[60*5*1e-6 inf]); 
%         boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        hold on
        vcut = 64*5*1e-6;
        line(ax.XLim,[vcut vcut],'Color',[.5 .5 .5])        
        ax.YScale = 'log';
        ax.YLim = [40*5*1e-6 0.5];
        ax.YTick = [40*5*1e-6 .001 .01 .1];
        axisn = axis;
        ylabel('Field volume log(m^{3})')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            % significance bridges
            ax_Fb = axes('Units','pixels','Position',[470 ynow 150 150],'Color','none');     
            axis(axisn-[0 0 100 0]);
            axis off
            y1 = ax.YLim;
            disp('Field volume:')    
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;    
      
%% ##################################### %% place field diameters
    ax_F = axes('Units','pixels','Position',[670 ynow 150 150]);    
        fv_sq1 = fdata.field_principalaxes(pf_idx_sq1) .*5 ./ 100;
        fv_la1 = fdata.field_principalaxes(pf_idx_la1) .*5 ./ 100;
        fv_la2 = fdata.field_principalaxes(pf_idx_la2) .*5 ./ 100;

        [ds,gs] = vectorDATAGROUP([],fv_sq1,fv_la1,fv_la2);
        [p,s] = boxplot3(ds,'xdata',gs,'kernbw',0.05,'buffer',0.01,'dotsize',5,'gap',0.1,'dotcols',{colsq,collt,coldi},'kerncols',{colsq,collt,coldi}); 
%         boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 2.5];
        ylabel('Enclosing diameter (m)')
        hold on
        vcut = 4^3 * 50/1000000000;
        line(ax.XLim,[vcut vcut],'Color',[.5 .5 .5])
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places            

            % significance bridges
            y1 = ax.YLim;
            disp('Field diameter:')    
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    


        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        


