%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG5_field_centroids small function to make Fig. 5
% Figure 5 contains example field distributions and field centroid data
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,842]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 600+70, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 410+70, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    
    annotation('textbox','Units','pixels','Position',[5, 330, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 180, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 
    
    annotation('textbox','Units','pixels','Position',[65, 390+70, 300, 20],'string','All fields','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[100, 600+70, 300, 20],'string','Arena','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[260, 600+70, 300, 20],'string','Aligned','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[430, 600+70, 300, 20],'string','Tilted','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

%% ##################################### %% Convex hulls from example sessions
    vlcut = 300;
    dirs = {[30,22],250,[sdir '\896_11012018.mat'],896,180111;...
            [30,22],250,[sdir '\896_11012018.mat'],896,180111;...
            [30,22],250,[sdir '\926_13042018.mat'],926,180413};  
        
    ax_poss = {[50 420+70 150 150],[220 420+70 150 150],[370 390+70 200 200]};
    ann_poss = {[-30 580+70 200 20],[140 580+70 200 20],[290 580+70 200 20]};    
    for pp = 1:3 % for every maze             
        disp(sprintf('\t...session: %d',pp));
        cd(sdir);
        load(dirs{pp,3},'-mat','sdata');

        start_string = ['r' sdata.rat_num '_' sdata.date]; % the start of every cluster fieldname
        fdnames = fieldnames(sdata);
        cindx = strfind(fdnames,start_string);
        cindx(cellfun('isempty',cindx)) = {NaN}; % fill empty index values with NaN
        cindx = find(cell2mat(cindx)==1); % find where the non-NaNs are
        cell_names = fdnames(cindx);    
        cnow = jet(length(cell_names));            

        ax_sess1b = axes('Units','pixels','Position',ax_poss{pp});   
            hold on
            if pp==1
                snow = 'square1_3d';
            else
                snow = 'lattice_3d';      
            end
            dwellmap = sdata.(snow).dwellmap;
            dwellmap2 = dwellmap;
            dwellmap2(dwellmap < 1) = NaN; % remove voxels with a coverage less than 1 second (the minimum when generating ratemap)
            [p2,p1,p3] = ind2sub(size(dwellmap2),find(~isnan(dwellmap2))); % find the subscript indices of these elements
            K = convhull(p1,p2,p3); % find the convexhull of these points
            tri = trisurf(K,p1,p2,p3); % plot it
            set(tri,'FaceColor','k','EdgeColor','none','FaceAlpha',0.04)
            hold on
            tfields = 0;
            ncell = 0;
            nfield = 0;
            for cc = 1:length(cell_names) % for every place cell
                uci = cell_names{cc};
                ucin = str2double(uci(regexp(uci,'\d')));

                sst = strsplit(uci,'_');
                tet = str2double(sst{3}(regexp(sst{3},'\d')));
                tetstr = ['t' num2str(tet)];    
                clu = str2double(sst{4}(regexp(sst{4},'\d')));              
                if ~clu || sdata.(uci).manual_cell_type ~= 1
                    continue
                end

                fdatan = sdata.(uci).(snow).field_data;
                nfields = sdata.(uci).(snow).nfields;
                tfields = tfields+nfields;
                if ~nfields
                    continue
                end            

                ncell = ncell+1;
                for ff = 1:nfields % for every detected place field
                    if ~isfield(fdatan(ff),'voxel_index')
                        continue
                    end
                    v = fdatan(ff).convex_volume;
                    if v>vlcut
                        continue
                    end   
                    nfield = nfield+1;
                    ps = fdatan(ff).voxel_index;
                    K = convhull(ps(:,2),ps(:,1),ps(:,3));
                    tri = trisurf(K,ps(:,2),ps(:,1),ps(:,3));
                    set(tri,'FaceColor',cnow(cc,:),'EdgeColor','none','FaceAlpha',.5);
                end              
            end
            hold on
            lx2 = sdata.(snow).lxrm;
            ly2 = sdata.(snow).lyrm;
            lz2 = sdata.(snow).lzrm;           
            h = line(lx2,ly2,lz2);
            set(h,'Color',[0.5 0.5 0.5 0.5],'LineWidth',1,'LineStyle','-');
            axis([min(lx2)-4,max(lx2)+4,min(ly2)-4,max(ly2)+4,min(lz2)-4,max(lz2)+4]);    

            view(dirs{pp,1});
            daspect([1 1 1])
            xlabel('X');
            ylabel('Y');
            zlabel('Z');
            axis vis3d off tight
            rotate3d on         
            lighting phong;
            camlight;          

            view(dirs{pp,1});         
            annstr = sprintf('Rat %d\n%d\n%d fields',dirs{pp,4},dirs{pp,5},tfields);
            annotation('textbox','Units','pixels','Position',ann_poss{pp},'string',annstr,'FontSize',6,'LineStyle','none','interpreter','none','HorizontalAlignment','right');   
    end
    cd(sdir);

%% ##################################### %% Inset maze schematics
%% Square
    ax_sq_sch = axes('Units','pixels','Position',ax_poss{1}+[100 100 -40 -40]);   
        plotMAZE(gcf,ax_sq_sch,1)     
        camproj perspective
        rotate3d on
        axis xy tight off

%% Aligned        
    ax_lt_sch = axes('Units','pixels','Position',ax_poss{2}+[100 100 -40 -40]);   
        plotMAZE(gcf,ax_lt_sch,2)     
        camproj perspective
        rotate3d on
        axis xy tight off
  
%% Tilted        
    ax_di_sch = axes('Units','pixels','Position',ax_poss{3}+[100 120 -80 -80]);   
        plotMAZE(gcf,ax_di_sch,3)     
        camproj perspective
        rotate3d on
        axis xy tight off  
     
%% ##################################### %% All field centroids
%% Square centroids
    ax_cent_sq = axes('Units','pixels','Position',ax_poss{1}-[40 210 -80 -80]);  
        index_now = pf_idx_sq1;
        fx1 = fdata.field_lattice_centroid(index_now,1);
        fy1 = fdata.field_lattice_centroid(index_now,2);
        fz1 = fdata.field_lattice_centroid(index_now,3);
        load('square1_frame.mat');
        lx1 = (lx - nanmean(lx)) ./ 10 + 5;
        ly1 = (ly - nanmean(ly)) ./ 10 + 5;
        lz1 = (lz - nanmean(lz)) ./ 10 -10;      
        cdat = [lx1 ly1 lz1];
        cdat(any(isnan(cdat),2),:) = [];
        k = convhulln(cdat);
        idx = inhull([fx1 fy1 fz1],cdat,k);
        scatter3(fx1(idx),fy1(idx),fz1(idx),20,fz1(idx),'filled','MarkerFaceAlpha',1,'MarkerEdgeColor','k','MarkerEdgeAlpha',.5);
        daspect([1 1 1])
        view(dirs{1,1});
        hold on
        colormap(ax_cent_sq,parula)
        line(lx1,ly1,lz1,'Color',[.5 .5 .5 .5]);
        axis xy tight off 

        hold on
        l1 = normr([-970 0 0]); l2 = normr([970 0 0]); l3 = normr([0 970 0]); l4 = normr([0 -970 0]); l5 = normr([0 0 970]); l6 = normr([0 0 -970]); l7 = normr([0 660 466.69]); l8 = normr([0 -660 -466.69]); l9 = normr([571.6 -330 466.69]); l10 = normr([-571.6 330 -466.69]);  l11 = normr([-571.55 -330 466.69]); l12 = normr([571.55 330 -466.69]);   
        adj = 90;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};
        orig = [5 5 -10];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis xy tight off 

%% Aligned centroids
    ax_cent_lt = axes('Units','pixels','Position',ax_poss{2}-[40 210 -80 -80]);  
        index_now = pf_idx_la1;
        fx1 = fdata.field_lattice_centroid(index_now,1);
        fy1 = fdata.field_lattice_centroid(index_now,2);
        fz1 = fdata.field_lattice_centroid(index_now,3);
        load('lattice_frame.mat');
        lx1 = (lx - nanmean(lx)) ./ 10 + 5;
        ly1 = (ly - nanmean(ly)) ./ 10 + 5;
        lz1 = (lz - nanmean(lz)) ./ 10 -10;
        cdat = [lx1 ly1 lz1];
        cdat(any(isnan(cdat),2),:) = [];
        k = convhulln(cdat);
        idx = inhull([fx1 fy1 fz1],cdat,k);
        scatter3(fx1(idx),fy1(idx),fz1(idx),20,fz1(idx),'filled','MarkerFaceAlpha',1,'MarkerEdgeColor','k','MarkerEdgeAlpha',.5);
        daspect([1 1 1])
        view(dirs{2,1});
        hold on
        colormap(ax_cent_lt,parula)

        line(lx1,ly1,lz1,'Color',[.5 .5 .5 .5]); 
        axis tight vis3d off    
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};
        orig = [5 5 -10];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis xy tight off 

%% Tilted centroids   
    ax_cent_di = axes('Units','pixels','Position',ax_poss{3}-[30 180 -40 -40]);  
        index_now = pf_idx_la2;
        fx2 = fdata.field_lattice_centroid(index_now,1);
        fy2 = fdata.field_lattice_centroid(index_now,2);
        fz2 = fdata.field_lattice_centroid(index_now,3);
        load('diag_frame.mat');
        lx2 = (lx - nanmean(lx)) ./ 10 + 5;
        ly2 = (ly - nanmean(ly)) ./ 10 + 5;
        lz2 = (lz - nanmean(lz)) ./ 10 -10;
        cdat = [lx2 ly2 lz2];
        cdat(any(isnan(cdat),2),:) = [];
        k = convhulln(cdat);
        idx = inhull([fx2 fy2 fz2],cdat,k);
        scatter3(fx2(idx),fy2(idx),fz2(idx),20,fz2(idx),'filled','MarkerFaceAlpha',1,'MarkerEdgeColor','k','MarkerEdgeAlpha',.5);
        daspect([1 1 1])
        view(dirs{3,1});    
        hold on
        colormap(ax_cent_di,parula)

        line(lx2,ly2,lz2,'Color',[.5 .5 .5 .5]);
        axis tight vis3d off    
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};
        orig = [5 5 -10];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis xy tight off 

%% colorbar for field centroids
    axc_field = axes('Units','pixels','Position',[ax_cent_di.Position(1)+220 ax_cent_di.Position(2)+70 10 100]);
        imagesc(((1:256)'));
        colormap(axc_field,'parula')
        axis xy off
        text(0.5,-0.08,'0','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
       
%% marker key        
    ax_Clt = axes('Units','pixels','Position',ax_poss{1}+[50 -95 -60 0]); 
        scatter3(1,1,1,20,1,'filled','MarkerFaceAlpha',1,'MarkerEdgeColor','k','MarkerEdgeAlpha',.5);
        daspect([1 1 1])
        view(90,0);
        hold on
        colormap(ax_Clt,parula)
        text(1,0.5,' = field centroid','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        axis off
        
%% ##################################### %% place field distributions
    ynow = 220;
    xi = -100:5:100;
    bw = 5;
    
%% Arena    
    ax_F1 = axes('Units','pixels','Position',[ax_cent_sq.Position(1)+50 ynow 130 80]);             
        cents = fdata.field_lattice_centroid(pf_idx_sq1,:);
        [~,~,~,f1] = histDENSITY(cents(:,1),xi,bw);
        [~,~,~,f2] = histDENSITY(cents(:,2),xi,bw);
        plot(xi(:),f1,'Color',colx,'LineWidth',1.5); hold on;
        plot(xi(:),f2,'Color',coly,'LineWidth',1.5);
        
        ax = gca;
        ax.XLim = [-100 100];
        xlabel('Distance from center (cm)')
        ylabel('Proportion of fields')
        grid off
        box off
        
        line([nanmedian(cents(:,1)),nanmedian(cents(:,1))],ax.YLim,'Color',colx)
        line([nanmedian(cents(:,2)),nanmedian(cents(:,2))],ax.YLim,'Color',coly)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        
%% Aligned        
    ax_F2 = axes('Units','pixels','Position',[ax_cent_lt.Position(1)+60 ynow 130 80]); 
        cents = fdata.field_lattice_centroid(pf_idx_la1,:);
        [~,~,~,f1] = histDENSITY(cents(:,1),xi,bw);
        [~,~,~,f2] = histDENSITY(cents(:,2),xi,bw);
        [~,~,~,f3] = histDENSITY(cents(:,3),xi,bw);
        p1 = plot(xi(:),f1,'Color',colx,'LineWidth',1.5); hold on;
        p2 = plot(xi(:),f2,'Color',coly,'LineWidth',1.5);    
        p3 = plot(xi(:),f3,'Color',colz,'LineWidth',1.5);    
        
        ax = gca;
        ax.XLim = [-100 100];
        xlabel('Distance from center (cm)')
        grid off
        box off
        ax.YColor = 'none';   
            
        l1 = line([nanmedian(cents(:,1)),nanmedian(cents(:,1))],ax.YLim,'Color',colx);
        l2 = line([nanmedian(cents(:,2)),nanmedian(cents(:,2))],ax.YLim,'Color',coly);
        l3 = line([nanmedian(cents(:,3)),nanmedian(cents(:,3))],ax.YLim,'Color',colz);
        
        ll = legend([p1 p2 p3],{'X' 'Y' 'Z'},'Location','best');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[-0.1 0.01 0 0]);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        
%% Tilted        
    ax_F3 = axes('Units','pixels','Position',[ax_cent_di.Position(1)+70 ynow 130 80]); 
        cents = fdata.field_lattice_centroid(pf_idx_la2,:);
        [~,~,~,f1] = histDENSITY(cents(:,1),xi,bw);
        [~,~,~,f2] = histDENSITY(cents(:,2),xi,bw);
        [~,~,~,f3] = histDENSITY(cents(:,3),xi,bw);
        plot(xi(:),f1,'Color',colx,'LineWidth',1.5); hold on;
        plot(xi(:),f2,'Color',coly,'LineWidth',1.5);    
        plot(xi(:),f3,'Color',colz,'LineWidth',1.5);     
            
        ax = gca;
        ax.XLim = [-100 100];
        xlabel('Distance from center (cm)')
        grid off
        box off
        ax.YColor = 'none';             
   
        line([nanmedian(cents(:,1)),nanmedian(cents(:,1))],ax.YLim,'Color',colx)
        line([nanmedian(cents(:,2)),nanmedian(cents(:,2))],ax.YLim,'Color',coly)
        line([nanmedian(cents(:,3)),nanmedian(cents(:,3))],ax.YLim,'Color',colz)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
                
%% ##################################### %% place field distribution shuffles
%% Arena X
    ax_sq1_insetX = axes('Units','pixels','Position',[ax_F1.Position(1) ax_F1.Position(2)-90 ax_F1.Position(3) 40]);  
        maz = 1;
        paper_3_ANA_fdist;

        bsiz = .5;
        bw2 = .25;
        xi = -10:0.1:10;
        [~,~,~,f] = histDENSITY(shuff_pos(:,1),xi,bw2);
        prs = prctile(shuff_pos(:,1),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',colx); hold on;
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = [];
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(1) obs_pos(1)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        
%% Arena Y        
    ax_sq1_insetY = axes('Units','pixels','Position',ax_sq1_insetX.Position+[0 -45 0 0]);  
        [~,~,~,f] = histDENSITY(shuff_pos(:,2),xi,bw2);
        prs = prctile(shuff_pos(:,2),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',coly); hold on;
        ylabel('Proportion of fields')
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = -10:5:10;
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(2) obs_pos(2)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        xlabel('Median field position (cm)')            

%% Aligned X
    ax_la1_insetX = axes('Units','pixels','Position',[ax_F2.Position(1) ax_F2.Position(2)-90 ax_F2.Position(3) 40]);  
        maz = 2;
        paper_3_ANA_fdist;
        [~,~,~,f] = histDENSITY(shuff_pos(:,1),xi,bw2);
        prs = prctile(shuff_pos(:,1),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',colx); hold on;
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = [];
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(1) obs_pos(1)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Aligned Y       
    ax_la1_insetY = axes('Units','pixels','Position',ax_la1_insetX.Position+[0 -45 0 0]);  
        [~,~,~,f] = histDENSITY(shuff_pos(:,2),xi,bw2);
        prs = prctile(shuff_pos(:,2),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',coly); hold on;
        ylabel('Proportion of fields')
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = [];
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(2) obs_pos(2)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Aligned Z            
    ax_la1_insetZ = axes('Units','pixels','Position',ax_la1_insetY.Position+[0 -45 0 0]);  
        [~,~,~,f] = histDENSITY(shuff_pos(:,3),xi,bw2);
        prs = prctile(shuff_pos(:,3),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',colz); hold on;
        xlabel('Median field position (cm)')                        
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = -10:5:10;
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(3) obs_pos(3)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Tilted X 
    ax_la2_insetX = axes('Units','pixels','Position',[ax_F3.Position(1) ax_F3.Position(2)-90 ax_F3.Position(3) 40]);  
        maz = 3;
        paper_3_ANA_fdist;
        [~,~,~,f] = histDENSITY(shuff_pos(:,1),xi,bw2);
        prs = prctile(shuff_pos(:,1),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',colx); hold on;
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = [];
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(1) obs_pos(1)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Tilted Y        
    ax_la2_insetY = axes('Units','pixels','Position',ax_la2_insetX.Position+[0 -45 0 0]);  
        [~,~,~,f] = histDENSITY(shuff_pos(:,2),xi,bw2);
        prs = prctile(shuff_pos(:,2),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',coly); hold on;
        ylabel('Proportion of fields')
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = [];
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(2) obs_pos(2)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% Tilted Z        
    ax_la2_insetZ = axes('Units','pixels','Position',ax_la2_insetY.Position+[0 -45 0 0]);  
        [~,~,~,f] = histDENSITY(shuff_pos(:,3),xi,bw2);
        prs = prctile(shuff_pos(:,3),[2.5 50 97.5]);
        a1 = area(xi,f,'FaceColor',colz); hold on;
        xlabel('Median field position (cm)')                        
        ax = gca;
        ax.YLim = [0 0.022];
        ax.YTick = 0:0.01:0.02;
        ax.XLim = [-10 10];
        ax.XTick = -10:5:10;
        lin1 = line([prs(1) prs(1)],ax.YLim,'Color','r');
        line([prs(3) prs(3)],ax.YLim,'Color','r');
        lb = line([obs_pos(3) obs_pos(3)],ax.YLim,'Color','b');   
        lr = line([prs(2) prs(2)],ax.YLim,'Color','r','LineStyle',':');   
        box off
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    











