%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG6_axis_lengths_elongation small function to make Fig. 6
% Figure 6 contains field axis lengths and their distributions
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,651,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    set(0,'DefaultAxesTitleFontWeight','normal');
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts
    flnw = 0.5; % the line width for different plots

    annotation('textbox','Units','pixels','Position',[5, 900, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[375, 900, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[490, 900, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 670, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% place field elongation and significance
    ax_B = axes('Units','pixels','Position',[410 725 80 150]);
        % get the elongation index of every place field
        eindx_sq1 = fdata.field_elongidx_stats(pf_idx_sq1,1); % elongation index
        eindx_la1 = fdata.field_elongidx_stats(pf_idx_la1,1);
        eindx_la2 = fdata.field_elongidx_stats(pf_idx_la2,1);        

        % get the result of the shuffle elongation test
        col_sq1 = fdata.field_elongidx_stats(pf_idx_sq1,5); % significance
        col_la1 = fdata.field_elongidx_stats(pf_idx_la1,5);
        col_la2 = fdata.field_elongidx_stats(pf_idx_la2,5);

        % get the proportion of elongated fields in each environment
        sig_sq1 = nansum(col_sq1)/numel(col_sq1)*100;
        sig_la1 = nansum(col_la1)/numel(col_la1)*100;
        sig_la2 = nansum(col_la2)/numel(col_la2)*100;

        [ds,gs] = vectorDATAGROUP([],eindx_sq1,eindx_la1,eindx_la2);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);    

        cmap = gray(5);     
        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 ax.YLim(2)];
        ylabel('Field elongation')

        hold on
        line(ax.XLim,[1 1],'Color',[.5 .5 .5])
        text(1,0.5,sprintf('%.1f%%',100-sig_sq1),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));
        text(2,0.5,sprintf('%.1f%%',100-sig_la1),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));
        text(3,0.5,sprintf('%.1f%%',100-sig_la2),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));  
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            disp('Spherical fields lattice (eidx):')        
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_sq1),numel(col_sq1),100-sig_sq1))
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_la1),numel(col_la1),100-sig_la1))
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_la2),numel(col_la2),100-sig_la2))

            % significance bridges
            disp(sprintf('Elongation:'))
            stats_and_bars(ds,gs,[],flnw,fsiz);
            
            [p,~,s] = signrank(eindx_sq1,1,'method','approximate');
            disp(sprintf('Arena elongation vs 1: z = %.4f, p = %.4f',s.zval,p));
            [p,~,s] = signrank(eindx_la1,1,'method','approximate');
            disp(sprintf('Aligned elongation vs 1: z = %.4f, p = %.4f',s.zval,p));            
            [p,~,s] = signrank(eindx_la2,1,'method','approximate');
            disp(sprintf('Tilted elongation vs 1: z = %.4f, p = %.4f',s.zval,p));
            
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% place field sphericity and significance
    ax_C = axes('Units','pixels','Position',[540 725 80 150]);
        % get the sphericity of every place field
        eindx_sq1 = fdata.field_sphericity_stats(pf_idx_sq1,1); % elongation index
        eindx_la1 = fdata.field_sphericity_stats(pf_idx_la1,1);
        eindx_la2 = fdata.field_sphericity_stats(pf_idx_la2,1);        

        % get the result of the shuffle sphericity test
        col_sq1 = fdata.field_sphericity_stats(pf_idx_sq1,5); % significance
        col_la1 = fdata.field_sphericity_stats(pf_idx_la1,5);
        col_la2 = fdata.field_sphericity_stats(pf_idx_la2,5);

        % get the proportion of spherical fields in each environment
        sig_sq1 = nansum(col_sq1)/numel(col_sq1)*100;
        sig_la1 = nansum(col_la1)/numel(col_la1)*100;
        sig_la2 = nansum(col_la2)/numel(col_la2)*100;

        [ds,gs] = vectorDATAGROUP([],eindx_sq1,eindx_la1,eindx_la2);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);     

        box off
        ax = gca;
        ax.XTickLabel = {m1name,m2name,m3name};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0.4 1];
        ylabel('Sphericity')

        hold on
        line(ax.XLim,[1 1],'Color',[.5 .5 .5])
        text(1,0.97,sprintf('%.1f%%',100-sig_sq1),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));
        text(2,0.97,sprintf('%.1f%%',100-sig_la1),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));
        text(3,0.97,sprintf('%.1f%%',100-sig_la2),'FontSize',6,'HorizontalAlignment','center','Color',cmap(1,:));  
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            disp('Spherical fields lattice (sphericity):')        
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_sq1),numel(col_sq1),100-sig_sq1))
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_la1),numel(col_la1),100-sig_la1))
            disp(sprintf('\t%d / %d (%.2f)',nansum(~col_la2),numel(col_la2),100-sig_la2))    

            % significance bridges
            disp(sprintf('Sphericity:'))
            stats_and_bars(ds,gs,[],flnw,fsiz,0.15);
            
            [p,~,s] = signrank(eindx_sq1,1,'method','approximate');
            disp(sprintf('Arena sphericity vs 1: z = %.4f, p = %.4f',s.zval,p));
            [p,~,s] = signrank(eindx_la1,1,'method','approximate');
            disp(sprintf('Aligned sphericity vs 1: z = %.4f, p = %.4f',s.zval,p));            
            [p,~,s] = signrank(eindx_la2,1,'method','approximate');
            disp(sprintf('Tilted sphericity vs 1: z = %.4f, p = %.4f',s.zval,p));
            
%% ##################################### %% Axis lengths for all mazes and axes
%% Arena
    ax_A = axes('Units','pixels','Position',[50 725 60 150]);
        baxis_sq1 = fdata.field_bounding_box(pf_idx_sq1,4:6)*5;
        baxis_la1 = fdata.field_bounding_box(pf_idx_la1,4:6)*5;
        baxis_la2 = fdata.field_bounding_box(pf_idx_la2,4:6)*5;
        baxis_la2d = fdata.field_diagonal_bounding_box(pf_idx_la2,4:6)*5;

        paxis_sq1 = fdata.field_principalaxes(pf_idx_sq1,:)*5;
        paxis_la1 = fdata.field_principalaxes(pf_idx_la1,:)*5;
        paxis_la2 = fdata.field_principalaxes(pf_idx_la2,:)*5;
        paxis_la2d = fdata.field_diagonal_principalaxes(pf_idx_la2,:)*5;

        [ds,gs] = vectorDATAGROUP([],baxis_sq1(:,1),baxis_sq1(:,2),paxis_sq1(:,1),paxis_sq1(:,2));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,colsq,colsq,colsq},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,colsq,colsq,colsq},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = [1:8];
        ax.XTickLabel = {'X' 'Y' 'P1' 'P2'};  
        xlabel(m1name)
        ax.XLim = [0.5 4.5];
        ynow = ax.YLim;
        ylabel('Axis length (cm)')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

%% Aligned        
    ax_A = axes('Units','pixels','Position',[120 725 90 150]);
        [ds,gs] = vectorDATAGROUP([],baxis_la1(:,1),baxis_la1(:,2),baxis_la1(:,3),paxis_la1(:,1),paxis_la1(:,2),paxis_la1(:,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{collt,collt,collt,collt,collt,collt},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{collt,collt,collt,collt,collt,collt},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'X' 'Y' 'Z' 'P1' 'P2' 'P3'};     
        ax.YLim = ynow;
        xlabel(m2name)
        ax.XLim = [0.5 6.5];
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

%% Tilted        
    ax_A = axes('Units','pixels','Position',[220 725 135 150]);
        [ds,gs] = vectorDATAGROUP([],baxis_la2(:,1),baxis_la2(:,2),baxis_la2(:,3),baxis_la2d(:,1),baxis_la2d(:,2),baxis_la2d(:,3),paxis_la2(:,1),paxis_la2(:,2),paxis_la2(:,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{coldi,coldi,coldi,coldi,coldi,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{coldi,coldi,coldi,coldi,coldi,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = 1:9;    
        ax.XTickLabel = {'X' 'Y' 'Z' 'A' 'B' 'C' 'P1' 'P2' 'P3'};   
        ax.YLim = ynow;
        xlabel(m3name)
        ax.XLim = [0.5 9.5];
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            %% square stats
            [p,a,sts] = friedman(baxis_sq1(:,1:2),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');
            ax.YLim = [0 210];   

            disp(sprintf('\tSquare field size HWD:'))    
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.3f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(baxis_sq1(:,1:2))))))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(baxis_sq1(:,1)),nanmedian(baxis_sq1(:,2)),nanmedian(baxis_sq1(:,3))))     
            arat = baxis_sq1(:,3) ./ nanmean(baxis_sq1(:,1:2),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1)) 
            
            % principal axis lengths
            disp(sprintf('\tSquare principal axes XYZ:'))    
            [p,a,sts] = friedman(paxis_sq1(:,1:3),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');        
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.3f',a{2,3},a{2,5},p))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(paxis_sq1(:,1)),nanmedian(paxis_sq1(:,2)),nanmedian(paxis_sq1(:,3))))     
            arat = paxis_sq1(:,1) ./ nanmean(paxis_sq1(:,2),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1))              

            %% Aligned lattice stats
            [p,a,sts] = friedman(baxis_la1(:,1:3),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');
            ax.YLim = [0 210];   

            disp(sprintf('\n\tAligned field size HWD:'))    
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.3f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(baxis_la1(:,1:2))))))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(baxis_la1(:,1)),nanmedian(baxis_la1(:,2)),nanmedian(baxis_la1(:,3))))     
            arat = baxis_la1(:,3) ./ nanmean(baxis_la1(:,1:2),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1))            

            % principal axis lengths
            disp(sprintf('\tAligned principal axes XYZ:'))    
            [p,a,sts] = friedman(paxis_la1(:,1:3),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');        
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.3f',a{2,3},a{2,5},p))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(paxis_la1(:,1)),nanmedian(paxis_la1(:,2)),nanmedian(paxis_la1(:,3))))     
            arat = paxis_la1(:,1) ./ nanmean(paxis_la1(:,2:3),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1))            

            %% Tilted lattice stats
            [p,a,sts] = friedman(baxis_la2(:,1:3),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');
            ax.YLim = [0 210];   

            disp(sprintf('\n\tTilted field size HWD:'))    
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.5f, eta = %.5f',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(vert(baxis_la2(:,1:2))))))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(baxis_la2(:,1)),nanmedian(baxis_la2(:,2)),nanmedian(baxis_la2(:,3))))     
            arat = baxis_la2(:,3) ./ nanmean(baxis_la2(:,1:2),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1))            

            % principal axis lengths
            disp(sprintf('\tTilted principal axes XYZ:'))    
            [p,a,sts] = friedman(paxis_la2(:,1:3),1,'off');
            [c,m,h,g] = multcompare(sts,'display','off','ctype','bonferroni');        
            disp(sprintf('\t\tX2(%d) = %.3f, p = %.5f',a{2,3},a{2,5},p))
            disp(sprintf('\t\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(paxis_la2(:,1)),nanmedian(paxis_la2(:,2)),nanmedian(paxis_la2(:,3))))     
            arat = paxis_la2(:,1) ./ nanmean(paxis_la2(:,2:3),2);
            disp(sprintf('\t\tMedian elongation = %.3f',nanmedian(arat)))     
            [p,~,s] = signrank(arat,1);
            u3 = mes(arat,1,'U3_1');
            disp(sprintf('\t\tz = %.3f, p = %.5f, u3 = %.3f',s.zval,p,u3.U3_1))            

%% ##################################### %% PDFs of bounding boxes
    ynow = 540;
%% Aligned XYZ
    ax_B1 = axes('Units','pixels','Position',[50 ynow 180 110]); 
        xi = 1:150;        
        bw = 5;     
        vx = (fdata.field_bounding_box(pf_idx_la1,4).*5);
        vy = (fdata.field_bounding_box(pf_idx_la1,5).*5);
        vz = (fdata.field_bounding_box(pf_idx_la1,6).*5);       
        [~,~,~,dx] = histDENSITY(vx,xi,bw);
        [~,~,~,dy] = histDENSITY(vy,xi,bw);
        [~,~,~,dz] = histDENSITY(vz,xi,bw);
        dx = dx.*100;
        dy = dy.*100;
        dz = dz.*100;

        p1 = plot(xi,dx,'Color',colx); hold on;
        p2 = plot(xi,dy,'Color',coly);
        p3 = plot(xi,dz,'Color',colz);
        xlabel('Field extent (cm)')
        ylabel('Fields (%)')      
        box off
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        ax = gca;
        ax.YLim = [0 2.5];
        ax.YTick = [0:0.5:2.5];
        ax.YTickLabel = {'0.0','0.5','1.0','1.5','2.0','2.5'};            
        y1 = ax.YLim;
        ll = legend([p1 p2 p3],{'X','Y','Z'});
        legend boxoff
        title(ll,m2name,'FontWeight','normal')

            [H1,P1,K1] = kstest2(vx,vy);
            [H2,P2,K2] = kstest2(vx,vz);
            [H3,P3,K3] = kstest2(vy,vz);
            disp('Bounding box distributions:')                
            disp('Aligned:')
            disp(sprintf('\tXvY: Z = %.3f, p = %.3f',K1,P1*3))
            disp(sprintf('\tXvZ: Z = %.3f, p = %.3f',K2,P2*3))
            disp(sprintf('\tYvZ: Z = %.3f, p = %.3f',K3,P3*3))

%% Tilted XYZ                
    ax_B2 = axes('Units','pixels','Position',ax_B1.Position + [200 0 0 0]); 
        xi = 1:150;        
        bw = 5;        
        vx = fdata.field_bounding_box(pf_idx_la2,4).*5;
        vy = fdata.field_bounding_box(pf_idx_la2,5).*5;
        vz = fdata.field_bounding_box(pf_idx_la2,6).*5;                
        [~,~,~,dx] = histDENSITY(vx,xi,bw);
        [~,~,~,dy] = histDENSITY(vy,xi,bw);
        [~,~,~,dz] = histDENSITY(vz,xi,bw);
        dx = dx.*100;
        dy = dy.*100;
        dz = dz.*100;

        p1 = plot(xi,dx,'Color',colx); hold on;
        p2 = plot(xi,dy,'Color',coly);
        p3 = plot(xi,dz,'Color',colz);
        xlabel('Field extent (cm)')
        box off
        ax = gca;
        ax.YLim = y1;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        ll = legend([p1 p2 p3],{'X','Y','Z'});
        legend boxoff 
        title(ll,m3name,'FontWeight','normal')

            [H1,P1,K1] = kstest2(vx,vy);
            [H2,P2,K2] = kstest2(vx,vz);
            [H3,P3,K3] = kstest2(vy,vz);
            disp('Tilted XYZ:')                
            disp(sprintf('\tXvY: Z = %.3f, p = %.3f',K1,P1*3))
            disp(sprintf('\tXvZ: Z = %.3f, p = %.3f',K2,P2*3))
            disp(sprintf('\tYvZ: Z = %.3f, p = %.3f',K3,P3*3))
                        
%% Tilted ABC                
    ax_B3 = axes('Units','pixels','Position',ax_B1.Position + [400 0 0 0]); 
        xi = 1:150;        
        bw = 5;        
        vx = fdata.field_diagonal_bounding_box(pf_idx_la2,4).*5;
        vy = fdata.field_diagonal_bounding_box(pf_idx_la2,5).*5;
        vz = fdata.field_diagonal_bounding_box(pf_idx_la2,6).*5;                
        [~,~,~,dx] = histDENSITY(vx,xi,bw);
        [~,~,~,dy] = histDENSITY(vy,xi,bw);
        [~,~,~,dz] = histDENSITY(vz,xi,bw);
        dx = dx.*100;
        dy = dy.*100;
        dz = dz.*100;

        p1 = plot(xi,dx,'Color',cola); hold on;
        p2 = plot(xi,dy,'Color',colb);
        p3 = plot(xi,dz,'Color',colc);
        xlabel('Field extent (cm)')
        box off
        ax = gca;
        ax.YLim = y1;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        ll = legend([p1 p2 p3],{'A','B','C'});
        legend boxoff 
        title(ll,m3name,'FontWeight','normal')

            [H1,P1,K1] = kstest2(vx,vy);
            [H2,P2,K2] = kstest2(vx,vz);
            [H3,P3,K3] = kstest2(vy,vz);
            disp('Tilted ABC:')                                
            disp(sprintf('\tXvY: Z = %.3f, p = %.3f',K1,P1*3))
            disp(sprintf('\tXvZ: Z = %.3f, p = %.3f',K2,P2*3))
            disp(sprintf('\tYvZ: Z = %.3f, p = %.3f',K3,P3*3))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    























