%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG7_field_orientation small function to make Fig. 7
% Figure 7 contains place field orientation analyses and spherical heatmaps
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,632]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[20, 605, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[20, 435, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[20, 191, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[100, 418, 300, 20],'string','Single session','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[74, 355, 300, 20],'string','All fields','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

    annotation('textbox','Units','pixels','Position',[65, 580, 300, 20],'string','Firing rate map','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[205, 580, 300, 20],'string','Place field','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[335, 580, 300, 20],'string','Field principal axis','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[475, 580, 300, 20],'string','Projected axis','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textarrow',[.27 .32],[.93 .93]);
    annotation('textarrow',[.48 .53],[.93 .93]);
    annotation('textarrow',[.74 .79],[.93 .93]);
    
    annotation('textbox','Units','pixels','Position',[100, 435, 300, 20],'string','Arena','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[270, 435, 300, 20],'string','Aligned','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[440, 435, 300, 20],'string','Tilted','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Top schematic - field orientation process  
%% example ratemap
    ax_rmap = axes('Units','pixels','Position',[30 445 160 160]);       
%         dir = {'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\850_P1_16_HPC\170313_kk_kt_ll_k3\klustest3\kwiktint',5,4,850,170313};    
        dir = {[sdir '\850_13032017.mat'],5,4,850,170313};    
        cd(sdir);
        load(dir{1},'-mat','sdata');

        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dir{2}) '_c' num2str(dir{3})]; 
        dat_now = sdata.(uci);     
    
        part_now3 = 'lattice_3d';
        ratemap = sdata.(uci).(part_now3).ratemap;
        dwellmap = sdata.(part_now3).dwellmap;
        lx2 = sdata.(part_now3).lxrm;
        ly2 = sdata.(part_now3).lyrm;
        lz2 = sdata.(part_now3).lzrm;

        ratemap(ratemap < 0.2*nanmax(ratemap(:))) = NaN;
        vol3d('cdata',ratemap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0.2*nanmax(ratemap(:)) nanmax(ratemap(:))]);

        hold on
            edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
            ori = [min(lx2), min(ly2), min(lz2)]; 
            plotcube(edg,ori,0,0,0.3);

        axis off
        pad_valr = 6;
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on   

%% colorbar for 3D ratemap
    axc_cmap = axes('Units','pixels','Position',[ax_rmap.Position(1)+10 ax_rmap.Position(2)+40 10 90]);
        cmap = repmat(reshape(1:100,[],1),1,1,2);
        cmap(cmap < 0.2*nanmax(cmap(:))) = NaN;
        vol3d('cdata',cmap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0.2*nanmax(cmap(:)) nanmax(cmap(:))]);
        axis xy on tight
        box on
        ax = gca;
        ax.XTick = [];
        ax.YTick = [20];
        ax.YTickLabel = {'20%'};
        text(0.5,-0.08,'0 Hz','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%% convex hull of place field        
    ax_chull = axes('Units','pixels','Position',ax_rmap.Position+[130 0 0 0]);       
        % plot overall position data outline
        fields = sdata.(uci).(part_now3).nfields;
        fddata = sdata.(uci).(part_now3).field_data;
        hold on
        
        nfield = 0;
        if ~fields<1
            cols = {'r','k','k','k'};
            map = zeros(size(dwellmap));
            fidx = fdata.tetrode==num2str(dir{2}) & fdata.cluster==num2str(dir{3}) & fdata.part==2;
            fdata2 = fdata(fidx,:);
            for ff = 1:fields % for every detected place field
                ps = fddata(ff).voxel_index;
                if fddata(ff).volume_voxels>fvol_thresh(1) & fddata(ff).field_visits>fv_thresh
                    emap = zeros(size(dwellmap));
                    emap(sub2ind(size(emap),ps(:,1),ps(:,2),ps(:,3))) = 1;
                    hiso = patch(isosurface(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5); hold on;
                    hiso2 = patch(isocaps(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.5);       
                    nfield = nfield+1;
                    map = map+emap;
                end
            end
            if sum(emap(:))>0
                lighting phong;
                isonormals(map,hiso);
                camlight;
            end

            hold on
                edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
                ori = [min(lx2), min(ly2), min(lz2)]; 
                plotcube(edg,ori,0,0,0.3);
            axis off
            axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
            view(-240,22)
            daspect([1 1 1])
            camproj perspective
            rotate3d on  
        end        
        
%% convex hull with principal axes        
    ax_chull2 = axes('Units','pixels','Position',ax_chull.Position+[130 0 0 0]);       
        % plot overall position data outline
        fields = sdata.(uci).(part_now3).nfields;
        fddata = sdata.(uci).(part_now3).field_data;
        hold on
        
        nfield = 0;
        if ~fields<1
            cols = {'k','k','k','k'};
            map = zeros(size(dwellmap));
            fidx = fdata.tetrode==num2str(dir{2}) & fdata.cluster==num2str(dir{3}) & fdata.part==2;
            fdata2 = fdata(fidx,:);
            for ff = 1:fields % for every detected place field
                ps = fddata(ff).voxel_index;
                if fddata(ff).volume_voxels>fvol_thresh(1) & fddata(ff).field_visits>fv_thresh
                    emap = zeros(size(dwellmap));
                    emap(sub2ind(size(emap),ps(:,1),ps(:,2),ps(:,3))) = 1;
                    hiso = patch(isosurface(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.2); hold on;
                    hiso2 = patch(isocaps(emap,0),'FaceColor',cols{ff},'EdgeColor','none','FaceAlpha',.2);       
                    nfield = nfield+1;
                    map = map+emap;

                    ev = fddata(ff).eigenvectors;
                    pa = fddata(ff).principalaxes./2;
                    ce = fddata(ff).centroid;
                    daspect([1 1 1])
                    axis equal

                    farrow(ce(1),ce(2),ce(3), ev(2,1).*pa(1)+ce(1), ev(1,1).*pa(1)+ce(2), ev(3,1).*pa(1)+ce(3)); hold on;
                    farrow(ce(1),ce(2),ce(3), -ev(2,1).*pa(1)+ce(1), -ev(1,1).*pa(1)+ce(2),-ev(3,1).*pa(1)+ce(3));
          
                end
            end
            if sum(emap(:))>0
                lighting phong;
                isonormals(map,hiso);
                camlight;
            end

            hold on
            edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
            ori = [min(lx2), min(ly2), min(lz2)]; 
            plotcube(edg,ori,0,0,0.3);
            axis off
            axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
            view(-240,22)
            daspect([1 1 1])
            camproj perspective
            rotate3d on   
        end        
                
%% sphere with projected point        
    ax_sphere = axes('Units','pixels','Position',ax_chull2.Position+[150 10 -20 -20]);          
        [X,Y,Z,F1] = projectEIGS([ev([2 1 3],1)'; -ev([2 1 3],1)']);  
        mx = nanmax(F1(:));    
        F1m = (F1 ./ mx);
        s = surf(X,Y,Z,F1m);
        s.FaceAlpha = 0.4;
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0;
        
        hold on;
        ce = [0 0 0];
        pa = 1;
        farrow(ce(1),ce(2),ce(3), ev(2,1).*pa(1)+ce(1), ev(1,1).*pa(1)+ce(2), ev(3,1).*pa(1)+ce(3)); hold on;
        farrow(ce(1),ce(2),ce(3), -ev(2,1).*pa(1)+ce(1), -ev(1,1).*pa(1)+ce(2),-ev(3,1).*pa(1)+ce(3));
        
        axis on vis3d; 
        rotate3d on;
        view(-240,22)
        daspect([1 1 1]); 
        grid on
        axis tight off  
        colormap(gca,jet(256));
        caxis([0 nanmax(F1m(:))])        
    
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Spherical field orientation maps
%% Square
    ynow = 190;
    view_now = [30 22];
    ax_sph_sq = axes('Units','pixels','Position',[10 180 230 230]);       
        V = [fdata.field_eigenvector(pf_idx_sq1,[2 1 3]); -fdata.field_eigenvector(pf_idx_sq1,[2 1 3])];
        [X,Y,Z,F1] = projectEIGS(V,256);  
        mx = nanmax(F1(:));    
        F1m = (F1 ./ mx);
        s = surf(X,Y,Z,F1m);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        axis on vis3d; 
        rotate3d on;
        view(view_now);    
        daspect([1 1 1]); 
        grid on
        axis tight on       
        colormap(gca,jet(256));
        caxis([0 nanmax(F1m(:))])

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        l1 = normr([-970 0 0]); l2 = normr([970 0 0]); l3 = normr([0 970 0]); l4 = normr([0 -970 0]); l5 = normr([0 0 970]); l6 = normr([0 0 -970]); l7 = normr([0 660 466.69]); l8 = normr([0 -660 -466.69]); l9 = normr([571.6 -330 466.69]); l10 = normr([-571.6 330 -466.69]);  l11 = normr([-571.55 -330 466.69]); l12 = normr([571.55 330 -466.69]);           
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [0 0 0];
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off 

%% Aligned
    ax_sph_lt = axes('Units','pixels','Position',ax_sph_sq.Position+[170 0 0 0]); 
        V = [fdata.field_eigenvector(pf_idx_la1,[2 1 3]); -fdata.field_eigenvector(pf_idx_la1,[2 1 3])];
        [X,Y,Z,F2] = projectEIGS(V,256);  
        mx = nanmax(F2(:));    
        F2m = (F2 ./ mx);  

        s = surf(X,Y,Z,F2m);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        axis on vis3d; 
        rotate3d on;
        view(view_now);    
        daspect([1 1 1]); 
        grid on
        axis tight on       
        colormap(gca,jet(256));
        caxis([0 nanmax(F2m(:))])

        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [0 0 0];
        for ll = 1:6
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off 

%% Tilted
   ax_sph_di = axes('Units','pixels','Position',ax_sph_lt.Position+[200 30 -60 -60]);    
        V = [fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3]); -fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3])];
        XYZ = AxelRot(V',-35.265,[1 0 0],[]);
        V = AxelRot(XYZ,-45,[0 1 0],[])';    
        [X,Y,Z,F3] = projectEIGS(V,256);  
        mx = nanmax(F3(:));    
        F3m = (F3 ./ mx);         
        s = surf(X,Y,Z,F3m);
        s.EdgeColor = 'k';
        s.EdgeAlpha = 0.0;
        axis on vis3d; 
        rotate3d on;
        view([-60 22]);    
        daspect([1 1 1]); 
        grid on
        axis tight on       
        colormap(gca,jet(256));
        caxis([0 nanmax(F3m(:))])

        rz = rotz(-90);
        l1 = (rz*normr([-970 0 0])')';  l2 = (rz*normr([970 0 0])')';  l3 = (rz*normr([0 970 0])')';  l4 = (rz*normr([0 -970 0])')';  l5 = (rz*normr([0 0 970])')';  l6 = (rz*normr([0 0 -970])')';  l7 = (rz*normr([0 660 466.69])')';  l8 = (rz*normr([0 -660 -466.69])')';  l9 = (rz*normr([571.6 -330 466.69])')';  l10 = (rz*normr([-571.6 330 -466.69])')';  l11 = (rz*normr([-571.55 -330 466.69])')';  l12 = (rz*normr([571.55 330 -466.69])')';   
        adj = 1.4;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-','-','-','-','-','-','-'};        
        orig = [0 0 0];
        for ll = 7:12
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off 

%% colorbar for field spheres
    axc_sphere = axes('Units','pixels','Position',[ax_sph_di.Position(1)+170 ax_sph_di.Position(2)+20 10 100]);
        imagesc(((1:256)'));
        colormap(gca,'jet')
        axis xy off
        text(0.5,-0.08,'0','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Example single session spherical field orientation maps
%% Square example
% figure
% i = 1;
% ru = unique(fdata.rat(pf_idx_sq1));
% for rt = 1:length(ru)
%     rnow = ru(rt);
%     du = unique(fdata.date(pf_idx_sq1 & fdata.rat==rnow));
%     for dt = 1:length(du)
%         subplot(8,8,i)
%             idx = fdata.rat==ru(rt) & fdata.date==du(dt);            
%             V1n = [fdata.field_eigenvector(idx,[2 1 3]); -fdata.field_eigenvector(idx,[2 1 3])];
%             [X,Y,Z,F1] = projectEIGS(V1n,256);   
%             mx = nanmax(F1(:));    
%             F1 = (F1 ./ mx);
%             s = surf(X,Y,Z,F1);
%             s.EdgeColor = 'k';
%             s.EdgeAlpha = 0.0;
%             axis on vis3d; 
%             rotate3d on;
%             view(view_now);    
%             daspect([1 1 1]);  
%             colormap(gca,jet(256));
%             caxis([0 nanmax(F1(:))])
%             title(sprintf('rat: %d, date: %d',ru(rt),du(dt)));
%             i = i+1;
%     end
% end
% return

    ynow = 330;
    gsize = 120;
    x1 = ax_sph_sq.Position(1)+110;
    sfact = 1.5;
    ax_poss = [x1 ynow gsize gsize; x1+gsize/sfact ynow gsize gsize; x1 ynow-gsize/sfact gsize gsize; x1+gsize/sfact ynow-gsize/sfact gsize gsize];
    ratz1 = [926 926];
    datz1 = [10042018 11042018];
    for ii = 1:1
        ax_sph_now = axes('Units','pixels','Position',ax_poss(ii,:));   
%             idx = pf_idx_sq1 & fdata.rat==ratz1(ii) & fdata.date==datz1(ii);
            idx = fdata.rat==ratz1(ii) & fdata.date==datz1(ii);            
            V1n = [fdata.field_eigenvector(idx,[2 1 3]); -fdata.field_eigenvector(idx,[2 1 3])];
            [X,Y,Z,F1] = projectEIGS(V1n,256);  
            mx = nanmax(F1(:));    
            F1 = (F1 ./ mx);
            s = surf(X,Y,Z,F1);
            s.EdgeColor = 'k';
            s.EdgeAlpha = 0.0;
            axis on vis3d; 
            rotate3d on;
            view(view_now);    
            daspect([1 1 1]);  
            colormap(gca,jet(256));
            caxis([0 nanmax(F1(:))])

            adj = 1.4;
            lcol = 'k';
            lwid = 1;
            hold on;
            lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
            lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
            orig = [0 0 0];
            for ll = 1:6
                lnow = lins{ll};
                line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
            end
            axis tight off         
    end

%% aligned example
    gsize = 120;
    x1 = ax_sph_lt.Position(1)+110;
    sfact = 1.5;
    ax_poss = [x1 ynow gsize gsize; x1+gsize/sfact ynow gsize gsize; x1 ynow-gsize/sfact gsize gsize; x1+gsize/sfact ynow-gsize/sfact gsize gsize];
    ratz2 = [896 852 775 894];
    datz2 = [16012018 27032017];
    for ii = 1:1
        ax_sph_now = axes('Units','pixels','Position',ax_poss(ii,:));    
            idx = fdata.rat==ratz2(ii) & fdata.date==datz2(ii);            
            V2n = [fdata.field_eigenvector(idx,[2 1 3]); -fdata.field_eigenvector(idx,[2 1 3])];
            [X,Y,Z,F1] = projectEIGS(V2n,256);  
            mx = nanmax(F1(:));    
            F1 = (F1 ./ mx);
            s = surf(X,Y,Z,F1);
            s.EdgeColor = 'k';
            s.EdgeAlpha = 0.0;
            axis on vis3d; 
            rotate3d on;
            view(view_now);    
            daspect([1 1 1]);  
            colormap(gca,jet(256));
            caxis([0 nanmax(F1(:))])

            adj = 1.4;
            lcol = 'k';
            lwid = 1;
            hold on;
            lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
            lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
            orig = [0 0 0];
            for ll = 1:6
                lnow = lins{ll};
                line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
            end
            axis tight off         
    end

%% tilted example
%     figure
%     i = 1;
%     ru = unique(fdata.rat(pf_idx_la2));
%     for rt = 1:length(ru)
%         rnow = ru(rt);
%         du = unique(fdata.date(pf_idx_la2 & fdata.rat==rnow));
%         for dt = 1:length(du)
%             subplot(7,7,i)
%                 idx = fdata.rat==ru(rt) & fdata.date==du(dt);            
%                 vnow = [fdata.field_diagonal_eigenvector(idx,[2 1 3]); -fdata.field_diagonal_eigenvector(idx,[2 1 3])];
%                 XYZ = AxelRot(vnow',-35.265,[1 0 0],[]);
%                 vnow = AxelRot(XYZ,-45,[0 1 0],[])';  
%                 [X,Y,Z,F1] = projectEIGS(vnow,256);  
%                 mx = nanmax(F1(:));    
%                 F1 = (F1 ./ mx);
%                 s = surf(X,Y,Z,F1);
%                 s.EdgeColor = 'k';
%                 s.EdgeAlpha = 0.0;
%                 axis on vis3d; 
%                 rotate3d on;
%                 view(view_now);    
%                 daspect([1 1 1]);  
%                 colormap(gca,jet(256));
%                 caxis([0 nanmax(F1(:))])
%                 title(sprintf('rat: %d, date: %d',ru(rt),du(dt)));
%                 i = i+1;
%         end
%     end
%     return

    gsize = 90;
    x1 = ax_sph_di.Position(1)+105;
    sfact = 1.5;
    ax_poss = [x1 ynow+15 gsize gsize; x1+gsize/sfact ynow gsize gsize; x1 ynow-gsize/sfact gsize gsize; x1+gsize/sfact ynow-gsize/sfact gsize gsize];
    ratz3 = [926 951];
    datz3 = [13042018 20092018];
    for ii = 1:1
        ax_sph_now = axes('Units','pixels','Position',ax_poss(ii,:));    
%             idx = pf_idx_la2 & fdata.rat==ratz3(ii) & fdata.date==datz3(ii);
            idx = fdata.rat==ratz3(ii) & fdata.date==datz3(ii);            
            V3n = [fdata.field_diagonal_eigenvector(idx,[2 1 3]); -fdata.field_diagonal_eigenvector(idx,[2 1 3])];
            XYZ = AxelRot(V3n',-35.265,[1 0 0],[]);
            V3n = AxelRot(XYZ,-45,[0 1 0],[])';    
            [X,Y,Z,F1] = projectEIGS(V3n,256);  
            mx = nanmax(F1(:));    
            F1 = (F1 ./ mx);         
            s = surf(X,Y,Z,F1);
            s.EdgeColor = 'k';
            s.EdgeAlpha = 0.0;
            axis on vis3d; 
            rotate3d on;
            view([-60 22]);    
            daspect([1 1 1]);  
            colormap(gca,jet(256));
            caxis([0 nanmax(F1(:))])

            adj = 1.4;
            lcol = 'k';
            lwid = 1;
            hold on;
            lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
            lsty = {'-','-','-','-','-','-','-','-','-','-','-','-'};        
            orig = [0 0 0];
            for ll = 7:12
                lnow = lins{ll};
                line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
            end
            axis tight off         
    end

%% ##################################### %% Field counts per axis
    ynow = 50;
    [prc,arc,pr,ar_shuff,cr,idcs] = sphereCHANCE(1000,1000);
    prcs = prc([3 4 5]);

%% #################### %% arena stem graph
    % field proportions, stem graph
    ax_sq1_stem = axes('Units','pixels','Position',[ax_sph_sq.Position(1)+50 ynow 140 100]); 
        V = [fdata.field_eigenvector(pf_idx_sq1,[2 1 3]); -fdata.field_eigenvector(pf_idx_sq1,[2 1 3])];
        [~,~,axcount,~,cr,id] = sphereCHANCE([],[],V);

%         figure
%         idx_now = pf_idx_sq1;
%         rrs = unique(fdata.rat(idx_now,:));
%         acounts = [];
%         marks = {'s','o','+','*','.','^','V','p','x','s','o','+','*','.','^','V','p','x'};
%         cols = {'b','r','g','k','c','m','b','r','g','k','c','m','b','r','g','k','c'};
%         for rr = 1:length(rrs)
%             dds = unique(fdata.date(idx_now & fdata.rat==rrs(rr)));
%             for dd = 1:length(dds)
%                 idx = idx_now & fdata.rat==rrs(rr) & fdata.date==dds(dd);
% 
%                 V = [fdata.field_eigenvector(idx,[2 1 3]); -fdata.field_eigenvector(idx,[2 1 3])];
%                 [~,~,axcount,~,cr,id] = sphereCHANCE([],[],V);    
%                 acounts = [acounts;axcount];
% 
%                 plot((1:6)+normrnd(0,0.07,[1 6]),axcount,[cols{rr} marks{rr}],'MarkerSize',10); hold on;
%             end
%         end
% 
%         hold on
%         boxplot(acounts,'symbol','w');
%         box off
%         ax = gca;
%         ax.XTickLabel = {'X','Y','Z','A','B','C'};    
%         ax.XLim = [0.5 6.5];
%         ax.YLim = [0 1];
%         ylabel('Proportion of fields')

        % build confidence intervals
        shuff = 1000;
        v1 = fdata.field_eigenvector(pf_idx_sq1,[2 1 3]);
        shuff_ax = NaN(shuff,length(axcount));
        for ss = 1:shuff
            idx = randi(size(v1,1),1,size(v1,1));
            fnow = [v1(idx,:);-v1(idx,:)];
            [~,~,axnow,~,~] = sphereCHANCE([],[],fnow);        
            shuff_ax(ss,:) = axnow;
        end        

        prshuff = prctile(shuff_ax,[2.5 97.5],1);
        cols = {colx,coly,colz,cola,colb,colc};        
        for i = 1:6       
            errorbar(i,axcount(i),axcount(i)-prshuff(1,i),axcount(i)-prshuff(2,i),'LineStyle','none','Color',cols{i}); hold on;
            plot(i,axcount(i),'Color',cols{i},'Marker','o')  
        end  
        
        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'X' 'Y' 'Z' 'A' 'B' 'C'};    
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .4];
        ax.YTick = [0 0.2 0.4];
        ax = gca;

        x = 0.5:0.5:6.5;
        y = repmat(prcs(2),length(x),1);
        b = [repmat(prcs(2)-prcs(1),length(x),1) repmat(prcs(3)-prcs(2),length(x),1)];
        boundedline(x,y,b,'r','alpha')   
        ylabel('Proportion of fields')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 
        text(0.7,0.44,sprintf('N = %d',size(V,1)/2),'FontSize',fsiz,'Units','normalized')
        disp(sprintf('Axis counts arena: %s, total fields: %d',mat2str(cr),sum(cr(:))))
   
            ds = [];
            gs = [];
            axidx = [1 1 2 2 3 3 4 4 5 5 6 6];
            for ii = 1:12
                idnow = id{ii};
                idnow = idnow(1:length(idnow)/2);
                findx = find(pf_idx_sq1);
                findx = findx(idnow);
                new_idx = false(size(pf_idx_sq1));
                new_idx(findx) = true;
                ds = [ds; fdata.field_principalaxes(new_idx,1)];
                gs = [gs; ones(size(fdata.field_principalaxes(new_idx,1))).*axidx(ii)];
            end
            [p,a,sts] = kruskalwallis(ds(gs<3),gs(gs<3),'off');
            [c,m,h,~] = multcompare(sts,'display','off','ctype','bonferroni');
            disp(sprintf('\tArena X,Y field lengths'))
            disp(sprintf('\tKruskalwallis: X2(%d) = %.1f, p = %.5f, eta = %.5f, post: %s     ',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(ds)),mat2str(c(:,end))))
            disp(sprintf('Medians: %.3f, %.3f',nanmedian(ds(gs==1))*5,nanmedian(ds(gs==2))*5))

%% arena inset distribution probability, correlations
    ax_sq1_density = axes('Units','pixels','Position',[ax_sph_sq.Position(1)+130 ynow+90 70 50]); 
        psR = prctile(ar_shuff(:),[0.5 50 99.5]);
        aro = sum(axcount(:,1:3),2)./sum(axcount(:,4:6),2); % observed axis ratio

        xi = 0:0.1:5;
        bw = 0.1;
        [~,~,~,f] = histDENSITY(ar_shuff(:),xi,bw);
        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 0.4];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        [~,~,axcount,~,~] = sphereCHANCE([],[],V1n);
        ars = sum(axcount(:,1:3),2)./sum(axcount(:,4:6),2); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');
        
        box off
        ax = gca;
        ax.XTick = 0:1:7;   
        ax.XLim = [0 7];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
        [~,o] = legendflex([a1,l1 l2 l3], {'shuffle','shuffle 99%',sprintf('animal average'),sprintf('single session')}, 'ref', gca, 'xscale', 0.4, 'anchor', [3 8], 'buffer', [-8 -10], 'box', 'off');
        
%% #################### %% aligned main stem graph  
    % field proportions, stem graph
    ax_la1_stem = axes('Units','pixels','Position',[ax_sph_lt.Position(1)+50 ynow 140 100]);    
        V = [fdata.field_eigenvector(pf_idx_la1,[2 1 3]); -fdata.field_eigenvector(pf_idx_la1,[2 1 3])]; 
        [prc,arc,axcount,ar,cr,id] = sphereCHANCE([],[],V);
        
        % build confidence intervals
        shuff = 1000;
        v1 = fdata.field_eigenvector(pf_idx_la1,[2 1 3]);
        shuff_ax = NaN(shuff,length(axcount));
        for ss = 1:shuff
            idx = randi(size(v1,1),1,size(v1,1));
            fnow = [v1(idx,:);-v1(idx,:)];
            [~,~,axnow,~,~] = sphereCHANCE([],[],fnow);        
            shuff_ax(ss,:) = axnow;
        end        

        prshuff = prctile(shuff_ax,[2.5 97.5],1);
        cols = {colx,coly,colz,cola,colb,colc};        
        for i = 1:6       
            errorbar(i,axcount(i),axcount(i)-prshuff(1,i),axcount(i)-prshuff(2,i),'LineStyle','none','Color',cols{i}); hold on;
            plot(i,axcount(i),'Color',cols{i},'Marker','o')  
        end

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'X' 'Y' 'Z' 'A' 'B' 'C'};    
        ax.YTick = [];
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .4];
        ax = gca;

        x = 0.5:0.5:6.5;
        y = repmat(prcs(2),length(x),1);
        b = [repmat(prcs(2)-prcs(1),length(x),1) repmat(prcs(3)-prcs(2),length(x),1)];
        boundedline(x,y,b,'r','alpha')   
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
        xlabel('Maze axis')
        text(0.7,0.44,sprintf('N = %d',size(V,1)/2),'FontSize',fsiz,'Units','normalized')
        disp(sprintf('Axis counts aligned: %s, total fields: %d',mat2str(cr),sum(cr(:))))        

            ds = [];
            gs = [];
            axidx = [1 1 2 2 3 3 4 4 5 5 6 6];
            for ii = 1:12
                idnow = id{ii};
                idnow = idnow(1:length(idnow)/2);
                findx = find(pf_idx_la1);
                findx = findx(idnow);
                new_idx = false(size(pf_idx_la1));
                new_idx(findx) = true;
                ds = [ds; fdata.field_principalaxes(new_idx,1)];
                gs = [gs; ones(size(fdata.field_principalaxes(new_idx,1))).*axidx(ii)];
            end
            [p,a,sts] = kruskalwallis(ds(gs<4),gs(gs<4),'off');
            [c,m,h,~] = multcompare(sts,'display','off','ctype','bonferroni');
            disp(sprintf('\tAligned X,Y,Z field lengths'))
            disp(sprintf('\tKruskalwallis: X2(%d) = %.1f, p = %.5f, eta = %.5f, post: %s     ',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(ds)),mat2str(c(:,end))))        
            disp(sprintf('Medians: %.3f, %.3f, %.3f',nanmedian(ds(gs==1))*5,nanmedian(ds(gs==2))*5,nanmedian(ds(gs==3))*5))
        
%% aligned inset distribution probability, correlations        
    ax_la1_density = axes('Units','pixels','Position',[ax_sph_lt.Position(1)+140 ynow+90 70 50]);      
        psR = prctile(ar_shuff(:),[0.5 50 99.5]);
        aro = sum(axcount(:,1:3),2)./sum(axcount(:,4:6),2); % observed axis ratio

        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 max(f(:))];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        [~,~,axcount,~,~] = sphereCHANCE([],[],V2n);
        ars = sum(axcount(:,1:3),2)./sum(axcount(:,4:6),2); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');
        
        box off
        ax = gca;
        ax.XTick = 0:1:5;   
        ax.XLim = [0 3];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 

%% #################### %% tilted main stem graph
    % field proportions
    ax_la2_stem = axes('Units','pixels','Position',[ax_sph_di.Position(1)+20 ynow 140 100]);     
        V = [fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3]); -fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3])];
        [prc,arc,axcount,ar,cr] = sphereCHANCE([],[],V);
        axcount = axcount([4 5 6 1 2 3]);

        % build confidence intervals
        shuff = 1000;
        v1 = fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3]);
        shuff_ax = NaN(shuff,length(axcount));
        for ss = 1:shuff
            idx = randi(size(v1,1),1,size(v1,1));
            fnow = [v1(idx,:);-v1(idx,:)];
            [~,~,axnow,~,~] = sphereCHANCE([],[],fnow);        
            shuff_ax(ss,:) = axnow([4 5 6 1 2 3]);
        end        

        prshuff = prctile(shuff_ax,[2.5 97.5],1);
        cols = {colx,coly,colz,cola,colb,colc};     
        for i = 1:6       
            errorbar(i,axcount(i),axcount(i)-prshuff(1,i),axcount(i)-prshuff(2,i),'LineStyle','none','Color',cols{i}); hold on;
            plot(i,axcount(i),'Color',cols{i},'Marker','o')  
        end

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'X' 'Y' 'Z' 'A' 'B' 'C'};    
        ax.YTick = [];
        ax.XLim = [0.5 6.5];
        ax.YLim = [0 .4];
        ax = gca;

        x = 0.5:0.5:6.5;
        y = repmat(prcs(2),length(x),1);
        b = [repmat(prcs(2)-prcs(1),length(x),1) repmat(prcs(3)-prcs(2),length(x),1)];
        boundedline(x,y,b,'r','alpha')   
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 

        text(1.02,0.32,sprintf('Chance'),'FontSize',fsiz,'Units','normalized','HorizontalAlignment','left','Color','r');
        text(0.05,0.44,sprintf('N = %d',size(V,1)/2),'FontSize',fsiz,'Units','normalized')
        disp(sprintf('Axis counts tilted: %s, total fields: %d',mat2str(cr),sum(cr(:))))
        
            ds = [];
            gs = [];
            axidx = [1 1 2 2 3 3 4 4 5 5 6 6];
            for ii = 1:12
                idnow = id{ii};
                idnow = idnow(1:length(idnow)/2);
                findx = find(pf_idx_la1);
                findx = findx(idnow);
                new_idx = false(size(pf_idx_la1));
                new_idx(findx) = true;
                ds = [ds; fdata.field_principalaxes(new_idx,1)];
                gs = [gs; ones(size(fdata.field_principalaxes(new_idx,1))).*axidx(ii)];
            end
            [p,a,sts] = kruskalwallis(ds(gs>3),gs(gs>3),'off');
            [c,m,h,~] = multcompare(sts,'display','off','ctype','bonferroni');
            disp(sprintf('\tAligned A,B,C field lengths'))
            disp(sprintf('\tKruskalwallis: X2(%d) = %.1f, p = %.5f, eta = %.5f, post: %s     ',a{2,3},a{2,5},p,a{2,5}/sum(~isnan(ds)),mat2str(c(:,end))))        
            disp(sprintf('Medians: %.3f, %.3f, %.3f',nanmedian(ds(gs==4))*5,nanmedian(ds(gs==5))*5,nanmedian(ds(gs==6))*5))
                
%% tilted inset distribution probability, correlations                
    ax_la2_density = axes('Units','pixels','Position',[ax_sph_di.Position(1)+100 ynow+90 70 50]);      
        psR = prctile(ar_shuff(:),[0.5 50 99.5]);
        aro = sum(axcount(:,1:3),2)./sum(axcount(:,4:6),2); % observed axis ratio

        area(xi,f,'FaceColor','k','FaceAlpha',0.2); hold on;
        a1 = patch([-1 -1],[-1 -1],'k','FaceColor',[.75 .75 .75]);
        ax = gca;
        y1 = [0 max(f(:))];
        ax.YLim = y1;
        l1 = line([psR(1) psR(1)],ax.YLim,'Color','r');        
        l1 = line([psR(3) psR(3)],ax.YLim,'Color','r');
        l2 = line([aro aro],ax.YLim,'Color','b');

        [~,~,axcount,~,~] = sphereCHANCE([],[],V3n);
        ars = sum(axcount(:,4:6),2)./sum(axcount(:,1:3),2); % observed axis ratio
        l3 = line([ars ars],ax.YLim,'Color','b','LineStyle',':');
        
        box off
        ax = gca;
        ax.XTick = 0:.5:2;   
        ax.XLim = [0 2];
        xlabel(sprintf('XYZ / ABC'))
        ylabel(sprintf('Probability'))        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',6,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places 
             
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    











