%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIG8_spatial_info_field_extents small function to make Fig. 8
% Figure 8 contains autocorrelation and spatial information results and field extent heatplot
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,671,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 885, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[270, 885, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[435, 885, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 680, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none');     

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% all plots  
%% ##################################### %% autocorrelation means
%% aligned
    ynow = 750;
    ax_C1 = axes('Units','pixels','Position',[50 ynow 90 110]);        
        cinfo = cell2mat(tdata.dsamps_autovecs_obs(pc_idx_la1));
        cinfox = cinfo(1:3:end,:);
        cinfoy = cinfo(2:3:end,:);
        cinfoz = cinfo(3:3:end,:);
        
        xm = nanmean(cinfox,1);
        xs = nanstd(cinfox,[],1) ./ sqrt(sum(~isnan(cinfox),1));
        ym = nanmean(cinfoy,1);
        ys = nanstd(cinfoy,[],1) ./ sqrt(sum(~isnan(cinfoy),1));        
        zm = nanmean(cinfoz,1);
        zs = nanstd(cinfoz,[],1) ./ sqrt(sum(~isnan(cinfoz),1));        
        xi = (-30:30).*5;
        
        e1 = errorbar(xi,xm,xs,'Color',colx); hold on;
        e2 = errorbar(xi,ym,ys,'Color',coly);         
        e3 = errorbar(xi,zm,zs,'Color',colz);         
        
        ax = gca;
        ax.XLim = [0 100];
        ax.YLim = [0 0.8];
        yy = ylabel('Correlation');   
        xlabel('Distance (cm)')      
        box off
        ax.YGrid = 'on';        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places                

        ll = legend([e1,e2,e3],'X','Y','Z');
        legend boxoff
        pos = get(ll,'Position');
        set(ll,'Position',pos+[0 0 0 0]);  

%% tiled lattice data
    ax_C2 = axes('Units','pixels','Position',ax_C1.Position + [110 0 0 0]);  
        cinfo = cell2mat(tdata.dsamps_autovecs_dia(pc_idx_la2));
        cinfox = cinfo(1:3:end,:);
        cinfoy = cinfo(2:3:end,:);
        cinfoz = cinfo(3:3:end,:);
        
        xm = nanmean(cinfox,1);
        xs = nanstd(cinfox,[],1) ./ sqrt(sum(~isnan(cinfox),1));
        ym = nanmean(cinfoy,1);
        ys = nanstd(cinfoy,[],1) ./ sqrt(sum(~isnan(cinfoy),1));        
        zm = nanmean(cinfoz,1);
        zs = nanstd(cinfoz,[],1) ./ sqrt(sum(~isnan(cinfoz),1));        
        xi = (-30:30).*5;
        
        e1 = errorbar(xi,xm,xs,'Color',cola); hold on;
        e2 = errorbar(xi,ym,ys,'Color',colb);         
        e3 = errorbar(xi,zm,zs,'Color',colc);         
        
        ax = gca;
        ax.XLim = [0 100];
        ax.YLim = [0 0.8];
        ax.YTickLabel = {};
        ylimn = ax.YLim;
        xlabel('Distance (cm)')      
        box off
        ax.YGrid = 'on';        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

        ll = legend([e1,e2,e3],'A','B','C');
        legend boxoff
        pos = get(ll,'Position');
        set(ll,'Position',pos+[0 0 0 0]);         

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% spatial information content
%% aligned
    ax_SI1 = axes('Units','pixels','Position',[310 ynow 60 110]);   
        sinfo = tdata.dsamps_spatinfo_obs(pc_idx_la1,:);
        sinfo(~any(sinfo,2),:) = [];
        sinfo = sinfo ./ nansum(sinfo,2);

        [ds,gs] = vectorDATAGROUP([],sinfo(:,3),sinfo(:,2),sinfo(:,1));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'XY' 'XZ' 'YZ'};  
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 0.8];
        y1 = ax.YLim;
        yy = ylabel('Proportion of SI');
        xx = xlabel(m2name);        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places   
            disp('Aligned spatial info XYZ:')
            stats_and_bars(ds,gs,[],flnw,fsiz)
            ax.YLim = y1;

%% Tilted            
    ax_SI3 = axes('Units','pixels','Position',ax_SI1.Position + [70 0 0 0]);   
        sinfo = tdata.dsamps_spatinfo_dia(pc_idx_la2,:);
        sinfo(~any(sinfo,2),:) = [];
        sinfo = sinfo ./ nansum(sinfo,2);

        [ds,gs] = vectorDATAGROUP([],sinfo(:,3),sinfo(:,2),sinfo(:,1));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'AB' 'AC' 'BC'};  
        ax.XLim = [0.5 3.5];
        ax.YLim = y1;
        xx = xlabel(m3name);        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places   
            disp('Tilted spatial info ABC:')        
            stats_and_bars(ds,gs,[],flnw,fsiz)
            ax.YLim = y1;

%% ##################################### %% field area under curve (AUC)
%% aligned
    ax_SD1 = axes('Units','pixels','Position',[490 ynow 60 110]); 
        index_now = pf_idx_la1;
        idx = find(index_now);   
        xsums = NaN(length(idx),1);
        ysums = NaN(length(idx),1);
        zsums = NaN(length(idx),1);
        for ff = 1:length(idx)
            fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_valsX(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            xsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));

            fd_frex = fdata.field_valsY(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            ysums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                              

            fd_frex = fdata.field_valsZ(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            zsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                               
        end          
    
        [ds,gs] = vectorDATAGROUP([],xsums,ysums,zsums);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);
        
        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'X','Y','Z'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 25];
        y1 = ax.YLim;
        xlabel(m2name)
        ylabel('AUC (rate x distance)')        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % significance bridges
            disp('Lattice AUCs:')
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;
            
%% tilted         
    ax_SD2 = axes('Units','pixels','Position',ax_SD1.Position + [70 0 0 0]); 
        index_now = pf_idx_la2;
        idx = find(index_now);   
        xsums = NaN(length(idx),1);
        ysums = NaN(length(idx),1);
        zsums = NaN(length(idx),1);    
        asums = NaN(length(idx),1);
        bsums = NaN(length(idx),1);
        csums = NaN(length(idx),1);             
        for ff = 1:length(idx)
            fd_pos = fdata.field_diagonal_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_diagonal_valsA(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            asums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                

            fd_frex = fdata.field_diagonal_valsB(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            bsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                              

            fd_frex = fdata.field_diagonal_valsC(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            csums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                   

            fd_frex = fdata.field_valsX(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            xsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));   

            fd_frex = fdata.field_valsY(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            ysums(ff,1) = trapz(fd_frex(~isnan(fd_frex))); 

            fd_frex = fdata.field_valsZ(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            zsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                                
        end                      
            
        [ds,gs] = vectorDATAGROUP([],asums,bsums,csums);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'A','B','C'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        xlabel(m3name)
        ylabel('AUC (rate x distance)')        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % significance bridges
            ax.YLim = y1;
            disp('Diagonal AUCs ABC:')
            stats_and_bars(ds,gs,[],flnw,fsiz);  
            ax.YLim = y1;

%% ##################################### %% field size along each dimension, aligned XYZ
%% aligned X
    ynow = 610;            
    ax_Bx = axes('Units','pixels','Position',[50 ynow 180 50]); 
        index_now = pf_idx_la1;
        idx = find(index_now);                
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,2),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
            fd_box = fdata.field_bounding_box(idx(ff),4);        
            fd_frex = fdata.field_valsX(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - (fd_pos(1))) .* 5 + (fd_cnt(2))) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(2) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end 
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        xlabel('Place field')
        ylabel('X (cm)')
        title(m2name,'FontWeight','normal','FontSize',fsiz)
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = [0 200];
        y1 = ax.YLim;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% aligned Y      
    ax_By = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_Bx.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la1;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,1),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
            fd_box = fdata.field_bounding_box(idx(ff),5);                
            fd_frex = fdata.field_valsY(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - (fd_pos(2))) .* 5 + (fd_cnt(1))) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(1) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        %xlabel('Place field')
        ylabel('Y (cm)')
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = y1;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% aligned Z 
    ax_Bz = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_By.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la1;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,3),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),:);
            fd_pos = fdata.field_centroid(idx(ff),:);
            fd_box = fdata.field_bounding_box(idx(ff),6);
            fd_frex = fdata.field_valsZ(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = ((1:length(fd_frex)) - fd_pos(3)) .* 5 + fd_cnt(3) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(3) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end  
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        xlabel('Place field')
        ylabel('Z (cm)')
        hold on
        ax.YAxis.FontSize = 6;   
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = y1;
        ax.XTick = [10 200 400 572];
        ax.XTickLabel = {'0' '200' '400' '600'};

        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
            
%% ##################################### %% field size along each dimension, tilted XYZ
%% tilted X
    ax_Bx = axes('Units','pixels','Position',[235 ynow 180 50]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,2),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
            fd_box = fdata.field_bounding_box(idx(ff),4);        
            fd_frex = fdata.field_valsX(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - (fd_pos(1))) .* 5 + (fd_cnt(2))) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(2) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end 
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        %xlabel('Place field')
        %ylabel('X (cm)')
        title(m3name,'FontWeight','normal','FontSize',fsiz)        
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [];
        ax.YLim = [0 200];
        y1 = ax.YLim;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% tilted Y        
    ax_By = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_Bx.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,1),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
            fd_box = fdata.field_bounding_box(idx(ff),5);                
            fd_frex = fdata.field_valsY(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - (fd_pos(2))) .* 5 + (fd_cnt(1))) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(1) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [];
        ax.YLim = y1;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

% tilted Z        
    ax_Bz = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_By.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_lattice_centroid(index_now,3),'ascend');
        idx = idx(idx2);   

        dat = [];
        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_lattice_centroid(idx(ff),:);
            fd_pos = fdata.field_centroid(idx(ff),:);
            fd_box = fdata.field_bounding_box(idx(ff),6);
            fd_frex = fdata.field_valsZ(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = ((1:length(fd_frex)) - fd_pos(3)) .* 5 + fd_cnt(3) + 100;
            vd = interp1(yd,fd_frex,1:200,'nearest');
            fmap(:,ff) = vd;

            dat = [dat; fdata.uci(idx(ff),1) fdata.rat(idx(ff),1) fdata.date(idx(ff),1) fdata.tetrode(idx(ff),1) fdata.cluster(idx(ff),1) fdata.field(idx(ff),1) fd_cnt(3) find(~isnan(vd),1,'first')-100 fd_box find(~isnan(vd),1,'last')-100 NaN];
            dat(end,end) = diff([dat(end,8) dat(end,10)])./5;
        end  
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        xlabel('Place field')
        %ylabel('Z (cm)')
        ax.XTick = [10 100 200 300 375];
        ax.XTickLabel = {'0' '100' '200' '300' '400'};         
        hold on
        ax.YAxis.FontSize = 6;   
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.YTick = [];
        ax.YLim = y1;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% ##################################### %% field size along each dimension, tilted ABC
%% tilted A
    ax_Bx = axes('Units','pixels','Position',[455 ynow 180 50]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_diagonal_lattice_centroid(index_now,2),'ascend');
        idx = idx(idx2);   

        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_diagonal_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_diagonal_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_diagonal_valsA(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - round(fd_pos(1))) .* 5 + round(fd_cnt(2))) + 100;
            vd = interp1(yd,fd_frex,1:200);
            fmap(:,ff) = vd;
        end
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        %xlabel('Place field')
        ylabel('A (cm)')
        title(m3name,'FontWeight','normal','FontSize',fsiz)                
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = [0 200];
        y1 = ax.YLim;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% tilted B        
    ax_By = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_Bx.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_diagonal_lattice_centroid(index_now,1),'ascend');
        idx = idx(idx2);   

        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_diagonal_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_diagonal_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_diagonal_valsB(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - round(fd_pos(2))) .* 5 + round(fd_cnt(1))) + 100;
            vd = interp1(yd,fd_frex,1:200);
            fmap(:,ff) = vd;
        end
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        %xlabel('Place field')
        ylabel('B (cm)')
        hold on
        ax.YAxis.FontSize = 6;                                            
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.XTick = [];
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = y1;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% tilted C        
    ax_Bz = axes('Units','pixels','Position',[ax_Bx.Position(1) ax_By.Position(2)-55 ax_Bx.Position(3) ax_Bx.Position(4)]); 
        index_now = pf_idx_la2;
        idx = find(index_now);                                    
        [~,idx2] = sort(fdata.field_diagonal_lattice_centroid(index_now,3),'ascend');
        idx = idx(idx2);   

        fmap = NaN(200,length(idx));
        for ff = 1:length(idx)
            fd_cnt = fdata.field_diagonal_lattice_centroid(idx(ff),[1 2 3]);
            fd_pos = fdata.field_diagonal_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_diagonal_valsC(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - round(fd_pos(3))) .* 5 + round(fd_cnt(3))) + 100;
            vd = interp1(yd,fd_frex,1:200);
            fmap(:,ff) = vd;
        end
        nindx = isnan(fmap);
        fmap(nindx) = 0;
        fmap = imgaussfilt(fmap,10);
        fmap(nindx) = NaN;
        im = imagesc(fmap);
        set(im,'alphadata',~isnan(fmap));
        axis xy tight

        ax = gca;
        xlabel('Place field')
        ax.XTick = [10 100 200 300 375];
        ax.XTickLabel = {'0' '100' '200' '300' '400'};          
        ylabel('C (cm)')
        hold on
        ax.YAxis.FontSize = 6;   
        line(ax.XLim,[50 50],'Color',[.5 .5 .5 .5])
        line(ax.XLim,[150 150],'Color',[.5 .5 .5 .5])
        ax.YTick = [50 100 150];
        ax.YTickLabel = {'-50' '0' '50'};
        ax.YLim = y1;
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
    
%% colorbar for field extents        
    axc = axes('Units','pixels','Position',get(ax_By,'Position')+[190 0 -172 20]);
        imagesc(((1:256)'));
        colormap(axc,'jet')
        axis xy off
        text(0.5,-0.08,'0','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
            
            
            
            
            
            
            
            
            
   


