%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS14_relation_between_mazes small function to make Fig. S14
% Figure S14 shows several comparisons between mazes, to see if cells keep the same properties
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,842]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[10, 810, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[10, 615, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[320, 615, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[10, 420, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[340, 410, 300, 20],'string','e','FontSize',18,'LineStyle','none','interpreter','none'); 

%% ##################################### Elongation of fields in arena vs aligned or tilted
%% firing rate
    ax_frates = axes('Units','pixels','Position',[60 680 140 120]); 
        fr1 = tdata.firing_rate_Hz(pc_idx_sq1);
        fr2 = tdata.firing_rate_Hz(pc_idx_la1);
        fr3 = tdata.firing_rate_Hz(pc_idx_la2);

        [ds,gs] = vectorDATAGROUP([],fr1(:),fr2(:),fr3(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Arena','Aligned','Tilted'};    
        ax.XLim = [0.5 3.5];
        ax.XTickLabelRotation = 30;

        y1 = ax.YLim;
        ylabel('Firing rate (Hz)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places    
        
        disp('Firing rates:')
        stats_and_bars(ds,gs,[],flnw,fsiz);

%% spatial information        
    ax_spati = axes('Units','pixels','Position',ax_frates.Position+[180 0 0 0]); 
        fr1 = tdata.spatial_information(pc_idx_sq1);
        fr2 = tdata.spatial_information(pc_idx_la1);
        fr3 = tdata.spatial_information(pc_idx_la2);

        [ds,gs] = vectorDATAGROUP([],fr1(:),fr2(:),fr3(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Arena','Aligned','Tilted'};    
        ax.XLim = [0.5 3.5];
        ax.XTickLabelRotation = 30;

        y1 = ax.YLim;
        ylabel('Spatial information (b/s)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places    
        
        disp('Spatial info:')
        stats_and_bars(ds,gs,[],flnw,fsiz);
        
%% sparsity        
    ax_spars = axes('Units','pixels','Position',ax_spati.Position+[180 0 0 0]); 
        fr1 = tdata.sparsity(pc_idx_sq1);
        fr2 = tdata.sparsity(pc_idx_la1);
        fr3 = tdata.sparsity(pc_idx_la2);

        [ds,gs] = vectorDATAGROUP([],fr1(:),fr2(:),fr3(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Arena','Aligned','Tilted'};    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 1];
        ax.YTick = [0 .5 1];
        ax.YTickLabel = {'0.0','0.5','1.0'};
        ax.XTickLabelRotation = 30;

        y1 = ax.YLim;
        ylabel('Sparsity');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        
        disp('Sparsity:')
        stats_and_bars(ds,gs,[],flnw,fsiz);        

%% ##################################### Elongation of fields in arena vs aligned or tilted
%% arena vs aligned
    ax_elong1 = axes('Units','pixels','Position',[60 470 120 120]); 
        cindx = pc_idx_la1;
        cell_names = tdata.uci(cindx);
        elongs = NaN(length(fdata.uci),2);
        for cc = 1:length(cell_names)
            fidx_sq1 = fdata.uci==cell_names(cc) & pf_idx_sq1;
            fidx_la1 = fdata.uci==cell_names(cc) & pf_idx_la1;
            
            eidx1 = fdata.field_principalaxes(fidx_sq1,1) ./ nanmean(fdata.field_principalaxes(fidx_sq1,[2 3]),2);
            eidx2 = fdata.field_principalaxes(fidx_la1,1) ./ nanmean(fdata.field_principalaxes(fidx_la1,[2 3]),2);
            
            elongs(cc,:) = [mean(eidx1(:)) mean(eidx2(:))];
        end
        scatter(elongs(:,1),elongs(:,2),25,'k','MarkerFaceAlpha',.3,'MarkerFaceColor','k','MarkerEdgeColor','none'); hold on;
        daspect([1 1 1]);
        xlabel('Aligned elongation')
        ylabel('Arena elongation')
        ax = gca;
        ax.XLim = [1 6];
        ax.YLim = [1 6];
        ax.XTick = 1:6;        
        grid on
        r2 = refline(1,0);
        r2.Color = 'r';
        r2.LineStyle = '--';
        r2 = refline;
        r2.Color = 'b';
        r2.LineStyle = '-';
        
        [r,p] = corr(elongs(:,1),elongs(:,2),'type','Pearson','rows','pairwise');
        disp(sprintf('Arena vs Aligned elongation: r = %.13f, p = %.4f',r,p));

%% arena vs tilted        
    ax_elong2 = axes('Units','pixels','Position',ax_elong1.Position+[130 0 0 0]); 
        cindx = pc_idx_la2;
        cell_names = tdata.uci(cindx);
        elongs = NaN(length(fdata.uci),2);
        for cc = 1:length(cell_names)
            fidx_sq1 = fdata.uci==cell_names(cc) & pf_idx_sq1;
            fidx_la1 = fdata.uci==cell_names(cc) & pf_idx_la2;
            
            eidx1 = fdata.field_principalaxes(fidx_sq1,1) ./ nanmean(fdata.field_principalaxes(fidx_sq1,[2 3]),2);
            eidx2 = fdata.field_principalaxes(fidx_la1,1) ./ nanmean(fdata.field_principalaxes(fidx_la1,[2 3]),2);
            
            elongs(cc,:) = [mean(eidx1(:)) mean(eidx2(:))];
        end
        scatter(elongs(:,1),elongs(:,2),25,'k','MarkerFaceAlpha',.3,'MarkerFaceColor','k','MarkerEdgeColor','none'); hold on;
        daspect([1 1 1]);
        xlabel('Tilted elongation')
        ax = gca;
        ax.XLim = [1 6];
        ax.YLim = [1 6];
        ax.YColor = 'none';
        ax.XTick = 1:6;
        grid on
        r2 = refline(1,0);
        r2.Color = 'r';
        r2.LineStyle = '--';
        r2 = refline;
        r2.Color = 'b';
        r2.LineStyle = '-';

        [r,p] = corr(elongs(:,1),elongs(:,2),'type','Pearson','rows','pairwise');
        disp(sprintf('Arena vs Tilted elongation: r = %.13f, p = %.4f',r,p));
        
%% ##################################### Elongation of multiple fields in arena and lattice    
%% aligned and shuffle
    ax_field1 = axes('Units','pixels','Position',ax_elong2.Position+[195 0 -30 0]); 
        cindx = pc_idx_la1;
        cell_names = tdata.uci(cindx);
        ldiffs = [];
        for cc = 1:length(cell_names)
            fidx_la1 = fdata.uci==cell_names(cc) & pf_idx_la1;
            laxes = fdata.field_principalaxes(fidx_la1,1);
            
            if numel(laxes)<2
                continue
            end
            diffs = laxes-laxes'; % pairwise differences in axis length
            idx = triu(ones(size(diffs)),1);
            vals = diffs(find(idx));
            ldiffs = [ldiffs; vals];
        end
        shuff = length(ldiffs(:,1));
        laxes = fdata.field_principalaxes(pf_idx_la1,1);
        sdiffs = [];
        for ss = 1:shuff
            rindx = randperm(numel(laxes),2);
            laxes_now = laxes(rindx);
            sdiffs = [sdiffs; diff(laxes_now)];
        end
        ldiffs = abs(ldiffs(:));
        sdiffs = abs(sdiffs(:));
        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Aligned','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = [0 35];
        ax.YTick = [0 10 20 30];
        y1 = ax.YLim;
        ylabel('Difference in field length (cm)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places    
        ax.XTickLabelRotation = 30;

        disp('Field lengths aligned:')
        stats_and_bars(ds,gs,[],flnw,fsiz);        
        
%% tilted and shuffle        
    ax_field2 = axes('Units','pixels','Position',ax_field1.Position+[100 0 0 0]); 
        cindx = pc_idx_la2;
        cell_names = tdata.uci(cindx);
        ldiffs = [];
        for cc = 1:length(cell_names)
            fidx_la2 = fdata.uci==cell_names(cc) & pf_idx_la2;
            laxes = fdata.field_principalaxes(fidx_la2,1);
            
            if numel(laxes)<2
                continue
            end
            diffs = laxes-laxes'; % pairwise differences in axis length
            idx = triu(ones(size(diffs)),1);
            vals = diffs(find(idx));
            ldiffs = [ldiffs; vals];
        end
        shuff = length(ldiffs(:,1));
        laxes = fdata.field_principalaxes(pf_idx_la2,1);
        sdiffs = [];
        for ss = 1:shuff
            rindx = randperm(numel(laxes),2);
            laxes_now = laxes(rindx);
            sdiffs = [sdiffs; diff(laxes_now)];
        end
        ldiffs = abs(ldiffs(:));
        sdiffs = abs(sdiffs(:));
        
        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Tilted','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = y1;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places    
        ax.XTickLabelRotation = 30;
        disp('Field lengths tilted:')
        stats_and_bars(ds,gs,[],flnw,fsiz);
        
%% ##################################### Orientation of multiple fields in arena and lattice      
%% aligned vs shuffle
    ax_ori1 = axes('Units','pixels','Position',ax_elong1.Position+[0 -200 0 0]); 
        cindx = pc_idx_la1;
        cell_names = tdata.uci(cindx);
        ldiffs = [];
        for cc = 1:length(cell_names)
            fidx_la1 = fdata.uci==cell_names(cc) & pf_idx_la1;
            laxes = fdata.field_eigenvector(fidx_la1,1:3);
            if size(laxes,1)<2
                continue
            end
            idx = nchoosek(1:size(laxes,1),2);
            for ii = 1:length(idx(:,1))
                ds = acos(dot(laxes(idx(ii,1),:),laxes(idx(ii,2),:)));
                ldiffs = [ldiffs;ds];  
            end
        end
        shuff = length(ldiffs(:,1));
        laxes = fdata.field_eigenvector(pf_idx_la1,1:3);
        sdiffs = [];
        for ss = 1:shuff
            rindx = randperm(numel(laxes(:,1)),2);
            laxes_now = laxes(rindx,:);
            ds = acos(dot(laxes_now(1,:),laxes_now(2,:)));
            sdiffs = [sdiffs;ds];  
        end
        
        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Aligned','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = [0 pi];
        ax.YTick = [0 pi*.5 pi];
        ax.YTickLabel = {'0',sprintf('%c/2',960),sprintf('%c',960)};
        ax.XTickLabelRotation = 30;
        
        y1 = ax.YLim;
        ylabel('Angle between fields (|rads|)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        disp('Angles between fields aligned:')
        stats_and_bars(ds,gs,[],flnw,fsiz);        
        
%% tilted vs shuffle        
    ax_ori2 = axes('Units','pixels','Position',ax_ori1.Position+[130 0 0 0]); 
        cindx = pc_idx_la2;
        cell_names = tdata.uci(cindx);
        ldiffs = [];
        for cc = 1:length(cell_names)
            fidx_la2 = fdata.uci==cell_names(cc) & pf_idx_la2;
            laxes = fdata.field_eigenvector(fidx_la2,1:3);
            if size(laxes,1)<2
                continue
            end
            idx = nchoosek(1:size(laxes,1),2);
            for ii = 1:length(idx(:,1))
                ds = acos(dot(laxes(idx(ii,1),:),laxes(idx(ii,2),:)));
                ldiffs = [ldiffs;ds];  
            end
        end
        shuff = length(ldiffs(:,1));
        laxes = fdata.field_eigenvector(pf_idx_la2,1:3);
        sdiffs = [];
        for ss = 1:shuff
            rindx = randperm(numel(laxes(:,1)),2);
            laxes_now = laxes(rindx,:);
            ds = acos(dot(laxes_now(1,:),laxes_now(2,:)));
            sdiffs = [sdiffs;ds];  
        end
        
        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Tilted','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = [0 pi];
        ax.XTickLabelRotation = 30;

        y1 = ax.YLim;
        ylabel('Angle between fields (|rads|)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places    
        disp('Angles between fields tilted:')
        stats_and_bars(ds,gs,[],flnw,fsiz);          
        
%% ##################################### field numbers in arena and lattice      
%% aligned vs arena and shuffle
    ax_fpc1 = axes('Units','pixels','Position',ax_ori2.Position+[195 0 -30 0]); 
        fvec = fdata.uci(pf_idx_la1);
        cell_names = unique(fvec);
        fds_la1 = histc(fdata.uci(pf_idx_la1),cell_names);   
        fds_sq1 = histc(fdata.uci(pf_idx_sq1),cell_names); 
        fds_sq1(fds_sq1>10 | fds_sq1<-10) = NaN;
        fds_la1(fds_la1>10 | fds_la1<-10) = NaN;
        ldiffs = fds_la1-fds_sq1;
        sdiffs = fds_la1-fds_sq1(randperm(numel(fds_sq1),numel(fds_sq1)));

        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Aligned-Arena','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = [-5 5];
        ax.XTickLabelRotation = 30;

        y1 = ax.YLim;
        ylabel('Fields per cell');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places    
        disp('Fields per cell aligned:')
        stats_and_bars(ds,gs,[],flnw,fsiz);  
        
%% tilted vs arena and shuffle        
    ax_fpc2 = axes('Units','pixels','Position',ax_fpc1.Position+[100 0 0 0]); 
        fvec = fdata.uci(pf_idx_la2);
        cell_names = unique(fvec);
        fds_la2 = histc(fdata.uci(pf_idx_la2),cell_names);   
        fds_sq1 = histc(fdata.uci(pf_idx_sq1),cell_names); 
        fds_sq1(fds_sq1>10 | fds_sq1<-10) = NaN;
        fds_la2(fds_la2>10 | fds_la2<-10) = NaN;
        ldiffs = fds_la2-fds_sq1;
        sdiffs = fds_la2-fds_sq1(randperm(numel(fds_sq1),numel(fds_sq1)));

        [ds,gs] = vectorDATAGROUP([],ldiffs(:),sdiffs(:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{'k','k'},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{'k','k'},'dotalpha',0.3);

        box off
        ax = gca;
        ax.XTick = 1:6;    
        ax.XTickLabel = {'Tilted-Arena','Shuffle'};    
        ax.XLim = [0.5 2.5];
        ax.YLim = [-5 5];
        ax.XTickLabelRotation = 30;

        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        disp('Fields per cell tilted tilted:')
        stats_and_bars(ds,gs,[],flnw,fsiz);  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    

























