%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS16_theta_speed small function to make Fig. S16
% Figure S16 shows analyses on theta and running speed
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible',fig_vis,'Position',[50,60,655,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts

    load_now = 1;    
    
    annotation('textbox','Units','pixels','Position',[5, 550, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[210, 550, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[420, 550, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 350, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[315, 350, 300, 20],'string','e','FontSize',18,'LineStyle','none','interpreter','none');         
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta parameters 
    ynow = 410;
    ax1 = axes('Units','pixels','Position',[460 ynow 170 120]); 
        psdfs = logspace(0,1.7,500);        
        pdata = bdata.theta_psd(pb_idx_sq1,:);
        x = cell2mat(pdata);
        x = reshape(x,500,[]);
        mean_psd1 = nanmean(x,2);
        sem_psd1 = nanstd(x,[],2) ./ sqrt(sum(~isnan(x),2));

        pdata = bdata.theta_psd(pb_idx_la1,:);
        x = cell2mat(pdata);
        x = reshape(x,500,[]);
        mean_psd2 = nanmean(x,2);
        sem_psd2 = nanstd(x,[],2) ./ sqrt(sum(~isnan(x),2));

        pdata = bdata.theta_psd(pb_idx_la2,:);
        x = cell2mat(pdata);
        x = reshape(x,500,[]);
        mean_psd3 = nanmean(x,2);
        sem_psd3 = nanstd(x,[],2) ./ sqrt(sum(~isnan(x),2));    

        e1 = plot(psdfs,mean_psd1,'Color',colsq); hold on;
        e2 = plot(psdfs,mean_psd2,'Color',collt);
        e3 = plot(psdfs,mean_psd3,'Color',coldi);

        ax = gca;
        ax.YLim = [0 450];
        ax.XLim = [0 30];
        xlabel('Frequency (Hz)');
        ylabel('PSD (uV ^{2}/Hz)');
        grid on
        plot([6 6],ax.YLim,'r')
        plot([12 12],ax.YLim,'r')
        box off

        ll = legend([e1 e2 e3],{m1name,m2name,m3name},'Location','NorthEast');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.02 0 0 0])  
        
    ax1 = axes('Units','pixels','Position',[50 ynow 150 120]);         
        [ds,gs] = vectorDATAGROUP([],bdata.theta_latent_power(pb_idx_sq1,:),bdata.theta_latent_power(pb_idx_la1,:),bdata.theta_latent_power(pb_idx_la2,:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 1500];
        ylabel('Theta power (uV ^{2}/Hz)');
        line(ax.XLim,[1 1],'Color','k','LineWidth',flnw);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % sig bridges, stats, text
            disp('Theta power:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1; 
            
    ax1 = axes('Units','pixels','Position',[255 ynow 150 120]);       
        [ds,gs] = vectorDATAGROUP([],bdata.theta_latent_frequency(pb_idx_sq1,:),bdata.theta_latent_frequency(pb_idx_la1,:),bdata.theta_latent_frequency(pb_idx_la2,:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [5.9 13];
        ylabel('Theta frequency (Hz)');
        line(ax.XLim,[1 1],'Color','k','LineWidth',flnw);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % sig bridges, stats, text
            disp('Theta frequency:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;
            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta power/speed relationship  
    % square
    ax1 = axes('Units','pixels','Position',[50 220 250 120]); 
        sval = 1:50;
        v1 = bdata.theta_latent_speed_curve(pb_idx_sq1,:);
        fdat = NaN(length(v1),length(sval));
        sq1_sscores = NaN(length(v1),1);
        sq1_sfits = NaN(length(v1),2);
        sq1_crve = NaN(length(v1),1);
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;      
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            sq1_sscores(d) = sscore;
            sq1_sfits(d,:) = p(:);
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];                        
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult,gof] = fit(xData,yData,ft,opts);
            sq1_crve(d) = fitresult.b;   
        end
        mspeed1 = nanmean(fdat,1); % mean firing rate per speed
        sspeed1 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        % lattice
        v1 = bdata.theta_latent_speed_curve(pb_idx_la1,:);
        fdat = NaN(length(v1),length(sval));
        la1_sscores = NaN(length(v1),1);
        la1_sfits = NaN(length(v1),2);   
        la1_crve = NaN(length(v1),1);        
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;    
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            la1_sscores(d) = sscore;
            la1_sfits(d,:) = p(:);  
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];            
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult, gof] = fit(xData,yData,ft,opts);
            la1_crve(d) = fitresult.b;          
        end
        mspeed2 = nanmean(fdat,1); % mean firing rate per speed
        sspeed2 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        % tilted
        v1 = bdata.theta_latent_speed_curve(pb_idx_la2,:);
        fdat = NaN(length(v1),length(sval));
        la2_sscores = NaN(length(v1),1);
        la2_sfits = NaN(length(v1),2);
        la2_crve = NaN(length(v1),1);        
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;   
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            la2_sscores(d) = sscore;
            la2_sfits(d,:) = p(:);     
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];                        
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult, gof] = fit(xData,yData,ft,opts);
            la2_crve(d) = fitresult.b;             
        end
        mspeed3 = nanmean(fdat,1); % mean firing rate per speed
        sspeed3 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        [e1,e1b] = boundedline(sval(:),mspeed1(:),sspeed1(:)); hold on;
        set(e1,'Color','k');
        set(e1b,'FaceColor',colsq,'FaceAlpha',0.6);
        [e2,e2b] = boundedline(sval(:),mspeed2(:),sspeed2(:)); hold on;
        set(e2,'Color','k');
        set(e2b,'FaceColor',collt,'FaceAlpha',0.6);        
        [e3,e3b] = boundedline(sval(:),mspeed3(:),sspeed3(:)); hold on;        
        set(e3,'Color','k');
        set(e3b,'FaceColor',coldi,'FaceAlpha',0.6);    
        uistack(e1b,'top')
        uistack(e1,'top')

        ax = gca;
        ax.XLim = [0 50];
        ax.YLim = [0 70];
        grid on
        box off
        xlabel('Speed (cm/s)')
        ylabel('Theta power (uV)');
        
        legend([e1b e2b e3b],{m1name m2name m3name},'Location','SouthEast');
        legend boxoff 
        
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta speed slope and intercept
    ynow = 50;
    ax1 = axes('Units','pixels','Position',[200 ynow 100 100]); % power function beta boxplots
        [ds,gs] = vectorDATAGROUP([],sq1_crve(:,1),la1_crve(:,1),la2_crve(:,1));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 3.5];        
        ylabel('Speed/power {\it b}');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))
        
            % sig bridges, stats, text
            disp('Speed vs theta power b:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1; 

    ax1 = axes('Units','pixels','Position',[50 ynow 100 100]); % correlation r boxplots                   
        [ds,gs] = vectorDATAGROUP([],sq1_sscores(:,1),la1_sscores(:,1),la2_sscores(:,1));        
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [-.5 1.5];
        ylabel('Speed-power r');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))
                
            % sig bridges, stats, text
            disp('Speed vs theta power correlation:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta frequency/speed relationship  
    % square
    ax1 = axes('Units','pixels','Position',[375 220 250 120]); 
        sval = 1:50;
        v1 = bdata.theta_latent_speed_freq_curve(pb_idx_sq1,:);
        fdat = NaN(length(v1),length(sval));
        sq1_sscores = NaN(length(v1),1);
        sq1_sfits = NaN(length(v1),2);
        sq1_crve = NaN(length(v1),1);        
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;      
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            sq1_sscores(d) = sscore;
            sq1_sfits(d,:) = p(:);
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];                                    
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult,~] = fit(xData,yData,ft,opts);
            sq1_crve(d) = fitresult.b;             
        end
        mspeed1 = nanmean(fdat,1); % mean firing rate per speed
        sspeed1 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        % lattice
        v1 = bdata.theta_latent_speed_freq_curve(pb_idx_la1,:);
        fdat = NaN(length(v1),length(sval));
        la1_sscores = NaN(length(v1),1);
        la1_sfits = NaN(length(v1),2);  
        la1_crve = NaN(length(v1),1);                
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;    
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            la1_sscores(d) = sscore;
            la1_sfits(d,:) = p(:);    
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];                                    
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult,~] = fit(xData,yData,ft,opts);
            la1_crve(d) = fitresult.b;             
        end
        mspeed2 = nanmean(fdat,1); % mean firing rate per speed
        sspeed2 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        % tilted
        v1 = bdata.theta_latent_speed_freq_curve(pb_idx_la2,:);
        fdat = NaN(length(v1),length(sval));
        la2_sscores = NaN(length(v1),1);
        la2_sfits = NaN(length(v1),2); 
        la2_crve = NaN(length(v1),1);                
        for d = 1:length(v1)
            dnow = v1{d};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat(d,:) = v;   
            
            p = polyfit(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),1);
            sscore = corr(dnow(dnow(:,1)<50,1),dnow(dnow(:,1)<50,2),'type','Pearson','rows','pairwise'); % speed score is the correlation between instantaneous firing rate and speed
            la2_sscores(d) = sscore;
            la2_sfits(d,:) = p(:); 
            
            %% fit power function to data
            x = dnow(dnow(:,1)<50,1);
            y = dnow(dnow(:,1)<50,2);            
            [xData,yData] = prepareCurveData(x,y);
            ft = fittype('power2');
            opts = fitoptions('Method','NonlinearLeastSquares');
            opts.Display = 'Off';
            opts.Lower = [0 -Inf -Inf];                                    
            opts.StartPoint = [50.8811628803047 0.0907383453537243 0.0416187163171008];
            [fitresult,~] = fit(xData,yData,ft,opts);
            la2_crve(d) = fitresult.b;         
        end
        mspeed3 = nanmean(fdat,1); % mean firing rate per speed
        sspeed3 = nanstd(fdat,[],1) ./ sqrt(sum(~isnan(fdat),1)); % SEM of firing rate per speed        

        [e1,e1b] = boundedline(sval(:),mspeed1(:),sspeed1(:)); hold on;
        set(e1,'Color','k');
        set(e1b,'FaceColor',colsq,'FaceAlpha',0.6);
        [e2,e2b] = boundedline(sval(:),mspeed2(:),sspeed2(:)); hold on;
        set(e2,'Color','k');
        set(e2b,'FaceColor',collt,'FaceAlpha',0.6);        
        [e3,e3b] = boundedline(sval(:),mspeed3(:),sspeed3(:)); hold on;        
        set(e3,'Color','k');
        set(e3b,'FaceColor',coldi,'FaceAlpha',0.6);    
        uistack(e1b,'top')
        uistack(e1,'top')
        
        ax = gca;
        ax.XLim = [0 50];
        ax.YLim = [8 9.5];
        grid on
        box off
        xlabel('Speed (cm/s)')
        ylabel('Theta frequency (Hz)');
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))
        
        ll = legend([e1b e2b e3b],{m1name,m2name,m3name},'Location','SouthEast');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.02 0 0 0])        

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta speed slope and intercept
    ax1 = axes('Units','pixels','Position',[525 ynow 100 100]); % power function values    
        [ds,gs] = vectorDATAGROUP([],sq1_sfits(:,1),la1_sfits(:,1),la2_sfits(:,1));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 3.5];                
        ylabel('Speed/power {\it b}');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))
        
            % sig bridges, stats, text
            disp('Speed vs theta frequency b:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;
           
    ax1 = axes('Units','pixels','Position',[375 ynow 100 100]);                     
        [ds,gs] = vectorDATAGROUP([],sq1_sscores(:,1),la1_sscores(:,1),la2_sscores(:,1));                
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 3.5];
        ax.YLim = [-.5 1.5];
        ylabel('Speed-frequency r');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))
                
            % sig bridges, stats, text
            disp('Speed vs theta frequency correlation:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;       

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
    
    
    
    
    
    
    