%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS17_cells_speed small function to make Fig. S17
% Figure S17 shows analyses on firing rate and running speed
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible',fig_vis,'Position',[50,60,655,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts

    load_now = 1;
    
    annotation('textbox','Units','pixels','Position',[5, 910, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 750, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[210, 750, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[440, 750, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Example speed profiles  
    ynow = 810;
    ax1 = axes('Units','pixels','Position',[50 ynow 120 80]);  
        dirs = {[sdir '\852_20032017.mat'],7,2,852,170320};
        cd(sdir);
        load(dirs{1},'-mat','sdata');          

        uci = 'r852_20032017_t8_c4';
        anstr = 'Cell 1 (aligned)';        
        cd(sdir);
        annotation('textbox','Units','pixels','Position',[110, 895, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none'); 

        part_now3 = ['square1_3d'];
        sscore = sdata.(uci).(part_now3).theta_params.speed_score;
        sslope = sdata.(uci).(part_now3).theta_params.speed_slope;
        sintpt = sdata.(uci).(part_now3).theta_params.speed_intercept;
        scurve = sdata.(uci).(part_now3).theta_params.speed_curve;
        xindx = scurve(:,1)<=50;    
        plot(scurve(xindx,1),scurve(xindx,2),'Color',colsq);
        hold on;
        scatter(scurve(xindx,1),scurve(xindx,2),20,'MarkerFaceColor',colsq,'MarkerEdgeColor','none')
        rr = refline(sslope,sintpt);
        set(rr,'Color','r');
        ax = gca;     
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k');
        axis on tight xy
        grid on
        ax.XLim = [0 50];  
        ax.XTick = [0 25 50];
        ax.YLim = [0 3];
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz);
        xlabel('Speed (cm/s)')
        ylabel('Firing Rate (Hz)')
        text(0.05,0.85,sprintf('%s\nslope = %.3f',m1name,sslope),'Units','normalized','FontSize',6)
    
    ax1 = axes('Units','pixels','Position',[190 ynow 120 80]);    
        part_now3 = ['lattice_3d'];
        sscore = sdata.(uci).(part_now3).theta_params.speed_score;
        sslope = sdata.(uci).(part_now3).theta_params.speed_slope;
        sintpt = sdata.(uci).(part_now3).theta_params.speed_intercept;
        scurve = sdata.(uci).(part_now3).theta_params.speed_curve;
        xindx = scurve(:,1)<=50;    
        plot(scurve(xindx,1),scurve(xindx,2),'Color',collt);
        hold on;
        scatter(scurve(xindx,1),scurve(xindx,2),20,'MarkerFaceColor',collt,'MarkerEdgeColor','none')
        rr = refline(sslope,sintpt);
        set(rr,'Color','r');
        ax = gca;     
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k');
        axis on tight xy
        grid on
        ax.XLim = [0 50]; 
        ax.XTick = [0 25 50];        
        ax.YLim = [0 3];
        ax.YTickLabel = {};
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz);    
        xlabel('Speed (cm/s)')
        text(0.05,0.85,sprintf('%s\nslope = %.3f',m2name,sslope),'Units','normalized','FontSize',6)

    ax1 = axes('Units','pixels','Position',[370 ynow 120 80]);  
        cd('Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Diagonal\926_P16k_32_HPC\180410\klustest3\kwiktint');
        load('kwiktint_sdata.mat');
        uci = 'r926_10042018_t12_c2';    
        anstr = 'Cell 2 (tilted)';                
        cd(sdir);
        annotation('textbox','Units','pixels','Position',[430, 895, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none'); 

        part_now3 = ['square1_3d'];
        sscore = sdata.(uci).(part_now3).theta_params.speed_score;
        sslope = sdata.(uci).(part_now3).theta_params.speed_slope;
        sintpt = sdata.(uci).(part_now3).theta_params.speed_intercept;
        scurve = sdata.(uci).(part_now3).theta_params.speed_curve;
        xindx = scurve(:,1)<=50;    
        plot(scurve(xindx,1),scurve(xindx,2),'Color',colsq);
        hold on;
        scatter(scurve(xindx,1),scurve(xindx,2),20,'MarkerFaceColor',colsq,'MarkerEdgeColor','none')
        rr = refline(sslope,sintpt);
        set(rr,'Color','r');
        ax = gca;     
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k');
        axis on tight xy
        grid on
        ax.XLim = [0 50];  
        ax.XTick = [0 25 50];
        ax.YLim = [0 5];
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz);
        xlabel('Speed (cm/s)')
        ylabel('Firing Rate (Hz)')
        text(0.05,0.85,sprintf('%s\nslope = %.3f',m1name,sslope),'Units','normalized','FontSize',6)
    
    ax1 = axes('Units','pixels','Position',[510 ynow 120 80]);    
        part_now3 = ['lattice_3d'];
        sscore = sdata.(uci).(part_now3).theta_params.speed_score;
        sslope = sdata.(uci).(part_now3).theta_params.speed_slope;
        sintpt = sdata.(uci).(part_now3).theta_params.speed_intercept;
        scurve = sdata.(uci).(part_now3).theta_params.speed_curve;
        xindx = scurve(:,1)<=50;    
        plot(scurve(xindx,1),scurve(xindx,2),'Color',coldi);
        hold on;
        scatter(scurve(xindx,1),scurve(xindx,2),20,'MarkerFaceColor',coldi,'MarkerEdgeColor','none')
        rr = refline(sslope,sintpt);
        set(rr,'Color','r');
        ax = gca;     
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k');
        axis on tight xy
        grid on
        ax.XLim = [0 50]; 
        ax.XTick = [0 25 50];        
        ax.YLim = [0 5];
        ax.YTickLabel = {};
        box on
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz);    
        xlabel('Speed (cm/s)')
        text(0.05,0.85,sprintf('%s\nslope = %.3f',m3name,sslope),'Units','normalized','FontSize',6)
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Theta parameters 
    ynow = 600;
    ax1 = axes('Units','pixels','Position',[50 ynow 130 120]);                 
        % square
        idx_now = find(pc_idx_sq1);
        sval = 1:2:100;
        fdat1 = NaN(length(idx_now),50);
        stup_data1 = NaN(length(idx_now),4);
        for d = 1:length(idx_now)
            dnow = tdata.theta_speed_curve{idx_now(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat1(d,:) = v;
            stup_data1(d,:) = [tdata.rat(idx_now(d),:) tdata.date(idx_now(d),:) tdata.tetrode(idx_now(d),:) tdata.cluster(idx_now(d),:)];
        end
        mspeed1 = nanmean(fdat1,1); % mean firing rate per speed
        sspeed1 = nanstd(fdat1,[],1) ./ sqrt(sum(~isnan(fdat1),1)); % SEM of firing rate per speed
        
        % lattice 
        idx_now = find(pc_idx_la1);
        sval = 1:2:100;
        fdat2 = NaN(length(idx_now),50);
        stup_data2 = NaN(length(idx_now),4);
        for d = 1:length(idx_now)
            dnow = tdata.theta_speed_curve{idx_now(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat2(d,:) = v;
            stup_data2(d,:) = [tdata.rat(idx_now(d),:) tdata.date(idx_now(d),:) tdata.tetrode(idx_now(d),:) tdata.cluster(idx_now(d),:)];
        end
        mspeed2 = nanmean(fdat2,1); % mean firing rate per speed
        sspeed2 = nanstd(fdat2,[],1) ./ sqrt(sum(~isnan(fdat2),1)); % SEM of firing rate per speed

        % tilted 
        idx_now = find(pc_idx_la2);
        sval = 1:2:100;
        fdat3 = NaN(length(idx_now),50);
        stup_data3 = NaN(length(idx_now),4);
        for d = 1:length(idx_now)
            dnow = tdata.theta_speed_curve{idx_now(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),dnow(:,2),sval);
            fdat3(d,:) = v;
            stup_data3(d,:) = [tdata.rat(idx_now(d),:) tdata.date(idx_now(d),:) tdata.tetrode(idx_now(d),:) tdata.cluster(idx_now(d),:)];
        end
        mspeed3 = nanmean(fdat3,1); % mean firing rate per speed
        sspeed3 = nanstd(fdat3,[],1) ./ sqrt(sum(~isnan(fdat3),1)); % SEM of firing rate per speed

%         e1 = errorbar(sval,mspeed1,sspeed1,'Color',colsq); hold on;
%         e2 = errorbar(sval,mspeed2,sspeed2,'Color',collt); hold on;
%         e3 = errorbar(sval,mspeed3,sspeed3,'Color',coldi); hold on;
        [e1,e1b] = boundedline(sval(:),mspeed1(:),sspeed1(:)); hold on;
        set(e1,'Color','k');
        set(e1b,'FaceColor',colsq,'FaceAlpha',0.6);
        [e2,e2b] = boundedline(sval(:),mspeed2(:),sspeed2(:)); hold on;
        set(e2,'Color','k');
        set(e2b,'FaceColor',collt,'FaceAlpha',0.6);        
        [e3,e3b] = boundedline(sval(:),mspeed3(:),sspeed3(:)); hold on;        
        set(e3,'Color','k');
        set(e3b,'FaceColor',coldi,'FaceAlpha',0.6);    
        uistack(e1b,'top')
        uistack(e1,'top')
        
        ax = gca;
        ax.XLim = [0 50];
        ax.XTick = [0:10:50];
        ax.YLim = [0 2.5];
        grid on
        box off
        xlabel('Speed (cm/s)')
        ylabel('Firing rate (Hz)')
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f'))

        ll = legend([e1b e2b e3b],{m1name,m2name,m3name},'Location','SouthEast');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.02 -0.005 0 0])

    ax1 = axes('Units','pixels','Position',[245 ynow 70 120]);     
        [ds,gs] = vectorDATAGROUP([],tdata.theta_speed_slope(pc_idx_sq1,:),tdata.theta_speed_slope(pc_idx_la1,:),tdata.theta_speed_slope(pc_idx_la2,:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 0.2];
        ylabel('Rate/speed slope')
        line(ax.XLim,[0 0],'Color',[.5 .5 .5],'LineWidth',flnw);
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))

            % sig bridges, stats, text
            disp('Rate/speed slope:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1; 
            
    ax1 = axes('Units','pixels','Position',[355 ynow 70 120]);     
        [ds,gs] = vectorDATAGROUP([],tdata.firing_rate_Hz(pc_idx_sq1,:),tdata.firing_rate_Hz(pc_idx_la1,:),tdata.firing_rate_Hz(pc_idx_la2,:));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 15];
        ylabel('Firing rate (Hz)')
        line(ax.XLim,[0 0],'Color',[.5 .5 .5],'LineWidth',flnw);

            % sig bridges, stats, text
            disp('Mean firing rate:')
            ax1 = ax.YLim;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;             

    ax1 = axes('Units','pixels','Position',[480 ynow 150 120]); % proportion of time at every speed
        % square
        idx_now = pc_idx_sq1;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time1 = NaN(length(uidx),length(sval));
        stup_data1 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time1(d,:) = v;        
            stup_data1(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time1 = fdat_time1 ./ nansum(fdat_time1,2);
        mtime1 = nanmean(fdat_time1,1); % mean firing rate per speed
        stime1 = nanstd(fdat_time1,[],1) ./ sqrt(sum(~isnan(fdat_time1),1)); % SEM of firing rate per speed           
            
        % aligned
        idx_now = pc_idx_la1;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time2 = NaN(length(uidx),length(sval));
        stup_data2 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time2(d,:) = v;        
            stup_data2(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time2 = fdat_time2 ./ nansum(fdat_time2,2);
        mtime2 = nanmean(fdat_time2,1); % mean firing rate per speed
        stime2 = nanstd(fdat_time2,[],1) ./ sqrt(sum(~isnan(fdat_time2),1)); % SEM of firing rate per speed            
                      
        % tilted
        idx_now = pc_idx_la2;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time3 = NaN(length(uidx),length(sval));
        stup_data3 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time3(d,:) = v;        
            stup_data3(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time3 = fdat_time3 ./ nansum(fdat_time3,2);
        mtime3 = nanmean(fdat_time3,1); % mean firing rate per speed
        stime3 = nanstd(fdat_time3,[],1) ./ sqrt(sum(~isnan(fdat_time3),1)); % SEM of firing rate per speed            
 
        [e1,e1b] = boundedline(sval(:),mtime1(:),stime1(:)); hold on;
        set(e1,'Color','k');
        set(e1b,'FaceColor',colsq,'FaceAlpha',0.6);
        [e2,e2b] = boundedline(sval(:),mtime2(:),stime2(:)); hold on;
        set(e2,'Color','k');
        set(e2b,'FaceColor',collt,'FaceAlpha',0.6);        
        [e3,e3b] = boundedline(sval(:),mtime3(:),stime3(:)); hold on;        
        set(e3,'Color','k');
        set(e3b,'FaceColor',coldi,'FaceAlpha',0.6);    
        uistack(e1b,'top')
        uistack(e1,'top')
        
        ax = gca;
        ax.XLim = [0 50];
        ax.XTick = [0:10:50];       
        ax.YLim(1) = 0;
        grid on
        box off
        xlabel('Speed (cm/s)')
        ylabel('Proportion of time')
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))
        
        ll = legend([e1b e2b e3b],{m1name,m2name,m3name},'Location','NorthEast');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.02 0.01 0 0])  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    






