%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS18_cells_speed small function to make Fig. S18
% Figure S18 shows analyses on theta and cell firing (firing phase and phase precession)
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE    
    fig2 = figure('visible',fig_vis,'Position',[50,60,660,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    load_now = 1;

    annotation('textbox','Units','pixels','Position',[5, 900, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 660, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 445, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 

    dirs = {[sdir '\896_19012018.mat'],0,0,896,180119};
    cd(sdir);
    load(dirs{1},'-mat','sdata');  
    uci = 'r896_19012018_t15_c7';      
    annotation('textbox','Units','pixels','Position',[110, 895, 300, 20],'string','Cell 1 (aligned lattice)','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Example cells  
%% autocorr cell 1
    ax_aco = axes('Units','pixels','Position',[50 810 100 80]); % square theta autocorr
        theta_data = sdata.(uci).square1.theta_train_long;
        cvec = theta_data(:,1);
        tms = theta_data(:,2);
        bar(tms,cvec,1,'FaceColor',colsq,'EdgeColor',colsq);
        ax = gca;
        ax.YLim = [0.001 0.15];
        ax.YTick = [0 0.001 0.01 0.1];
        ax.XTick = [];
        axis([tms(1) tms(end) ax.YLim]);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz); 
        ax.YScale = 'log';
        text(0.05,0.95,m1name,'Units','normalized','FontSize',6)

%% autocorr cell 2        
    ax_aco2 = axes('Units','pixels','Position',ax_aco.Position+[0 -100 0 0]); % lattice theta autocorr
        theta_data = sdata.(uci).lattice.theta_train_long;
        corrdata = theta_data(:,1);
        tms = theta_data(:,2);
        bar(tms,corrdata,1,'FaceColor',collt,'EdgeColor',collt);
        ax = gca;
        ax.YLim = [0.001 0.15];
        ax.YTick = [0 0.001 0.01 0.1];
        axis([tms(1) tms(end) ax.YLim]);
        xlabel('Time lag (ms)') % label x axis
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz); 
        ax.YScale = 'log';
        y = ylabel('Log probability'); % label y axis
        set(y,'position',get(y,'position')+[0,0.15,0]);
        text(0.05,0.95,m2name,'Units','normalized','FontSize',6)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% spike phase
    ax_sp = axes('Units','pixels','Position',[200 810 100 80]); % square phase preference
        spp = sdata.(uci).square1.spike_phase;
        ai = deg2rad(-180:10:540); % doing this means we have bins symmetrical around zero
        ai = ai(:);
        spp2 = [spp; (spp+2*pi)];
        spp2 = spp2(:);
        yi = histcounts(spp2,ai) / numel(spp2);    
        aip = histcents(ai);
        bar(aip,yi,1,'FaceColor',colsq,'EdgeColor',colsq);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % Put axis lines on top, change their width and fontsize, make sure the text is black  
        ax = gca;
        ax.XTick = [];
        ax.YLim = [0 0.025];
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))

        cm = circ_mean(spp(~isnan(spp)));
        hold on
        line([cm cm],ax.YLim,'Color','b','LineWidth',1);
        line([cm+2*pi cm+2*pi],ax.YLim,'Color','b','LineWidth',1);        
        cwav = cos(ai(:))*(ax.YLim(2)/2)+(ax.YLim(2)/2);
        plot(ai(:),cwav,'r')
        
    ax_sp2 = axes('Units','pixels','Position',ax_sp.Position+[0 -100 0 0]); % lattice phase preference 
        spp = sdata.(uci).lattice.spike_phase;
        spp2 = [spp; (spp+2*pi)];
        spp2 = spp2(:);
        yi = histcounts(spp2,ai) / numel(spp2);    
        bar(aip,yi,1,'FaceColor',collt,'EdgeColor',collt);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % Put axis lines on top, change their width and fontsize, make sure the text is black  
        ax = gca;
        ax.XTick = [-pi 0 pi 2*pi 3*pi];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};    
        ax.YLim = [0 0.025];    
        xlabel(sprintf('Theta Phase (%c)',char(176)))  
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))
        y = ylabel('Proportion of spikes');
        set(y,'position',get(y,'position')+[0,0.013,0]);
        
        cm = circ_mean(spp(~isnan(spp)));
        hold on
        line([cm cm],ax.YLim,'Color','b','LineWidth',1);
        line([cm+2*pi cm+2*pi],ax.YLim,'Color','b','LineWidth',1);                
        cwav = cos(ai(:))*(ax.YLim(2)/2)+(ax.YLim(2)/2);
        plot(ai(:),cwav,'r')
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    dirs = {[sdir '\926_09042018.mat'],0,0,926,180409};
    cd(sdir);
    load(dirs{1},'-mat','sdata');  
    uci = 'r926_09042018_t15_c1';
    cd(sdir);
    annotation('textbox','Units','pixels','Position',[430, 895, 300, 20],'string','Cell2 (tilted lattice)','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% autocorr  
    ax_aco = axes('Units','pixels','Position',[370 810 100 80]); % square theta autocorr
        theta_data = sdata.(uci).square1.theta_train_long;
        cvec = theta_data(:,1);
        tms = theta_data(:,2);
        bar(tms,cvec,1,'FaceColor',colsq,'EdgeColor',colsq);
        ax = gca;
        ax.YLim = [0.001 0.15];
        ax.YTick = [0 0.001 0.01 0.1];
        ax.XTick = [];
        axis([tms(1) tms(end) ax.YLim]);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz); 
        ax.YScale = 'log';
        text(0.05,0.95,m1name,'Units','normalized','FontSize',6)

    ax_aco2 = axes('Units','pixels','Position',ax_aco.Position+[0 -100 0 0]); % lattice theta autocorr
        theta_data = sdata.(uci).lattice.theta_train_long;
        corrdata = theta_data(:,1);
        tms = theta_data(:,2);
        bar(tms,corrdata,1,'FaceColor',coldi,'EdgeColor',coldi);
        ax = gca;
        ax.YLim = [0.001 0.15];
        ax.YTick = [0 0.001 0.01 0.1];
        axis([tms(1) tms(end) ax.YLim]);
        xlabel('Time lag (ms)') % label x axis
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz); 
        ax.YScale = 'log';
        y = ylabel('Log probability'); % label y axis
        set(y,'position',get(y,'position')+[0,0.15,0]);
        text(0.05,0.95,m3name,'Units','normalized','FontSize',6)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% spike phase
    ax_sp = axes('Units','pixels','Position',[520 810 100 80]); % square phase preference
        spp = sdata.(uci).square1.spike_phase;
        ai = deg2rad(-180:10:540); % doing this means we have bins symmetrical around zero
        ai = ai(:);
        spp2 = [spp; (spp+2*pi)];
        spp2 = spp2(:);
        yi = histcounts(spp2,ai) / numel(spp2);    
        aip = histcents(ai);
        bar(aip,yi,1,'FaceColor',colsq,'EdgeColor',colsq);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % Put axis lines on top, change their width and fontsize, make sure the text is black  
        ax = gca;
        ax.XTick = [];
        ax.YLim = [0 0.025];
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))

        cm = circ_mean(spp(~isnan(spp)));
        hold on
        line([cm cm],ax.YLim,'Color','b','LineWidth',1);
        line([cm+2*pi cm+2*pi],ax.YLim,'Color','b','LineWidth',1);        
        cwav = cos(ai(:))*(ax.YLim(2)/2)+(ax.YLim(2)/2);
        plot(ai(:),cwav,'r')
        
    ax_sp2 = axes('Units','pixels','Position',ax_sp.Position+[0 -100 0 0]); % lattice phase preference 
        spp = sdata.(uci).lattice.spike_phase;
        spp2 = [spp; (spp+2*pi)];
        spp2 = spp2(:);
        yi = histcounts(spp2,ai) / numel(spp2);    
        bar(aip,yi,1,'FaceColor',coldi,'EdgeColor',coldi);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % Put axis lines on top, change their width and fontsize, make sure the text is black  
        ax = gca;
        ax.XTick = [-pi 0 pi 2*pi 3*pi];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};    
        ax.YLim = [0 0.025];    
        xlabel(sprintf('Theta Phase (%c)',char(176)))  
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))
        y = ylabel('Proportion of spikes');
        set(y,'position',get(y,'position')+[0,0.013,0]);
        
        cm = circ_mean(spp(~isnan(spp)));
        hold on
        line([cm cm],ax.YLim,'Color','b','LineWidth',1);
        line([cm+2*pi cm+2*pi],ax.YLim,'Color','b','LineWidth',1);                
        cwav = cos(ai(:))*(ax.YLim(2)/2)+(ax.YLim(2)/2);
        plot(ai(:),cwav,'r')

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%         v1 = tdata.theta_cell_modulation(pc_idx_sq1,:);
%         v2 = tdata.theta_cell_modulation(pc_idx_la1,:);
%         v3 = tdata.theta_cell_modulation(pc_idx_la2,:);
% 
%         [ds,gs] = vectorDATAGROUP([],v1,v2,v3);
%         boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);
%         box off
%         ax = gca;
%         ax.XTickLabel = {m1name m2name m3name};    
%         ax.XTickLabelRotation = 45;
%         ax.XLim = [0.5 3.5];
%         % ax.YLim = [0 0.2];
%         ylabel('Theta index')
%         line(ax.XLim,[0 0],'Color',[.5 .5 .5],'LineWidth',flnw);        
% 
%         % sig bridges, stats, text
%         disp('Theta index:')
%         ax1 = ax.YLim;        
%         stats_and_bars(ds,gs,[],flnw,fsiz);
%         ax.YLim = ax1;  

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% square phase precession scatter graph  
    ax_lims = [7 11];
    ax1 = axes('Units','pixels','Position',[80 520 120 120]); 
        v1 = tdata.theta_latent_frequency(pc_idx_sq1,:);
        v2 = tdata.theta_cell_frequency(pc_idx_sq1,:);
        dat = [v1 v2];
        dat(any(isnan(dat),2),:) = [];
        d = densityScatter(dat',{'plotting',0,'filterFactor',0});
        scatter(dat(:,1),dat(:,2),40,1-d,'filled'); hold on; 
        plot([0 50],[0 50],'k--')
        daspect([1 1 1])
        ax = gca;
        ax.XLim = ax_lims;
        ax.YLim = ax_lims;
        ax.XTickLabel = {};
        ax.YTickLabel = {};
        grid on
        title(m1name,'FontWeight','normal')

            r = corr(dat(:,1),dat(:,2),'type','Pearson','rows','pairwise');
            tnum = sum(dat(:,1)<dat(:,2));
            bnum = sum(dat(:,1)>dat(:,2));
            disp(sprintf('\tSquare frequency x frequency'))
            disp(sprintf('\t\tr = %.2f, top = %d (%.2f), bottom = %d (%.2f)',r,tnum,tnum./length(dat(:,1)),bnum,bnum./length(dat(:,1))))
            disp(sprintf('\t\tmd = %.2f, md = %.2f',nanmedian(v1),nanmedian(v2)))
            [p,~,sts] = signrank(v1(:),v2(:),'method','approximate');
            disp(sprintf('\t\tz = %.2f, p = %.5f',sts.zval,p));
    
    ax1a = axes('Units','pixels','Position',ax1.Position+[-30 0 -100 0]); 
        bs = 0.1;
        bw = 0.1;
        xi = ax_lims(1):bs:ax_lims(2);
        f = histDENSITY(v2,xi,bw);    
        plot(f,xi,'k');
        box off
        grid on
        ax = gca;
        ax.XGrid = 'off';
        ax.YLim = ax_lims;
        ax.XLim(1) = 0;
        ax.XAxisLocation = 'top';
        ylabel('Cell theta (Hz)')
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','none','YColor','k');

    ax1b = axes('Units','pixels','Position',ax1.Position+[0 -30 0 -100]); 
        f = histDENSITY(v1,xi,bw);    
        plot(xi,f+0.01,'k');
        box off
        grid on
        ax = gca;
        ax.YGrid = 'off';    
        ax.XLim = ax_lims;
        ax.YLim(1) = 0;
        xlabel('Global theta (Hz)')    
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none');
     
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% lattice phase precession scatter graph  
    ax2 = axes('Units','pixels','Position',[285 520 120 120]); 
        v1 = tdata.theta_latent_frequency(pc_idx_la1,:);
        v2 = tdata.theta_cell_frequency(pc_idx_la1,:);
        dat = [v1 v2];
        dat(any(isnan(dat),2),:) = [];
        d = densityScatter(dat',{'plotting',0,'filterFactor',0});
        scatter(dat(:,1),dat(:,2),40,1-d,'filled'); hold on; 
        plot([0 50],[0 50],'k--')
        daspect([1 1 1])
        ax = gca;
        ax.XLim = ax_lims;
        ax.YLim = ax_lims;
        ax.XTickLabel = {};
        ax.YTickLabel = {};    
        grid on
        title(m2name,'FontWeight','normal')

            r = corr(dat(:,1),dat(:,2),'type','Pearson','rows','pairwise');
            tnum = sum(dat(:,1)<dat(:,2));
            bnum = sum(dat(:,1)>dat(:,2));
            disp(sprintf('\tLattice frequency x frequency'))            
            disp(sprintf('\t\tr = %.2f, top = %d (%.2f), bottom = %d (%.2f)',r,tnum,tnum./length(dat(:,1)),bnum,bnum./length(dat(:,1))))
            disp(sprintf('\t\tmd = %.2f, md = %.2f',nanmedian(v1),nanmedian(v2)))
            [p,~,sts] = signrank(v1(:),v2(:),'method','approximate');
            disp(sprintf('\t\tz = %.2f, p = %.5f',sts.zval,p));
            
    ax2a = axes('Units','pixels','Position',ax2.Position+[-30 0 -100 0]); 
        bs = 0.1;
        bw = 0.1;
        xi = ax_lims(1):bs:ax_lims(2);
        f = histDENSITY(v2,xi,bw);    
        plot(f,xi,'k');
        box off
        grid on
        ax = gca;
        ax.XGrid = 'off';    
        ax.YLim = ax_lims;
        ax.XLim(1) = 0;
        ax.XAxisLocation = 'top';    
        ylabel('Cell theta (Hz)')
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','none','YColor','k');

    ax2b = axes('Units','pixels','Position',ax2.Position+[0 -30 0 -100]); 
        f = histDENSITY(v1,xi,bw);    
        plot(xi,f+0.01,'k');
        box off
        grid on
        ax = gca;
        ax.YGrid = 'off';        
        ax.XLim = ax_lims;
        ax.YLim(1) = 0;
        xlabel('Global theta (Hz)')    
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none');

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% tilted phase precession scatter graph  
    ax3 = axes('Units','pixels','Position',[490 520 120 120]); 
        v1 = tdata.theta_latent_frequency(pc_idx_la2,:);
        v2 = tdata.theta_cell_frequency(pc_idx_la2,:);
        dat = [v1 v2];
        dat(any(isnan(dat),2),:) = [];
        d = densityScatter(dat',{'plotting',0,'filterFactor',0});
        scatter(dat(:,1),dat(:,2),40,1-d,'filled'); hold on; 
        plot([0 50],[0 50],'k--')
        daspect([1 1 1])
        ax = gca;
        ax.XLim = ax_lims;
        ax.YLim = ax_lims;
        ax.XTickLabel = {};
        ax.YTickLabel = {};    
        grid on
        title(m3name,'FontWeight','normal')

            r = corr(dat(:,1),dat(:,2),'type','Pearson','rows','pairwise');
            tnum = sum(dat(:,1)<dat(:,2));
            bnum = sum(dat(:,1)>dat(:,2));
            disp(sprintf('\tDiagonal frequency x frequency'))            
            disp(sprintf('\t\tr = %.2f, top = %d (%.2f), bottom = %d (%.2f)',r,tnum,tnum./length(dat(:,1)),bnum,bnum./length(dat(:,1))))
            disp(sprintf('\t\tmd = %.2f, md = %.2f',nanmedian(v1),nanmedian(v2)))
            [p,~,sts] = signrank(v1(:),v2(:),'method','approximate');
            disp(sprintf('\t\tz = %.2f, p = %.5f',sts.zval,p));
            
    ax3a = axes('Units','pixels','Position',ax3.Position+[-30 0 -100 0]); 
        bs = 0.1;
        bw = 0.1;
        xi = ax_lims(1):bs:ax_lims(2);
        f = histDENSITY(v2,xi,bw);    
        plot(f,xi,'k');
        box off
        grid on
        ax = gca;
        ax.XGrid = 'off';    
        ax.YLim = ax_lims;
        ax.XLim(1) = 0;
        ax.XAxisLocation = 'top';    
        ylabel('Cell theta (Hz)')
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','none','YColor','k');

    ax3b = axes('Units','pixels','Position',ax3.Position+[0 -30 0 -100]); 
        f = histDENSITY(v1,xi,bw);    
        plot(xi,f+0.01,'k');
        box off
        grid on
        ax = gca;
        ax.YGrid = 'off';        
        ax.XLim = ax_lims;
        ax.YLim(1) = 0;
        xlabel('Global theta (Hz)')    
        set(ax,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Spike phase bar graphs 
    sq1s = tdata.theta_spike_phase_stats(pc_idx_sq1,:);
    la1s = tdata.theta_spike_phase_stats(pc_idx_la1,:);
    la2s = tdata.theta_spike_phase_stats(pc_idx_la2,:);

    xi = -pi:0.4:pi; 
    bw = 0.2;

    ax1 = axes('Units','pixels','Position',[50 320 150 100]); 
        d = sq1s(:,4);
        ncells = sum(~isnan(d));
        f1 = histDENSITY(d,xi,bw) / ncells; 
        bar([xi(:);xi(:)+2*pi],[f1;f1],1.1,'FaceColor',colsq,'EdgeColor',colsq);
        ax = gca;
        ax.XLim = [-pi 3*pi];
        ax.YLim = [0 0.2];
        hold on
        cwav = cos([xi(:);xi(:)+2*pi])*(ax.YLim(2)/2)+(ax.YLim(2)/2);
        plot([xi(:);xi(:)+2*pi],cwav,'r')
        cm = circ_mean(d(~isnan(d)));
        plot([cm cm],ax.YLim,'b','LineWidth',1)
        plot([cm+(2*pi) cm+(2*pi)],ax.YLim,'b','LineWidth',1)
        ax.XTick = [];
        ax.XTick = [-pi 0 pi 2*pi 3*pi];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};
        ylabel('Proportion of cells')
        [r,p,z,n] = circ_rtest2(d(~isnan(d)));
        
            disp(sprintf('\tSquare spike theta phase'))            
            disp(sprintf('\t\tcirc mean = %.2f, median rv = %.2f',cm,nanmedian(sq1s(:,1))))
            title(sprintf('Median r = %.2f',nanmedian(sq1s(:,1))),'FontWeight','normal')
            disp(sprintf('\t\tr = %.2f, p = %.4f, n = %d',r,p,n))
            

    ax2 = axes('Units','pixels','Position',ax1.Position+[205 0 0 0]); 
        d = la1s(:,4);
        ncells = sum(~isnan(d));    
        f2 = histDENSITY(d,xi,bw) / ncells; 
        bar([xi(:);xi(:)+2*pi],[f2;f2],1.1,'FaceColor',collt,'EdgeColor',collt);
        ax = gca;
        ax.XLim = [-pi 3*pi];
        ax.YLim = [0 0.2];    
        hold on
        plot([xi(:);xi(:)+2*pi],cwav,'r')   
        cm = circ_mean(d(~isnan(d)));
        plot([cm cm],ax.YLim,'b','LineWidth',1)  
        plot([cm+(2*pi) cm+(2*pi)],ax.YLim,'b','LineWidth',1) 
        ax.XTick = [];        
        ax.XTick = [-pi 0 pi 2*pi 3*pi];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};    
        ylabel('Proportion of cells')
        [r,p,z,n] = circ_rtest2(d(~isnan(d)));

            disp(sprintf('\tSquare spike theta phase'))            
            disp(sprintf('\t\tcirc mean = %.2f, median rv = %.2f',cm,nanmedian(la1s(:,1))))
            title(sprintf('Median r = %.2f',nanmedian(la1s(:,1))),'FontWeight','normal')
            disp(sprintf('\t\tr = %.2f, p = %.4f, n = %d',r,p,n))
                        
    ax3 = axes('Units','pixels','Position',ax1.Position+[410 0 0 0]); 
        d = la2s(:,4);
        ncells = sum(~isnan(d));    
        f3 = histDENSITY(d,xi,bw) / ncells; 
        bar([xi(:);xi(:)+2*pi],[f3;f3],1.1,'FaceColor',coldi,'EdgeColor',coldi);
        ax = gca;
        ax.XLim = [-pi 3*pi];
        ax.YLim = [0 0.2];    
        hold on
        plot([xi(:);xi(:)+2*pi],cwav,'r')   
        cm = circ_mean(d(~isnan(d)));
        plot([cm cm],ax.YLim,'b','LineWidth',1)    
        plot([cm+(2*pi) cm+(2*pi)],ax.YLim,'b','LineWidth',1)  
        ax.XTick = [];        
        ax.XTick = [-pi 0 pi 2*pi 3*pi];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};
        ylabel('Proportion of cells')
        [r,p,z,n] = circ_rtest2(d(~isnan(d)));

            disp(sprintf('\tSquare spike theta phase'))            
            disp(sprintf('\t\tcirc mean = %.2f, median rv = %.2f',cm,nanmedian(la2s(:,1))))
            title(sprintf('Median r = %.2f',nanmedian(la2s(:,1))),'FontWeight','normal')
            disp(sprintf('\t\tr = %.2f, p = %.4f, n = %d',r,p,n))
            
            disp(sprintf('\tOverall phase stats'))            
            [p1,k1,K] = circ_kuipertest(sq1s(:,4),la1s(:,4));
            [p2,k2,K] = circ_kuipertest(sq1s(:,4),la2s(:,4));
            [p3,k3,K] = circ_kuipertest(la1s(:,4),la2s(:,4));
            D1 = finddelay(repmat(f1,10,1),repmat(f2,10,1))*0.4;
            D2 = finddelay(repmat(f1,10,1),repmat(f3,10,1))*0.4;
            D3 = finddelay(repmat(f2,10,1),repmat(f3,10,1))*0.4;            
            disp(sprintf('\t\tsq1 vs la1: k = %.4f, p = %.4f, delay = %.4f',k1,p1,D1))
            disp(sprintf('\t\tsq1 vs la2: k = %.4f, p = %.4f, delay = %.4f',k2,p2,D2))
            disp(sprintf('\t\tla1 vs la2: k = %.4f, p = %.4f, delay = %.4f',k3,p3,D3))
           
            [ds,gs] = vectorDATAGROUP([],sq1s(:),la1s(:),la2s(:));
            [p,a,sts] = kruskalwallis(ds,gs,'off');
            a{2,5}./sum(~isnan(ds));
            [c,~,~,~] = multcompare(sts,'display','off','ctype','bonferroni');    
            disp(sprintf('Median r = %.3f, %.3f, %.3f',nanmedian(sq1s(:,1)),nanmedian(la1s(:,1)),nanmedian(la2s(:,1))));
            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %% Spike phase every cell image       
    ax1 = axes('Units','pixels','Position',[50 70 150 230]);    
        idx = pc_idx_sq1;
        crve = tdata.theta_spike_phase_curve(idx,:);
        crve = reshape(cell2mat(crve),63,[])';
        crve = crve ./ nansum(crve,2);
        crve(:,end) = crve(:,1);
        rayv = tdata.theta_spike_phase_stats(idx,1);
        rayv = rayv(~isnan(rayv));

        [~,sidx] = sort(rayv,'ascend');
        rayv = rayv(sidx);
        crve = crve(sidx,:);
        crve = [crve crve];
        im = imagesc(crve);
        set(im,'alphadata',~isnan(crve));
        axis xy
        ax = gca;
        ax.XTick = [1 32.5 64 95 126];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};   
        ax.YTick = [ax.YTick size(crve,1)];
        xlabel('Preferred phase')
        ylabel('Place cell')
        caxis([0 0.04]);

    ax1 = axes('Units','pixels','Position',[255 70 150 230]); 
        idx = pc_idx_la1;
        crve = tdata.theta_spike_phase_curve(idx,:);
        crve = reshape(cell2mat(crve),63,[])';
        crve = crve ./ nansum(crve,2);
        crve(:,end) = crve(:,1);
        rayv = tdata.theta_spike_phase_stats(idx,1);
        rayv = rayv(~isnan(rayv));

        [~,sidx] = sort(rayv,'ascend');
        rayv = rayv(sidx);
        crve = crve(sidx,:);
        crve = [crve crve];
        im = imagesc(crve);
        set(im,'alphadata',~isnan(crve));
        axis xy
        ax = gca;
        ax.XTick = [1 32.5 64 95 126];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};   
        ax.YTick = [ax.YTick(1:end-1) size(crve,1)];
        xlabel('Preferred phase')
        ylabel('Place cell')
        caxis([0 0.04]);
        
    ax1 = axes('Units','pixels','Position',[460 70 150 230]); 
        idx = pc_idx_la2;
        crve = tdata.theta_spike_phase_curve(idx,:);
        crve = reshape(cell2mat(crve),63,[])';
        crve = crve ./ nansum(crve,2);       
        crve(:,end) = crve(:,1);
        rayv = tdata.theta_spike_phase_stats(idx,1);
        rayv = rayv(~isnan(rayv));
        [~,sidx] = sort(rayv,'ascend');
        rayv = rayv(sidx);
        crve = crve(sidx,:);
        crve = [crve crve];
        im = imagesc(crve);
        set(im,'alphadata',~isnan(crve));
        axis xy
        ax = gca;
        ax.XTick = [1 32.5 64 95 126];
        ax.XTickLabel = {'-\pi' '0' '\pi' '2\pi' '3\pi'};   
        ax.YTick = [ax.YTick size(crve,1)];
        xlabel('Preferred phase')
        ylabel('Place cell')
        caxis([0 0.04]);
        
        axp = ax.Position;
        cc = colorbar;
        cc.Position = cc.Position+[0.09 0 -.0001 0];
        cc.Ticks = [0 .04];
        yy = ylabel(cc,'Firing probability');
        set(yy,'Position',get(yy,'Position')+[-3 0 0]);
        ax.Position = axp;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
    
    
    
    
    
    
    
    
    
    
    
    