%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS2_eigen_schematic small function to make Fig. S2
% Figure S2 contains a schematic showing how ellipses were fitted to fields using their eigenvector
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,595,842]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Function body
       mu = [1 -1]; 
       Sigma = [.2 .1; .1 .2];
       [X1,X2] = meshgrid(linspace(-1,3,100)', linspace(-3,1,100)');
       X = [X1(:) X2(:)];
       p = mvnpdf(X, mu, Sigma);
       map1 = reshape(p,100,100);
       map2 = imbinarize(map1,0.2.*nanmax(map1(:)));
       map3 = repmat(map2,1,1,2);
       sts = regionprops3(map3,'EigenVectors','Centroid','PrincipalAxisLength');      

    ax_field = axes('Units','pixels','Position',[50 700 110 110]);          
        imagesc(map1); hold on;
        daspect([1 1 1])
        axis xy off
        title('Firing rate map','FontSize',fsiz,'FontWeight','normal')
        
    axc = axes('Units','pixels','Position',[ax_field.Position(1)+20 ax_field.Position(2)-20 ax_field.Position(3)-40 10]);
        imagesc(((1:256)));
        colormap(axc,'jet')
        axis xy off
        text(-0.15,0.5,'0Hz','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(1.15,0.5,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        
    ax_field = axes('Units','pixels','Position',[180 700 110 110]);          
        imshow(map2); hold on;
        daspect([1 1 1])
        axis xy off
        xa = axis;
        p1 = patch([-1 -1],[-2 -2],'k');
        p2 = patch([-1 -1],[-2 -2],'w');
        [~,o] = legendflex([p1 p2], {'Below threshold','Place field'}, 'ref', gca, 'xscale', 0.4, 'anchor', [3 8], 'buffer', [-100 -130], 'box', 'off', 'FontSize',6);
        axis(xa);
        title('Place field','FontSize',fsiz,'FontWeight','normal')
        
    ax_field = axes('Units','pixels','Position',[310 700 110 110]);          
        map4 = map1;
        map4(~map2) = NaN;
        contourf(map4,4);
        daspect([1 1 1])
        axis xy on
        ax = gca;
        ax.XTick = [];
        ax.YTick = [];
        axis(xa);        
        text(0.1,0.1,mat2str(Sigma),'FontSize',fsiz,'Units','normalized');
        title('Covariance matrix','FontSize',fsiz,'FontWeight','normal')        

    ax_field = axes('Units','pixels','Position',[440 700 110 110]); 
        ev = sts.EigenVectors{1};
        pa = sts.PrincipalAxisLength./2;
        ce = sts.Centroid;
        
        cpoints = find(map2(:,:,1));
        [r,c] = ind2sub(size(map2(:,:,1)),cpoints);
        k = convhull(r,c);
        p1 = plot(c(k),r(k),'k'); hold on;
        p2 = plot(ce(1),ce(2),'go','MarkerSize',8);
        axis(xa);
        daspect([1 1 1])         
        axis xy on
        f1 = farrow(ce(1),ce(2),ce(3), ev(2,1).*pa(1)+ce(1), ev(1,1).*pa(1)+ce(2), ev(3,1).*pa(1)+ce(3),'r',1); hold on;
        farrow(ce(1),ce(2),ce(3), -ev(2,1).*pa(1)+ce(1), -ev(1,1).*pa(1)+ce(2),-ev(3,1).*pa(1)+ce(3),'r',1);
        f2 = farrow(ce(1),ce(2),ce(3), ev(2,2).*pa(2)+ce(1), ev(1,2).*pa(2)+ce(2), ev(3,2).*pa(2)+ce(3),'b',1); hold on;
        farrow(ce(1),ce(2),ce(3), -ev(2,2).*pa(2)+ce(1), -ev(1,2).*pa(2)+ce(2),-ev(3,2).*pa(2)+ce(3),'b',1);
        ax = gca;
        ax.XTick = [];
        ax.YTick = [];
        [~,o] = legendflex([p1 p2 f1 f2], {'Convex hull','Centroid','Major axis','Minor axis'}, 'ref', gca, 'xscale', 0.4, 'anchor', [3 8], 'buffer', [-100 -140], 'box', 'off', 'FontSize',6);
        axis(xa);   
        title('Field characteristics','FontSize',fsiz,'FontWeight','normal')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
    
    



























