%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS3_binmorph_schematic small function to make Fig. S3
% Figure S3 contains a schematic demonstrating the binary morphology analysis
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible','off');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Function body
    x = zeros(32,32);
    x(1:22,5) = 1;
    x(5:26,15) = 1;
    x(12:32,25) = 1;
    x(1:10,25) = 1;

    x(5,4:15) = 1;
    x(12,19:28) = 1;
    x(26,20:31) = 1;
    x(30,1:14) = 1;
    x(24,11:17) = 1;

    subplot(2,2,[1 2])
    imshow(x)
    daspect([1 1 1])
    title('A')

    subplot(2,2,3)
    x2 = imerode(x,ones(1,5));
    x3 = imerode(x,ones(5,1));
    imshow(x2)
    daspect([1 1 1])
    % title(['{\Sigma} = ' num2str(sum(x2(:)))],'interpreter','tex')
    xlabel(['Proportion of total = ',num2str(sum(x2(:))/sum([x2(:);x3(:)]),2)])
    axis on
    ax = gca;
    ax.XTick = 16;
    ax.YTick = [];
    ax.XTickLabel = {['{\Sigma} = ' num2str(sum(x2(:)))]};

    subplot(2,2,4)
    imshow(x3)
    daspect([1 1 1])
    % title(['{\Sigma} = ' num2str(sum(x3(:)))],'interpreter','tex')
    xlabel(['Proportion of total = ',num2str(sum(x3(:))/sum([x2(:);x3(:)]),2)])
    axis on
    ax = gca;
    ax.XTick = 16;
    ax.YTick = [];
    ax.XTickLabel = {['{\Sigma} = ' num2str(sum(x3(:)))]};

    ax_vol = axes('Units','pixels','Position',[118 290 30 30]);           
    y1 = zeros(7,7);
    y1(4,2:6) = 1;
    imshow(y1)
    daspect([1 1 1])
    title('B')

    ax_vol = axes('Units','pixels','Position',[428 290 30 30]);           
    y1 = zeros(7,7);
    y1(2:6,4) = 1;
    imshow(y1)
    daspect([1 1 1])
    title('B')

    annotation('arrow',[.3 .3],[.75 .46],'LineWidth',1.5);
    annotation('line',[.3 .39],[.75 .75],'LineWidth',1.5);
    annotation('arrow',[.73 .73],[.75 .46],'LineWidth',1.5);
    annotation('line',[.73 .64],[.75 .75],'LineWidth',1.5);
    annotation('textbox','Units','pixels','Position',[420, 263, 300, 20],'string',['A {\theta} B'],'FontSize',ax.FontSize,'LineStyle','none','interpreter','tex'); 
    annotation('textbox','Units','pixels','Position',[110, 263, 300, 20],'string',['A {\theta} B'],'FontSize',ax.FontSize,'LineStyle','none','interpreter','tex'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    





























