%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS4_binmorph_schematic small function to make Fig. S4
% Figure S4 contains a schematic showing the different values extracted from autocorrelograms
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
fignow = figure('visible',fig_vis,'Position',[50,60,605,842]);
set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
set(gcf,'color','w'); % makes the background colour white
colormap(jet(256)); % to make sure the colormap is not the horrible default one

annotation('textbox','Units','pixels','Position',[5, 740, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
annotation('textbox','Units','pixels','Position',[5, 580, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Function body
%% ##################################### Schematics of the different values extracted
%% Autocorrelation
    ax_amap = axes('Units','pixels','Position',[40 620 120 120]);   
        dir = {[sdir '\775_27102016.mat'],14,3,775,161027};    
        cd(sdir);
        load(dir{1},'-mat','sdata');        
        
        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dir{2}) '_c' num2str(dir{3})];    
        part_now3 = 'lattice_3d';
        ratemap = sdata.(uci).(part_now3).ratemap;
        amap = sdata.(uci).(part_now3).autocorrelogram; 
        lx2 = sdata.(part_now3).lxrm;
        ly2 = sdata.(part_now3).lyrm;
        lz2 = sdata.(part_now3).lzrm;
        amap(amap < 0.2*nanmax(amap(:))) = NaN;
        pval = 10;
        amap = amap(pval+1:end-pval,pval+1:end-pval,pval+1:end-pval); % unpad
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);

        hold on
        edg = size(amap);
        ori = [.5 .5 .5]; 
        plotcube(edg,ori,0,0,0.3);        
        axis off       
        view(30,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on     
        anstr = 'Autocorrelation';
        annotation('textbox','Units','pixels','Position',[ax_amap.Position(1)+10 ax_amap.Position(2)+105, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none');            
        
%% Autocorrelation with X axis midline highlighted    
    ax_xmid = axes('Units','pixels','Position',ax_amap.Position+[130 0 0 0]);   
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);
        hold on
        edg = [3 size(amap,2) 3];
        ori = size(amap)./2-1.5;
        ori(2) = .5;
        plotcube(edg,ori,1,'b',0.3);
        edg = size(amap);
        ori = [.5 .5 .5]; 
        plotcube(edg,ori,0,0,0.3);        
        axis off       
        view(30,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on   
        anstr = 'Central along X';
        annotation('textbox','Units','pixels','Position',[ax_xmid.Position(1)+10 ax_xmid.Position(2)+105, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none');
        
%% Autocorrelation with Y axis midline highlighted            
    ax_ymid = axes('Units','pixels','Position',ax_xmid.Position+[130 0 0 0]);   
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);
        hold on
        edg = [size(amap,1) 3 3];
        ori = size(amap)./2-1.5;
        ori(1) = .5;
        plotcube(edg,ori,1,'b',0.3);         
        edg = size(amap);
        ori = [.5 .5 .5]; 
        plotcube(edg,ori,0,0,0.3);        
        axis off       
        view(30,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on        
        anstr = 'Central along Y';
        annotation('textbox','Units','pixels','Position',[ax_ymid.Position(1)+10 ax_ymid.Position(2)+105, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none');
        
%% Autocorrelation with Z axis midline highlighted            
    ax_zmid = axes('Units','pixels','Position',ax_ymid.Position+[130 0 0 0]);   
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);
        hold on
        edg = [3 3 size(amap,3)];
        ori = size(amap)./2-1.5;
        ori(3) = .5;
        plotcube(edg,ori,1,'b',0.3);  
        edg = size(amap);
        ori = [.5 .5 .5]; 
        plotcube(edg,ori,0,0,0.3);        
        axis off       
        view(30,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on         
        anstr = 'Central along Z';
        annotation('textbox','Units','pixels','Position',[ax_zmid.Position(1)+10 ax_zmid.Position(2)+105, 300, 20],'string',anstr,'FontSize',fsiz,'LineStyle','none','interpreter','none');        

%% colorbar for 3D amap
    axc_cmap = axes('Units','pixels','Position',[ax_zmid.Position(1)+140 ax_zmid.Position(2)+10 10 90]);
        cmap = repmat(reshape(1:100,[],1),1,1,2);
        cmap(cmap < 0.2*nanmax(cmap(:))) = NaN;
        vol3d('cdata',cmap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0.2*nanmax(cmap(:)) nanmax(cmap(:))]);
        axis xy on tight
        box on
        ax = gca;
        ax.XTick = [];
        ax.YTick = [20];
        ax.YTickLabel = {'20%'};
        text(0.5,-0.08,'0 Hz','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(0.5,1.08,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');        
        
%% ##################################### Example ratemap and autocorrelations
%% ratemap with vertical column
    ax_rmap1 = axes('Units','pixels','Position',[0 420 180 180]);       
        dir = {[sdir '\852_20032017.mat'],7,1,852,170320};    
        cd(sdir);
        load(dir{1},'-mat','sdata');             
        
        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dir{2}) '_c' num2str(dir{3})];    
        part_now3 = 'lattice_3d';
        ratemap = sdata.(uci).(part_now3).ratemap;
        amap = sdata.(uci).(part_now3).autocorrelogram; 
        lx2 = sdata.(part_now3).lxrm;
        ly2 = sdata.(part_now3).lyrm;
        lz2 = sdata.(part_now3).lzrm;
        ratemap(ratemap < 0.2*nanmax(ratemap(:))) = NaN;
        vol3d('cdata',ratemap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(ratemap(:))]);

        hold on
        edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
        ori = [min(lx2), min(ly2), min(lz2)]; 
        plotcube(edg,ori,0,0,0.3);
        axis off
        pad_valr = 6;
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on 

        anstr = sprintf('%s, %s, t%s, c%s',sdata.rat_num, sdata.date, num2str(dir{2}), num2str(dir{3}));
        annotation('textbox','Units','pixels','Position',[ax_rmap1.Position(1)+30 ax_rmap1.Position(2)+140, 300, 20],'string',anstr,'FontSize',6,'LineStyle','none','interpreter','none');        

%% autocorrelation of column
    ax_amap1 = axes('Units','pixels','Position',[ax_rmap1.Position(1)+160 ax_rmap1.Position(2)+35 120 120]);     
        amap(amap < 0.2*nanmax(amap(:))) = NaN;
        pval = 10;
        amap = amap(pval+1:end-pval,pval+1:end-pval,pval+1:end-pval); % unpad
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);

        hold on
        edg = size(amap);
        ori = [1 1 1]; 
        plotcube(edg,ori,0,0,0.3);        
        axis off      
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on     

%% graph of median values
    ax_g1 = axes('Units','pixels','Position',[ax_amap1.Position(1)+170 ax_rmap1.Position(2)+55 80 90]);           
        vals = sdata.(uci).(part_now3).down_sampled.obs_auto_info;
        stem(1,vals(1),'Color',colx); hold on;
        stem(2,vals(2),'Color',coly);
        stem(3,vals(3),'Color',colz);
        
        ax = gca;
        ax.XLim = [0.5 3.5];
        ax.YLim = [-.2 .8];
        ax.YTick = [-.2:0.2:.8];        
        xlabel('Axis')
        ax.XTickLabel = {'X','Y','Z'};
        ylabel('Median correlation (r)')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places  
    
%% graph of correlation x distance
    ax_g2 = axes('Units','pixels','Position',ax_g1.Position+[140 0 10 0]);           
        vals = sdata.(uci).(part_now3).down_sampled.obs_auto_vecs;    
        xi = (-30:30).*5;
        
        e1 = plot(xi,vals(1,:),'Color',colx); hold on;
        e2 = plot(xi,vals(2,:),'Color',coly);         
        e3 = plot(xi,vals(3,:),'Color',colz);         
        
        ax = gca;
        ax.XLim = [0 100];
        ax.YLim = [-.2 0.8];
        ax.YTick = [-.2:0.2:.8];
        yy = ylabel('Correlation (r)');   
        xlabel('Distance (cm)')      
        box off
        ax.YGrid = 'on';        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places                
        [~,o] = legendflex([e1 e2 e3], {'X','Y','Z'}, 'ref', gca, 'xscale', 0.6, 'anchor', [3 8], 'buffer', [2 -30], 'box', 'off', 'FontSize',6);
         
%% ##################################### Example ratemap and autocorrelations (2nd cell)        
%% ratemap with horizontal column        
    ax_rmap2 = axes('Units','pixels','Position',[ax_rmap1.Position(1) ax_rmap1.Position(2)-160 ax_rmap1.Position(3) ax_rmap1.Position(4)]);       
        dir = {[sdir '\775_28102016.mat'],10,1,775,161028};    
        cd(sdir);
        load(dir{1},'-mat','sdata');           
        
        % collect the data we want
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dir{2}) '_c' num2str(dir{3})];    
        part_now3 = 'lattice_3d';
        ratemap = imrotate(sdata.(uci).(part_now3).ratemap,-90);
        amap = imrotate(sdata.(uci).(part_now3).autocorrelogram,-90); 
        lx2 = sdata.(part_now3).lxrm;
        ly2 = sdata.(part_now3).lyrm;
        lz2 = sdata.(part_now3).lzrm;
        ratemap(ratemap < 0.2*nanmax(ratemap(:))) = NaN;
        vol3d('cdata',ratemap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(ratemap(:))]);

        hold on
        edg = [max(lx2)-min(lx2), max(ly2)-min(ly2), max(lz2)-min(lz2)];
        ori = [min(lx2), min(ly2), min(lz2)]; 
        plotcube(edg,ori,0,0,0.3);
        axis off tight
        pad_valr = 6;
        axis([min(lx2)-pad_valr,max(lx2)+pad_valr,min(ly2)-pad_valr,max(ly2)+pad_valr,min(lz2)-pad_valr,max(lz2)+pad_valr]);        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on 

        anstr = sprintf('%s, %s, t%s, c%s',sdata.rat_num, sdata.date, num2str(dir{2}), num2str(dir{3}));
        annotation('textbox','Units','pixels','Position',[ax_rmap2.Position(1)+30 ax_rmap2.Position(2)+140, 300, 20],'string',anstr,'FontSize',6,'LineStyle','none','interpreter','none');        
        
%% autocorrelation of horizontal
    ax_amap2 = axes('Units','pixels','Position',[ax_rmap1.Position(1)+160 ax_rmap2.Position(2)+35 120 120]);     
        amap(amap < 0.2*nanmax(amap(:))) = NaN;
        pval = 10;
        amap = amap(pval+1:end-pval,pval+1:end-pval,pval+1:end-pval); % unpad        
        vol3d('cdata',amap,'texture','3D');
        alphamap('rampup');
        colormap(gca,'jet');
        caxis([0 nanmax(amap(:))]);

        hold on
        edg = size(amap);
        ori = [1 1 1]; 
        plotcube(edg,ori,0,0,0.3);
        axis off tight        
        view(-240,22)
        daspect([1 1 1])
        camproj perspective
        rotate3d on     

%% graph of median values
    ax_g1 = axes('Units','pixels','Position',[ax_amap2.Position(1)+170 ax_rmap2.Position(2)+55 80 90]);           
        vals = sdata.(uci).(part_now3).down_sampled.obs_auto_info;
        stem(1,vals(1),'Color',colx); hold on;
        stem(2,vals(2),'Color',coly);
        stem(3,vals(3),'Color',colz);
        
        ax = gca;
        ax.XLim = [0.5 3.5];
        ax.YLim = [-.2 .8];
        ax.YTick = [-.2:0.2:.8];        
        xlabel('Axis')
        ax.XTickLabel = {'X','Y','Z'};
        ylabel('Median correlation (r)')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places  
    
%% graph of correlation x distance
    ax_g2 = axes('Units','pixels','Position',ax_g1.Position+[140 0 10 0]);           
        vals = sdata.(uci).(part_now3).down_sampled.obs_auto_vecs;    
        xi = (-30:30).*5;
        
        e1 = plot(xi,vals(1,:),'Color',colx); hold on;
        e2 = plot(xi,vals(2,:),'Color',coly);         
        e3 = plot(xi,vals(3,:),'Color',colz);         
        
        ax = gca;
        ax.XLim = [0 100];
        ax.YLim = [-.2 0.8];
        ax.YTick = [-.2:0.2:.8];
        yy = ylabel('Correlation (r)');   
        xlabel('Distance (cm)')      
        box off
        ax.YGrid = 'on';        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places                

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    




















