%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS5_coverage_speed small function to make Fig. S5
% Figure S5 is the first supplementary data figure and contains example trajectories, coverage and speed analysis
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE 
    fignow = figure('visible',fig_vis,'Position',[50,60,900,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 910, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none');         
    annotation('textbox','Units','pixels','Position',[5, 730, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[150, 730, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[280, 730, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[450, 730, 300, 20],'string','e','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[5, 515, 300, 20],'string','f','FontSize',18,'LineStyle','none','interpreter','none');     
    annotation('textbox','Units','pixels','Position',[300, 515, 300, 20],'string','g','FontSize',18,'LineStyle','none','interpreter','none');     
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Plot example trajectories
    dirs = {[sdir '\852_20032017.mat'],852,170320;... 
            [sdir '\851_13042017.mat'],851,170413;...
            [sdir '\896_16012018.mat'],896,180116;...            
            [sdir '\926_16042018.mat'],926,180416;... 
            [sdir '\924_25042018.mat'],924,180425;...             
            [sdir '\951_18092018.mat'],951,180918}; 

    ynow = 760;
    axpos = {[10 ynow 140 140],[140 ynow 140 140],[270 ynow 140 140],[400 ynow-30 190 190],[540 ynow-30 190 190],[680 ynow-30 190 190]};
    for cc = 1:size(dirs,1)  %; continue;  
        ax_c1 = axes('Units','pixels','Position',axpos{cc});      
            cd(sdir);
            load(dirs{cc,1},'-mat','sdata');  

            part_now3 = 'lattice_3d';
            lx = sdata.(part_now3).lx;
            ly = sdata.(part_now3).ly;
            lz = sdata.(part_now3).lz;             
            pox = sdata.(part_now3).pox;
            poy = sdata.(part_now3).poy;
            poz = sdata.(part_now3).poz;

            % plot  position data 
            cline(pox,poy,poz,poz); hold on;
            line(lx,ly,lz,'Color',[.5 .5 .5]);
            view(3)
            daspect([1 1 1])
            axis vis3d off tight xy
            camproj perspective
            rotate3d on       
            
            annstr = sprintf('Rat %d, %d, %.f mins',dirs{cc,2},dirs{cc,3},numel(pox).*(1./50)./60);
            if cc>3
                annotation('textbox','Units','pixels','Position',[axpos{cc}(1)+40, axpos{cc}(2)+160, 300, 20],'string',annstr,'FontSize',6,'LineStyle','none','interpreter','none');                     
            else
                annotation('textbox','Units','pixels','Position',[axpos{cc}(1)+15, axpos{cc}(2)+130, 300, 20],'string',annstr,'FontSize',6,'LineStyle','none','interpreter','none');     
            end
            
            if cc==1
                arrow3([-11.55 -600 31.38],[958.4 -600 31.38],'k-',2); 
                text(400,-750,31.38,'Y layers 1-6','Rotation',25,'FontSize',6,'HorizontalAlignment','center')
                arrow3([-220 -430 31.38],[-220 540 31.38],'k-',2);
                text(-350,-50,31.38,'X layers 1-6','Rotation',-38,'FontSize',6,'HorizontalAlignment','center')
                arrow3([-150 590 31.38],[-150 590 1001],'k-',2);
                text(-400,500,580,'Z layers 1-6','Rotation',90,'FontSize',6,'HorizontalAlignment','center')
                axis vis3d off tight xy
            elseif cc==4
                arrow3([500+200 162 -497.7],[1186+200 -234 62.3],'k-',2); % right arrow
                text(400,-750,250,'B layers 1-6','Rotation',33,'FontSize',6,'HorizontalAlignment','center')
                arrow3([-210.5-250 -234-50 262.3+50],[-210-250 558-50 822.4+50],'k-',2);
                text(50,-50,-300,'A layers 1-6','Rotation',-15,'FontSize',6,'HorizontalAlignment','center')
                arrow3([475.4 162 -497.7],[-210.5 -234 62.3],'k-',2); % bottom
                text(-400,300,350,'C layers 1-6','Rotation',-60,'FontSize',6,'HorizontalAlignment','center')
                axis vis3d off tight xy                
            end
    end
    cd(sdir);

%% ##################################### %% maze coverage boxplot
ynow = 580;
ax_D = axes('Units','pixels','Position',[50 ynow 80 130]);
    pc1 = bdata.path_coverage(pb_idx_la1);
    pc2 = bdata.path_coverage(pb_idx_la2);
    [H,P1] = lillietest(pc1);    
    [H,P2] = lillietest(pc2); 
    
    disp(sprintf('Path coverage:'))       
    disp(sprintf('\tmedians: %.3f, %.3f',nanmedian(pc1),nanmedian(pc2)))
    disp(sprintf('\tnormal?: %.3f, %.3f',P1,P2))   

    [ds,gs] = vectorDATAGROUP([],pc1,pc2);        
    boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{collt,coldi},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{collt,coldi},'dotalpha',0.8);
    
    box off
    ax = gca;
    ax.XTick = [1 2];
    ax.XTickLabel = {m2name m3name};    
    ax.XTickLabelRotation = 45;    
    ax.YLim = [0 100];
    ax.YTick = [0:25:100];
    ax.XLim = [0.5 2.5];
    ax.YGrid = 'on';
    ylabel('Maze coverage (%)')
    set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

        % sig bridges, stats, text
        disp('Path coverage:')    
        stats_and_bars(ds,gs,[],flnw,fsiz);
        disp(sprintf('\tnormal?: %.3f, %.3f',P1,P2)) 

%% ##################################### %% top bottom dwell time boxplot
    ax_Hright = axes('Units','pixels','Position',ax_D.Position+[150 0 0 0]); 
        rats = unique(bdata.rat(pb_idx_sq1));
        thig_vec1 = NaN(length(rats),1);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_sq1;
            thig_vec1(rr) = nanmean(bdata.thigmotax_ratio(idx));
        end   

        rats = unique(bdata.rat(pb_idx_la1));
        thig_vec2 = NaN(length(rats),1);
        tobo_vec1 = NaN(length(rats),1);    
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la1;
            thig_vec2(rr) = nanmean(bdata.thigmotax_ratio(idx));
            tobo_vec1(rr) = nanmean(bdata.endtoend_ratio(idx));
        end  

        rats = unique(bdata.rat(pb_idx_la2));
        thig_vec3 = NaN(length(rats),1);
        tobo_vec2 = NaN(length(rats),1);        
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la2;
            thig_vec3(rr) = nanmean(bdata.thigmotax_ratio(idx));
            tobo_vec2(rr) = nanmean(bdata.endtoend_ratio(idx));        
        end  

        [ds,gs] = vectorDATAGROUP([],tobo_vec1,tobo_vec2);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{collt,coldi},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m2name m3name};    
        ax.XTickLabelRotation = 45;        
        ax.XLim = [0.5 2.5];
        ax.YLim = [0 5];
        y1 = ax.YLim;
        ylabel('Time in bottom half / top half');
        line(ax.XLim,[1 1],'Color','k','LineWidth',flnw);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % sig bridges, stats, text
            disp('Dwell time ratios t/b:')  
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;
            set(ax,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places            

            disp('TopBot lattice:')    
            [H,P1] = lillietest(tobo_vec1);       
            [p,~,s] = signrank(tobo_vec1,1,'method','approximate');
            u3 = mes(tobo_vec1,1,'U3_1');
            disp(sprintf('\tz = %.3f, p = %.3f, u3 = %.3f',s.zval,p,u3.U3_1))
            disp(sprintf('\tMd = %.2f, normal?: %.3f',nanmedian(tobo_vec1),P1))     

            disp('TopBot diagonal:')    
            [H,P2] = lillietest(tobo_vec2);       
            [p,~,s] = signrank(tobo_vec2,1,'method','approximate');
            u3 = mes(tobo_vec2,1,'U3_1');        
            disp(sprintf('\tz = %.3f, p = %.3f, u3 = %.3f',s.zval,p,u3.U3_1))
            disp(sprintf('\tMd = %.2f, normal?: %.3f',nanmedian(tobo_vec2),P2))  

%% ##################################### %% outer inner half boxplot  
    ax_Hleft = axes('Units','pixels','Position',ax_D.Position+[280 0 0 0]);    
        [ds,gs] = vectorDATAGROUP([],thig_vec1,thig_vec2,thig_vec3);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colsq,collt,coldi},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colsq,collt,coldi},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTickLabel = {m1name m2name m3name};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 5];
        ylabel('Time in outer half / inner half');
        line(ax.XLim,[1 1],'Color','k','LineWidth',flnw);
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        ax1 = ax.YLim;

            % sig bridges, stats, text
            disp('Dwell time ratios:')
            ax.YLim = ax1;        
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = ax1;        

            disp('Thigmotax square:')    
            [H,P1] = lillietest(thig_vec1);
            [p,~,s] = signrank(thig_vec1,1,'method','approximate');
            u3 = mes(thig_vec1,1,'U3_1');        
            disp(sprintf('\tz = %.3f, p = %.3f, u3 = %.3f',s.zval,p,u3.U3_1))
            disp(sprintf('\tMd = %.2f, normal?: %.3f',nanmedian(thig_vec1),P1))

            disp('Thigmotax lattice:')    
            [H,P2] = lillietest(thig_vec2);
            [p,~,s] = signrank(thig_vec2,1,'method','approximate');
            u3 = mes(thig_vec2,1,'U3_1');        
            disp(sprintf('\tz = %.3f, p = %.3f, u3 = %.3f',s.zval,p,u3.U3_1))
            disp(sprintf('\tMd = %.2f, normal?: %.3f',nanmedian(thig_vec2),P2))  

            disp('Thigmotax diagonal:')    
            [H,P3] = lillietest(thig_vec3);       
            [p,~,s] = signrank(thig_vec3,1,'method','approximate');
            u3 = mes(thig_vec3,1,'U3_1');        
            disp(sprintf('\tz = %.3f, p = %.3f, u3 = %.3f',s.zval,p,u3.U3_1))
            disp(sprintf('\tMd = %.2f, normal?: %.3f',nanmedian(thig_vec3),P3))    

%% colorbar for positions       
    axc = axes('Units','pixels','Position',[650 740 120 10]);
        imagesc(((1:256)));
        colormap(axc,'jet')
        axis xy off
        text(-0.1,0.5,'Min','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');
        text(1.1,0.5,'Max','FontSize',fsiz,'Units','normalized','HorizontalAlignment','center','Color','k');

%% ##################################### %% average speed along every axis boxplot
%% Arena
    ax_Fb = axes('Units','pixels','Position',[500 ynow 70 130]);    
        rats = unique(bdata.rat(pb_idx_sq1));
        datn = NaN(length(rats),3);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_sq1;
            datn(rr,1) = mean(nanmean(bdata.speed_x(idx),2));
            datn(rr,2) = mean(nanmean(bdata.speed_y(idx),2)); 
            datn(rr,3) = mean(nanmean(bdata.speed_z(idx),2)); 
        end   
        ds = datn(:,1:3);
        ds = ds(:);    
        gs = [ones(size(datn(:,1)))*1; ones(size(datn(:,2)))*2; ones(size(datn(:,3)))*3];

        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'X' 'Y' 'Z'};        
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 .15];
        y1 = ax.YLim;
        xlabel(m1name);  
        ylabel('Average speed (m/s)');
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black      
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f')) % change Ytick labels to have the same number of decimal places    

            % sig bridges, stats, text
            disp('Diffusivity lattice:')
            ax.YLim = y1;
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;

%% aligned            
    ax_Fb2 = axes('Units','pixels','Position',ax_Fb.Position+[80 0 0 0]);    
        rats = unique(bdata.rat(pb_idx_la1));
        datn = NaN(length(rats),3);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la1;
            datn(rr,1) = mean(nanmean(bdata.speed_x(idx),2));
            datn(rr,2) = mean(nanmean(bdata.speed_y(idx),2)); 
            datn(rr,3) = mean(nanmean(bdata.speed_z(idx),2)); 
        end   
        ds = datn(:,1:3);
        ds = ds(:);    
        gs = [ones(size(datn(:,1)))*1; ones(size(datn(:,2)))*2; ones(size(datn(:,3)))*3];

        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'X' 'Y' 'Z'};        
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 .6];
        ax.YTick = [];
        xlabel(m2name);  
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black      

            % sig bridges, stats, text
            disp('Diffusivity lattice:')   
            ax.YLim = y1;
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;

%% tilted XYZ         
    ax_Fc3 = axes('Units','pixels','Position',ax_Fb.Position+[160 0 0 0]);    
        rats = unique(bdata.rat(pb_idx_la2));
        datn = NaN(length(rats),3);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la2;
            datn(rr,1) = mean(nanmean(bdata.speed_x(idx),2));
            datn(rr,2) = mean(nanmean(bdata.speed_y(idx),2)); 
            datn(rr,3) = mean(nanmean(bdata.speed_z(idx),2)); 
        end   
        ds = datn(:,1:3);
        ds = ds(:);    
        gs = [ones(size(datn(:,1)))*1; ones(size(datn(:,2)))*2; ones(size(datn(:,3)))*3];

        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{colx,coly,colz},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'X' 'Y' 'Z'};        
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        xlabel(m3name);    
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black      

            % sig bridges, stats, text
            disp('Diffusivity diagonal:')
            ax.YLim = y1;
            stats_and_bars(ds,gs,[],flnw,fsiz,0.14);
            ax.YLim = y1;

% tilted ABC            
    ax_Fc4 = axes('Units','pixels','Position',ax_Fb.Position+[240 0 0 0]);    
        rats = unique(bdata.rat(pb_idx_la2));
        datn = NaN(length(rats),3);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la2;
            datn(rr,1) = mean(nanmean(bdata.speed_a(idx),2));
            datn(rr,2) = mean(nanmean(bdata.speed_b(idx),2)); 
            datn(rr,3) = mean(nanmean(bdata.speed_c(idx),2)); 
        end   
        ds = datn(:,1:3);
        ds = ds(:);    
        gs = [ones(size(datn(:,1)))*1; ones(size(datn(:,2)))*2; ones(size(datn(:,3)))*3];

        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',20,'dotcolor',{cola,colb,colc},'dotalpha',0.8);
        box off
        ax = gca;
        ax.XTick = [1:3];
        ax.XTickLabel = {'A' 'B' 'C'};        
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        xlabel(m3name);    
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black      

            % sig bridges, stats, text
            disp('Diffusivity diagonal:')  
            ax.YLim = y1;
            stats_and_bars(ds,gs,[],flnw,fsiz,0.14);
            ax.YLim = y1;        
          
%% ##################################### %% Run time at each speed (speed profiles)           
    ynow = 360;
    ax1 = axes('Units','pixels','Position',[50 ynow 220 130]); % proportion of time at every speed
        % square
        idx_now = pc_idx_sq1;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time1 = NaN(length(uidx),length(sval));
        stup_data1 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time1(d,:) = v;        
            stup_data1(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time1 = fdat_time1 ./ nansum(fdat_time1,2);
        mtime1 = nanmean(fdat_time1,1); % mean firing rate per speed
        stime1 = nanstd(fdat_time1,[],1) ./ sqrt(sum(~isnan(fdat_time1),1)); % SEM of firing rate per speed           
            
        % aligned
        idx_now = pc_idx_la1;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time2 = NaN(length(uidx),length(sval));
        stup_data2 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time2(d,:) = v;        
            stup_data2(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time2 = fdat_time2 ./ nansum(fdat_time2,2);
        mtime2 = nanmean(fdat_time2,1); % mean firing rate per speed
        stime2 = nanstd(fdat_time2,[],1) ./ sqrt(sum(~isnan(fdat_time2),1)); % SEM of firing rate per speed            
                      
        % tilted
        idx_now = pc_idx_la2;
        [~,uidx] = unique(tdata.date(idx_now,:));
        sval = 1:2:100;
        fdat_time3 = NaN(length(uidx),length(sval));
        stup_data3 = NaN(length(uidx),2);
        for d = 1:length(uidx)
            dnow = tdata.theta_speed_curve{uidx(d),:};
            tnow = tdata.theta_speed_time{uidx(d),:};
            if isempty(dnow)
                continue
            end
            v = interp1(dnow(:,1),tnow,sval);
            fdat_time3(d,:) = v;        
            stup_data3(d,:) = [tdata.date(uidx(d)) tdata.rat(uidx(d))];
        end
        fdat_time3 = fdat_time3 ./ nansum(fdat_time3,2);
        mtime3 = nanmean(fdat_time3,1); % mean firing rate per speed
        stime3 = nanstd(fdat_time3,[],1) ./ sqrt(sum(~isnan(fdat_time3),1)); % SEM of firing rate per speed            
 
        [e1,e1b] = boundedline(sval(:),mtime1(:),stime1(:)); hold on;
        set(e1,'Color','k');
        set(e1b,'FaceColor',colsq,'FaceAlpha',0.6);
        [e2,e2b] = boundedline(sval(:),mtime2(:),stime2(:)); hold on;
        set(e2,'Color','k');
        set(e2b,'FaceColor',collt,'FaceAlpha',0.6);        
        [e3,e3b] = boundedline(sval(:),mtime3(:),stime3(:)); hold on;        
        set(e3,'Color','k');
        set(e3b,'FaceColor',coldi,'FaceAlpha',0.6);    
        uistack(e1b,'top')
        uistack(e1,'top')
        
        ax = gca;
        ax.XLim = [0 50];
        ax.XTick = [0:10:50];       
        ax.YLim(1) = 0;
        grid on
        box off
        xlabel('Speed (cm/s)')
        ylabel('Proportion of time')
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.2f'))
        
        ll = legend([e1b e2b e3b],{m1name,m2name,m3name},'Location','NorthEast');
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.02 0.01 0 0])             

%% ##################################### %% dwell time layers 
%% proportion of time each layer aligned
    ax_Htop = axes('Units','pixels','Position',[350 ynow 220 130]);     
        rats = unique(bdata.rat(pb_idx_la1));
        x_dwell = NaN(length(rats),6);
        y_dwell = NaN(length(rats),6);
        z_dwell = NaN(length(rats),6);
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la1;
            x_dwell(rr,:) = nanmean(bdata.dwell_layer_X(idx,2:7) ./ nansum(bdata.dwell_layer_X(idx,2:7),2),1);
            y_dwell(rr,:) = nanmean(bdata.dwell_layer_Y(idx,2:7) ./ nansum(bdata.dwell_layer_Y(idx,2:7),2),1);
            z_dwell(rr,:) = nanmean(bdata.dwell_layer_Z(idx,2:7) ./ nansum(bdata.dwell_layer_Z(idx,2:7),2),1);
        end          
        mvalx = nanmean(x_dwell,1);
        svalx = nanstd(x_dwell,[],1) ./ sqrt(sum(~isnan(x_dwell),1));
        mvaly = nanmean(y_dwell,1);
        svaly = nanstd(y_dwell,[],1) ./ sqrt(sum(~isnan(y_dwell),1));    
        mvalz = nanmean(z_dwell,1);
        svalz = nanstd(z_dwell,[],1) ./ sqrt(sum(~isnan(z_dwell),1));    

        p1 = plot(1:6,mvalx,'Color',colx); hold on;
        errorbar(1:6,mvalx,svalx,'Color',colx);
        p2 = plot(1:6,mvaly,'Color',coly);
        errorbar(1:6,mvaly,svaly,'Color',coly);
        p3 = plot(1:6,mvalz,'Color',colz);
        errorbar(1:6,mvalz,svalz,'Color',colz);

        ax = gca;
        ax.XLim = [.5 6.5];
        ax.YLim = [0 .4];
        y1 = ax.YLim;
        box off
        ax.XTick = 1:6;
        ax.YTick = 0:0.1:0.4;
        xlabel('Lattice layer')
        yl = ylabel('Proportion of time');
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 
        ax.YGrid = 'on';

        ll = legend([p1 p2 p3],{'X','Y','Z'},'FontSize',5);
        legend boxoff
        title('Aligned','FontWeight','normal','FontSize',fsiz)

%% proportion of time each layer tilted        
    ax_Hbot = axes('Units','pixels','Position',ax_Htop.Position+[240 0 0 0]);     
        rats = unique(bdata.rat(pb_idx_la2));
        x_dwell = NaN(length(rats),6);
        y_dwell = NaN(length(rats),6);
        z_dwell = NaN(length(rats),6);    
        for rr = 1:length(rats)
            idx = bdata.rat==rats(rr) & pb_idx_la2;
            x_dwell(rr,:) = nanmean(bdata.dwell_layer_A(idx,2:7) ./ nansum(bdata.dwell_layer_A(idx,2:7),2),1);
            y_dwell(rr,:) = nanmean(bdata.dwell_layer_B(idx,2:7) ./ nansum(bdata.dwell_layer_B(idx,2:7),2),1);
            z_dwell(rr,:) = nanmean(bdata.dwell_layer_C(idx,2:7) ./ nansum(bdata.dwell_layer_C(idx,2:7),2),1);
        end          
        x_dwell = fliplr(x_dwell);
        mvalx = nanmean(x_dwell,1);
        svalx = nanstd(x_dwell,[],1) ./ sqrt(sum(~isnan(x_dwell),1));
        mvaly = nanmean(y_dwell,1);
        svaly = nanstd(y_dwell,[],1) ./ sqrt(sum(~isnan(y_dwell),1));    
        mvalz = nanmean(z_dwell,1);
        svalz = nanstd(z_dwell,[],1) ./ sqrt(sum(~isnan(z_dwell),1));    

        p1 = plot(1:6,mvalx,'Color',cola); hold on;
        errorbar(1:6,mvalx,svalx,'Color',cola);
        p2 = plot(1:6,mvaly,'Color',colb);
        errorbar(1:6,mvaly,svaly,'Color',colb);
        p3 = plot(1:6,mvalz,'Color',colc);
        errorbar(1:6,mvalz,svalz,'Color',colc);

        ax = gca;
        ax.XLim = [.5 6.5];
        ax.YLim = y1;
        box off        
        set(ax,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places    
        ax.XTick = 1:6;
        ax.YTick = 0:0.1:0.4;
        xlabel('Lattice layer')
        ax.YGrid = 'on';
        ax.YColor = 'none';

        ll = legend([p1 p2 p3],{'A','B','C'},'FontSize',5);
        legend boxoff
        title('Tilted','FontWeight','normal','FontSize',fsiz)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        



