%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS9_zingg_results small function to make Fig. S9
% Figure S9 shows the result of the Zingg shape classification on all place fields
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible',fig_vis,'Position',[50,60,651,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    set(0,'DefaultAxesTitleFontWeight','normal');
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts
    flnw = 0.5; % the line width for different plots

%% ##################################### %% Zingg shape classification key 
    ax_F1 = axes('Units','pixels','Position',[50 610 50 50]);      
    [x,y,z] = ellipsoid(0,0,0,1,1,1,30);
    s = surf(x,y,z);
    s.EdgeColor = 'k';
    s.EdgeAlpha = .08;
    axis equal off

    ax_F2 = axes('Units','pixels','Position',[ax_F1.Position(1) 570 50 50]);      
    [x,y,z] = ellipsoid(0,0,0,4,1,1,30);
    s = surf(x,y,z);
    s.EdgeColor = 'k';
    s.EdgeAlpha = .08;
    axis equal off

    ax_F3 = axes('Units','pixels','Position',[ax_F1.Position(1) 535 50 50]);      
    [x,y,z] = ellipsoid(0,0,0,3,2,1,30);
    s = surf(x,y,z);
    s.EdgeColor = 'k';
    s.EdgeAlpha = .08;
    axis equal off

    ax_F4 = axes('Units','pixels','Position',[ax_F1.Position(1) 490 50 50]);      
    [x,y,z] = ellipsoid(0,0,0,3,3,0.8,30);
    s = surf(x,y,z);
    s.EdgeColor = 'k';
    s.EdgeAlpha = .08;
    axis equal off

    annotation('textbox','Units','pixels','Position',[ax_F1.Position(1)+45, 630, 300, 20],'string','Equant','FontSize',8,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[ax_F1.Position(1)+45, 590, 300, 20],'string','Prolate','FontSize',8,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[ax_F1.Position(1)+45, 550, 300, 20],'string','Bladed','FontSize',8,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[ax_F1.Position(1)+45, 510, 300, 20],'string','Oblate','FontSize',8,'LineStyle','none','interpreter','none'); 

%% ##################################### %% Setup Zingg classification parameters    
    R = 3/2; a = 7; b = 7; v1 = [];% bottom right
    for c = 7:-0.1:b/R
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v1(end+1,:) = [ax(:) ay(:)];
    end
    R = 3/2; a = 7; b = 7; v2 = []; % bottom left
    for c = b/R:-0.1:0
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v2(end+1,:) = [ax(:) ay(:)];
    end
    c = 7; b = R*c; v3 = []; % bottom middle diagonal
    for a = 10.5:0.1:15.75
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v3(end+1,:) = [ax(:) ay(:)];
    end  
    c = 7; b = R*c; v4 = []; % top middle diagonal
    for a = 15.75:0.1:100
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v4(end+1,:) = [ax(:) ay(:)];
    end  
    b = 7; a = R*b; v5 = []; % middle right
    for c = 7:-0.1:4.66
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v5(end+1,:) = [ax(:) ay(:)];
    end
    b = 7; a = R*b; v6 = []; % middle left
    for c = 4.66:-0.1:0
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v6(end+1,:) = [ax(:) ay(:)];
    end
    b = 7; c = 7; v7 = []; % right bottom diagonal
    for a = 7:0.1:10.5
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v7(end+1,:) = [ax(:) ay(:)];
    end 
    b = 7; c = 7; v8 = [];
    for a = 10.5:0.1:100 % right top diagonal
        t = sqrt(sum([a b c].^2)); ax = c/t; ay = a/t; v8(end+1,:) = [ax(:) ay(:)];
    end 

%% ##################################### %% Arena
    ax_F = axes('Units','pixels','Position',[ax_F1.Position(1)+130+40 500 90 150]);      
        cols = [rgb('Black');rgb('Blue');rgb('Red');rgb('Green')];
        vals = fdata.field_principalaxes(pf_idx_sq1,:)*5;
        axa = vals(:,1) ./ sqrt(sum(vals.^2,2));
        axc = vals(:,3) ./ sqrt(sum(vals.^2,2));
        sq1_e = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100;
        sq1_p = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
        sq1_b = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
        sq1_o = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;

        shuff = 100;
        rvals = NaN(shuff,4);
        for ss = 1:shuff
            vals2 = vals(randperm(numel(vals)));
            vals2 = reshape(vals2,size(vals));
            vals2 = sort(vals2,2,'descend');
            axa = vals2(:,1) ./ sqrt(sum(vals2.^2,2));
            axc = vals2(:,3) ./ sqrt(sum(vals2.^2,2));        
            rvals(ss,1) = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100; 
            rvals(ss,2) = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,3) = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,4) = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;
        end
        t95 = [prctile(rvals(:,1),99) prctile(rvals(:,2),99) prctile(rvals(:,3),99) prctile(rvals(:,4),99)];

        stem(1,sq1_e,'Color',cols(1,:)); hold on;
        stem(2,sq1_p,'Color',cols(2,:));
        stem(3,sq1_b,'Color',cols(3,:));
        stem(4,sq1_o,'Color',cols(4,:));
        sq1_zingg = [sq1_e sq1_p sq1_b sq1_o];

        offset = 5;
        if sq1_e > t95(1)
            text(1,sq1_e+offset,'**','HorizontalAlignment','center');
        end
        if sq1_p > t95(2)
            text(2,sq1_p+offset,'**','HorizontalAlignment','center');
        end    
        if sq1_b > t95(3)
            text(3,sq1_b+offset,'**','HorizontalAlignment','center');
        end    
        if sq1_o > t95(4)
            text(4,sq1_o+offset,'**','HorizontalAlignment','center');
        end

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'equant' 'prolate' 'bladed' 'oblate'};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 4.5];
        ax.YLim = [0 50];   
        ax.YTick = [0:10:50];
        y1 = ax.YLim;
        ylabel(sprintf('Place fields (%%)'))
        xlabel(m1name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places

            disp(sprintf('Zingg square'))           
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',sq1_e,sq1_p,sq1_b,sq1_o))
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',t95(1),t95(2),t95(3),t95(4)))

%% ##################################### %% Aligned        
    ax_F = axes('Units','pixels','Position',[ax_F1.Position(1)+195+40+30 500 90 150]);      
        vals = fdata.field_principalaxes(pf_idx_la1,:)*5;
        axa = vals(:,1) ./ sqrt(sum(vals.^2,2));
        axc = vals(:,3) ./ sqrt(sum(vals.^2,2));
        la1_e = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100;
        la1_p = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
        la1_b = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
        la1_o = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;    

        rvals = NaN(shuff,4);
        for ss = 1:shuff
            vals2 = vals(randperm(numel(vals)));
            vals2 = reshape(vals2,size(vals));
            vals2 = sort(vals2,2,'descend');
            axa = vals2(:,1) ./ sqrt(sum(vals2.^2,2));
            axc = vals2(:,3) ./ sqrt(sum(vals2.^2,2));        
            rvals(ss,1) = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100; 
            rvals(ss,2) = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,3) = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,4) = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;
        end
        t95 = [prctile(rvals(:,1),99) prctile(rvals(:,2),99) prctile(rvals(:,3),99) prctile(rvals(:,4),99)];    
        stem(1,la1_e,'Color',cols(1,:)); hold on;
        stem(2,la1_p,'Color',cols(2,:));
        stem(3,la1_b,'Color',cols(3,:));
        stem(4,la1_o,'Color',cols(4,:));
        la1_zingg = [la1_e la1_p la1_b la1_o];

        if la1_e > t95(1)
            text(1,la1_e+offset,'**','HorizontalAlignment','center');
        end
        if la1_p > t95(2)
            text(2,la1_p+offset,'**','HorizontalAlignment','center');
        end    
        if la1_b > t95(3)
            text(3,la1_b+offset,'**','HorizontalAlignment','center');
        end    
        if la1_o > t95(4)
            text(4,la1_o+offset,'**','HorizontalAlignment','center');
        end    

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'equant' 'prolate' 'bladed' 'oblate'};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 4.5];
        ax.YLim = y1;   
        ax.YTick = [];
        xlabel(m2name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places

            disp(sprintf('Zingg lattice'))           
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',la1_e,la1_p,la1_b,la1_o))
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',t95(1),t95(2),t95(3),t95(4)))

%% ##################################### %% Tilted            
    ax_F = axes('Units','pixels','Position',[ax_F1.Position(1)+260+40+60 500 90 150]);      
        vals = fdata.field_principalaxes(pf_idx_la2,:)*5;
        axa = vals(:,1) ./ sqrt(sum(vals.^2,2));
        axc = vals(:,3) ./ sqrt(sum(vals.^2,2));
        la2_e = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100;
        la2_p = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
        la2_b = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
        la2_o = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;

        rvals = NaN(shuff,4);
        for ss = 1:shuff
            vals2 = vals(randperm(numel(vals)));
            vals2 = reshape(vals2,size(vals));
            vals2 = sort(vals2,2,'descend');
            axa = vals2(:,1) ./ sqrt(sum(vals2.^2,2));
            axc = vals2(:,3) ./ sqrt(sum(vals2.^2,2));        
            rvals(ss,1) = sum(inpolygon(axc,axa,[v1(:,1);v3(:,1);flipud(v5(:,1));flipud(v7(:,1))],[v1(:,2);v3(:,2);flipud(v5(:,2));flipud(v7(:,2))])) ./ numel(axa) .* 100; 
            rvals(ss,2) = sum(inpolygon(axc,axa,[v5(:,1);v4(:,1);0;flipud(v8(:,1))],[v5(:,2);v4(:,2);1;flipud(v8(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,3) = sum(inpolygon(axc,axa,[v6(:,1);0;0;flipud(v4(:,1))],[v6(:,2);v6(end,2);1;flipud(v4(:,2))])) ./ numel(axa) .* 100;
            rvals(ss,4) = sum(inpolygon(axc,axa,[v2(:,1);0;0;flipud(v6(:,1));flipud(v3(:,1))],[v2(:,2);v2(end,2);v6(end,2);flipud(v6(:,2));flipud(v3(:,2))])) ./ numel(axa) .* 100;
        end
        t95 = [prctile(rvals(:,1),99) prctile(rvals(:,2),99) prctile(rvals(:,3),99) prctile(rvals(:,4),99)];

        stem(1,la2_e,'Color',cols(1,:)); hold on;
        stem(2,la2_p,'Color',cols(2,:));
        stem(3,la2_b,'Color',cols(3,:));
        stem(4,la2_o,'Color',cols(4,:));
        la2_zingg = [la2_e la2_p la2_b la2_o];

        if la2_e > t95(1)
            text(1,la2_e+offset,'**','HorizontalAlignment','center');
        end
        if la2_p > t95(2)
            text(2,la2_p+offset,'**','HorizontalAlignment','center');
        end    
        if la2_b > t95(3)
            text(3,la2_b+offset,'**','HorizontalAlignment','center');
        end    
        if la2_o > t95(4)
            text(4,la2_o+offset,'**','HorizontalAlignment','center');
        end     

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'equant' 'prolate' 'bladed' 'oblate'};    
        ax.XTickLabelRotation = 45;    
        ax.XLim = [0.5 4.5];
        ax.YLim = y1;   
        ax.YTick = [];
        xlabel(m3name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places

            disp(sprintf('Zingg diagonal'))           
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',la2_e,la2_p,la2_b,la2_o))
            disp(sprintf('\t%.3f, %.3f, %.3f, %.3f',t95(1),t95(2),t95(3),t95(4))) 
                  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
        paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            
            