%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS11_axis_lengths_elongation small function to make Fig. S11
% Figure S11 shows multiple further analyses on field elongation
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fignow = figure('visible',fig_vis,'Position',[50,60,651,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    set(0,'DefaultAxesTitleFontWeight','normal');
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts
    flnw = 0.5; % the line width for different plots

    annotation('textbox','Units','pixels','Position',[5, 900, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 670, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 480, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none');
    annotation('textbox','Units','pixels','Position',[5, 300, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none');

%% ##################################### %% PDF of field sizes with overlapping space highlighted
    ax_Esq = axes('Units','pixels','Position',[50 740 180 110]);       
        xi = 1:150;        
        bw = 5;     
        vx = fdata.field_bounding_box(pf_idx_la1,4).*5;
        vy = fdata.field_bounding_box(pf_idx_la1,5).*5;
        vz = fdata.field_bounding_box(pf_idx_la1,6).*5;       
        [~,~,~,dx] = histDENSITY(vx,xi,bw);
        [~,~,~,dy] = histDENSITY(vy,xi,bw);
        [~,~,~,dz] = histDENSITY(vz,xi,bw);
        dx = dx.*100;
        dy = dy.*100;
        dz = dz.*100;
        dxy = nanmean([dx dy],2);

        p1 = plot(xi,dxy,'Color','b','LineWidth',flnw); hold on;
        p3 = plot(xi,dz,'Color',colz,'LineWidth',flnw);
        xlabel('Field extent (cm)')
        ylabel('Fields (%)')      
        box off
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        ax = gca;
        ax.YLim = [0 2.5];
        ax.YTick = [0:0.5:2.5];
        ax.YTickLabel = {'0.0','0.5','1.0','1.5','2.0','2.5'};
        hold on
        idx = xi>=29.6 & xi < 80.2;
        xp = [xi(idx) fliplr(xi(idx))];
        yp = [dz(idx); flipud(dxy(idx))];
        patch(xp(:),yp(:),'g','FaceAlpha',.5,'EdgeColor','none');

        idx = xi>=80.2 & xi < 120.6;
        xp = [xi(idx) fliplr(xi(idx))];
        yp = [dxy(idx); flipud(dz(idx))];
        patch(xp(:),yp(:),'r','FaceAlpha',.5,'EdgeColor','none');            

        ll = legend([p1 p3],{'XY','Z'});
        legend boxoff            
    
%% ##################################### %% Example cells with elongation
        xs = [ax_Esq.Position(1)+220,ax_Esq.Position(1)+310,ax_Esq.Position(1)+400,ax_Esq.Position(1)+490,ax_Esq.Position(1)+220,ax_Esq.Position(1)+310,ax_Esq.Position(1)+400,ax_Esq.Position(1)+490];
        ys = [ax_Esq.Position(2)-30, ax_Esq.Position(2)-30, ax_Esq.Position(2)-30, ax_Esq.Position(2)-30, ax_Esq.Position(2)+70, ax_Esq.Position(2)+70, ax_Esq.Position(2)+70, ax_Esq.Position(2)+70];
%         dirs = {'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\896_P11_32_HPC\180119\klustest3\kwiktint',15,8,896,190118;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\894_P9_32_HPC\171221\klustest3\kwiktint',11,1,894,211217;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\852_P3_16_HPC\170817_kk_kt_ll_k3\klustest3\kwiktint',8,1,852,170817;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\770_K1_36_HPC\170314_kk_kt_ll_k3\klustest3\kwiktint',15,2,770,140317;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\896_P11_32_HPC\180119\klustest3\kwiktint',12,3,896,190118;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\894_P9_32_HPC\180118\klustest3\kwiktint',15,5,894,180118;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\852_P3_16_HPC\170810_kk_kt_ll_k3\klustest3\kwiktint',8,2,852,100817;...
%                 'Y:\Jeffery lab\Roddy G\Experiments\Lattice Maze\Data\Place cells\851_P2_16_HPC\170413_kk_kt_ll_k3\klustest3\kwiktint',5,1,851,130417};              
        dirs = {[sdir '\896_19012018.mat'],15,8,896,190118;...
                [sdir '\894_21122017.mat'],11,1,894,211217;...
                [sdir '\852_17082017.mat'],8,1,852,170817;...
                [sdir '\770_14032017.mat'],15,2,770,140317;...
                [sdir '\896_19012018.mat'],12,3,896,190118;...
                [sdir '\894_18012018.mat'],15,5,894,180118;...
                [sdir '\852_10082017.mat'],8,2,852,100817;...
                [sdir '\851_13042017.mat'],5,1,851,130417};              

        cols = {'r','r','r','r','g','g','g','g'};            
        for dd = 1:8
            disp(sprintf('\t...cell: %d',dd));
            cd(sdir);
            load(dirs{dd,1},'-mat','sdata');   

            % collect the data we want
            uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dirs{dd,2}) '_c' num2str(dirs{dd,3})]; 
            dat_now = sdata.(uci);    
            part_now3 = 'lattice_3d';

            % plot ratemap
            ax_1 = axes('Units','pixels','Position',[xs(dd) ys(dd) 80 80]);    
                dwellmap = sdata.(part_now3).dwellmap;
                fields = sdata.(uci).(part_now3).nfields;
                fddata = sdata.(uci).(part_now3).field_data;
                lx2 = sdata.(part_now3).lxrm;
                ly2 = sdata.(part_now3).lyrm;
                lz2 = sdata.(part_now3).lzrm;
                hold on
                h = line(lx2,ly2,lz2);
                set(h,'Color',[0.5 0.5 0.5 0.2],'LineWidth',1,'LineStyle','-');
                hold on

                for ff = 1:1 % for every detected place field
                    % plot outline of this place field
                    ps = fddata(ff).voxel_index;
                    K = convhull(ps(:,2),ps(:,1),ps(:,3));
                    tri = trisurf(K,ps(:,2),ps(:,1),ps(:,3));
                    set(tri,'FaceColor',cols{dd},'EdgeAlpha',0.5);
                    alpha(.1);  
                end

                axis off tight
                view(3)
                daspect([1 1 1])
                axis vis3d
                camproj perspective
                rotate3d on 
                title(sprintf('%d %d',dirs{dd,4},dirs{dd,5}),'FontWeight','normal','FontSize',6)
        end
            
%% ##################################### %% place field scatter of elongation and distance from center
%% arena
    ynow = 540;
    ax_F1 = axes('Units','pixels','Position',[50 ynow 180 110]); 
        cents = fdata.field_lattice_centroid(pf_idx_sq1,:);
        elong = fdata.field_principalaxes(pf_idx_sq1,1) ./ fdata.field_principalaxes(pf_idx_sq1,2);
        ds = sqrt(sum(cents.^2,2)); % distance from center
        
        malpha = 0.3;
        msiz = 30;
        scatter(ds,elong,msiz,colsq,'filled','MarkerFaceAlpha',malpha,'MarkerEdgeColor','none');
        ax = gca;
        ax.YLim = [1 5];
        y1 = ax.YLim;
        ax.XLim = [0 150];
        x1 = ax.XLim;        
        rr = refline;
        set(rr,'Color','r');
        xlabel('Distance from center (cm)')
        ylabel('Field elongation')
        grid on
        box off
        
        [r,p] = corr(ds,elong,'type','Pearson','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        title(m1name,'FontWeight','normal')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

%% aligned        
    ax_F2 = axes('Units','pixels','Position',ax_F1.Position+[200 0 0 0]); 
        cents = fdata.field_lattice_centroid(pf_idx_la1,:);
        elong = fdata.field_principalaxes(pf_idx_la1,1) ./ nanmean(fdata.field_principalaxes(pf_idx_la1,2:3),2);
        ds = sqrt(sum(cents.^2,2)); % distance from center
        nanmedian(ds);
        mad(ds);
           
        malpha = 0.3;
        msiz = 30;
        scatter(ds,elong,msiz,collt,'filled','MarkerFaceAlpha',malpha,'MarkerEdgeColor','none');
        ax = gca;
        ax.YLim = y1;
        ax.XLim = x1;        
        rr = refline;
        set(rr,'Color','r');
        xlabel('Distance from center (cm)')
        ylabel('Elongation')
        grid on
        box off
        
        [r,p] = corr(ds,elong,'type','Pearson','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        title(m2name,'FontWeight','normal')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        ax.YColor = 'none';             

%% tilted        
    ax_F3 = axes('Units','pixels','Position',ax_F1.Position+[400 0 0 0]); 
        cents = fdata.field_lattice_centroid(pf_idx_la2,:);
        elong = fdata.field_principalaxes(pf_idx_la2,1) ./ nanmean(fdata.field_principalaxes(pf_idx_la2,2:3),2);
        ds = sqrt(sum(cents.^2,2)); % distance from center
        nanmedian(ds);
        mad(ds);
           
        malpha = 0.3;
        msiz = 30;
        scatter(ds,elong,msiz,coldi,'filled','MarkerFaceAlpha',malpha,'MarkerEdgeColor','none');
        ax = gca;
        ax.YLim = y1;
        ax.XLim = x1;        
        rr = refline;
        set(rr,'Color','r');
        xlabel('Distance from center (cm)')
        ylabel('Elongation')
        grid on
        box off
        
        [r,p] = corr(ds,elong,'type','Pearson','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} < .0001'],'Units','normalized','Color','r','FontSize',6)
        title(m3name,'FontWeight','normal')
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        ax.YColor = 'none';   

%% ##################################### %% elongation with experience  
%% arena
    ynow = 350;
    ax_F = axes('Units','pixels','Position',[50 ynow 180 110]);  
        rats = unique(tdata.rat(pc_idx_sq1,1));
        ars = [];
        for rr = 1:length(rats)
            dts = unique(tdata.date(tdata.rat==rats(rr)));
            for dd = 1:length(dts)
                indx = fdata.rat==rats(rr) & pf_idx_sq1 & fdata.date==dts(dd);
                pdat = nanmean(fdata.field_principalaxes(indx,1) ./ fdata.field_principalaxes(indx,2));
                ars = [ars; rr dd pdat];
            end
        end

        scatter(ars(:,2),ars(:,3),60,ars(:,1),'filled','MarkerFaceAlpha',.8,'MarkerEdgeColor','b','MarkerEdgeAlpha',.4);
        hold on
        axis xy
        colormap(ax_F,'parula')
        caxis([0 max(ars(:,1))+1])

        ax = gca;
        ax.XLim = [0 15];   
        ax.YLim = [1 3];
        grid on
        xlabel('Day')
        ylabel('Field elongation')

        rr = refline;
        set(rr,'Color','r')
        [r,p] = corr(ars(:,2),ars(:,3),'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 

            disp('elong with exp square:')  
            disp(sprintf('\tr = %.3f, p = %.3f',r,p))  

%% aligned            
    ax_F = axes('Units','pixels','Position',[245 ax_F.Position(2) 180 110]);  
        rats = unique(tdata.rat(pc_idx_la1,1));
        ars = [];
        for rr = 1:length(rats)
            dts = unique(tdata.date(tdata.rat==rats(rr)));
            for dd = 1:length(dts)
                indx = fdata.rat==rats(rr) & pf_idx_la1 & fdata.date==dts(dd);
                pdat = nanmean(fdata.field_principalaxes(indx,1) ./ fdata.field_principalaxes(indx,2));
                ars = [ars; rr dd pdat];
            end
        end

        scatter(ars(:,2),ars(:,3),60,ars(:,1),'filled','MarkerFaceAlpha',.8,'MarkerEdgeColor','b','MarkerEdgeAlpha',.4);
        hold on
        axis xy
        colormap(ax_F,'parula')
        caxis([0 max(ars(:,1))+1])

        ax = gca;
        ax.XLim = [0 15];   
        ax.YLim = [1 3];
        ax.YTick = [];
        grid on
        xlabel('Day')
        %ylabel('Field elongation (P1/P3)','Interpreter','latex')

        rr = refline;
        set(rr,'Color','r')
        [r,p] = corr(ars(:,2),ars(:,3),'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black   

        line(ax.XLim,[1.5 1.5],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[2.5 2.5],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[2 2],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[3 3],'Color',[.5 .5 .5 .5]);
        line([.1 .1],ax.YLim,'Color',[.5 .5 .5 .5]);

            disp('elong with exp lattice:')  
            disp(sprintf('\tr = %.3f, p = %.3f',r,p))  

%% tilted            
    ax_F = axes('Units','pixels','Position',[440 ax_F.Position(2) 180 110]);  
        rats = unique(tdata.rat(pc_idx_la2,1));
        ars = [];
        for rr = 1:length(rats)
            dts = unique(tdata.date(tdata.rat==rats(rr)));
            for dd = 1:length(dts)
                indx = fdata.rat==rats(rr) & pf_idx_la2 & fdata.date==dts(dd);
                pdat = nanmean(fdata.field_principalaxes(indx,1) ./ fdata.field_principalaxes(indx,2));
                ars = [ars; rr dd pdat];
            end
        end

        scatter(ars(:,2),ars(:,3),60,ars(:,1),'filled','MarkerFaceAlpha',.8,'MarkerEdgeColor','b','MarkerEdgeAlpha',.4);
        hold on
        axis xy
        colormap(ax_F,'parula')
        caxis([0 max(ars(:,1))+1])

        ax = gca;
        ax.XLim = [0 15];   
        ax.YLim = [1 3];
        ax.YTick = [];
        grid on
        xlabel('Day')
        %ylabel('Field elongation (P1/P3)','Interpreter','latex')

        rr = refline;
        set(rr,'Color','r')
        [r,p] = corr(ars(:,2),ars(:,3),'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

        line(ax.XLim,[1.5 1.5],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[2.5 2.5],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[2 2],'Color',[.5 .5 .5 .5]);
        line(ax.XLim,[3 3],'Color',[.5 .5 .5 .5]);
        line([.1 .1],ax.YLim,'Color',[.5 .5 .5 .5]);

            disp('elong with exp diagonal:')  
            disp(sprintf('\tr = %.3f, p = %.3f',r,p))  
            
%% ##################################### %% isolation distance and lratio 
%% Lratio
    ynow = ax_F.Position(2)-180;
    ax_E1 = axes('Units','pixels','Position',[50 ynow ax_F.Position(3) 110]); 
        isod = tdata.IsoD(pc_idx_la1,1);
        lrat = tdata.Lratio(pc_idx_la1,1);
        snr = tdata.snr_of_wave(pc_idx_la1,1);
        amp = tdata.amplitude_of_wave(pc_idx_la1,1); 
        rpv = tdata.rpviolations(pc_idx_la1,1); 

        ucis = tdata.uci(pc_idx_la1,1);
        ars = NaN(length(ucis),1);
        for uu = 1:length(ucis)
            indx = fdata.uci==ucis(uu) & pf_idx_la1;
            ars(uu) = nanmean(fdata.field_principalaxes(indx,1) ./ fdata.field_principalaxes(indx,3));
        end

        scatter(lrat,ars,50,'MarkerFaceColor','k','MarkerEdgeColor','none','MarkerFaceAlpha',.2)
        axis xy 

        ax = gca;
        ax.XLim = [0 nanmax(lrat)];
        ax.YLim = [0 6];
        ax.YTick = 0:2:6;
        grid on
        xlabel('L_{ratio}')
        ylabel('Field elongation')

        rr = refline;
        set(rr,'Color','r')
        line([ax.XLim(2) ax.XLim(2)],ax.YLim,'Color',[ax.GridColor ax.GridAlpha]);
        line(ax.XLim,[ax.YLim(2) ax.YLim(2)],'Color',[ax.GridColor ax.GridAlpha]);
        [r,p] = corr(lrat,ars,'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.f')) % change Ytick labels to have the same number of decimal places 

            disp('Isolation distance:')  
            disp(sprintf('\tr = %.3f, p = %.3f',r,p))      

%% IsoD
    ax_E2 = axes('Units','pixels','Position',[245 ax_E1.Position(2) ax_E1.Position(3) ax_E1.Position(4)]);  
        scatter(isod,ars,50,'MarkerFaceColor','k','MarkerEdgeColor','none','MarkerFaceAlpha',.2)
        axis xy 

        ax = gca;
        ax.XLim = [0 nanmax(isod)];
        ax.YLim = [0 6];
        ax.YTick = 0:2:6;
        ax.YTick = [];
        grid on
        xlabel('IsoD')

        rr = refline;
        set(rr,'Color','r')
        [r,p] = corr(isod,ars,'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        ax.GridColor = [.15 .15 .15];
        line(ax.XLim,[2:2:6;2:2:6]','Color',[ax.GridColor ax.GridAlpha]);    
        line([ax.XLim(1)+1 ax.XLim(1)+1],ax.YLim,'Color',[ax.GridColor ax.GridAlpha]);
        line([ax.XLim(2) ax.XLim(2)],ax.YLim,'Color',[ax.GridColor ax.GridAlpha]);
        line(ax.XLim,[ax.YLim(2) ax.YLim(2)],'Color',[ax.GridColor ax.GridAlpha]); 

%% signal to noise ratio (SNR)        
    ax_E2 = axes('Units','pixels','Position',[440 ax_E1.Position(2) ax_E1.Position(3) ax_E1.Position(4)]);  
        scatter(snr,ars,50,'MarkerFaceColor','k','MarkerEdgeColor','none','MarkerFaceAlpha',.2)
        axis xy 

        ax = gca;
        ax.XLim = [0.98 nanmax(snr)];
        ax.YLim = [0 6];
        ax.YTick = 0:2:6;
        ax.YTick = [];
        grid on
        xlabel('SNR')

        rr = refline;
        set(rr,'Color','r')
        [r,p] = corr(snr,ars,'type','Spearman','rows','pairwise');
        text(0.6,0.95,['{\itr} = ' sprintf('%.2f',r) ', {\itp} = ' strrep(sprintf('%.3f',p),'0.','.')],'Units','normalized','Color','r','FontSize',6)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','w'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        ax.GridColor = [.15 .15 .15];
        line(ax.XLim,[2:2:6;2:2:6]','Color',[ax.GridColor ax.GridAlpha]);    
        line([ax.XLim(1)+.002 ax.XLim(1)+.002],ax.YLim,'Color',[ax.GridColor ax.GridAlpha]);
        line([ax.XLim(2) ax.XLim(2)],ax.YLim,'Color',[ax.GridColor ax.GridAlpha]);
        line(ax.XLim,[ax.YLim(2) ax.YLim(2)],'Color',[ax.GridColor ax.GridAlpha]); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
        
        
        
        
        
        
        
        
        
        
        
        
        
        
