%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS12_alternative_orientation small function to make Fig. S12
% Figure S12 shows an alternative analysis on field elongation
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible',fig_vis,'Position',[50,60,850,900]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    set(0,'DefaultAxesTitleFontWeight','normal');
    colormap(jet(256)); % to make sure the colormap is not the horrible default one
    fsiz = 8; % the fontsize for different texts
    flnw = 0.5; % the line width for different plots

    annotation('textbox','Units','pixels','Position',[5, 880, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 690, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    plot_views = [30 22];

%% ##################################### %% Example projection and shuffle     
%% tilted lattice schematic
        leng = 9;
        l1 = normr([-970 0 0]); 
        l2 = normr([970 0 0]); 
        l3 = normr([0 970 0]); 
        l4 = normr([0 -970 0]); 

        rot_mat = rotz(60);
        l5 = (rot_mat*normr([0 0 970])')'; 
        l6 = (rot_mat*normr([0 0 -970])')'; 
        l7 = (rot_mat*normr([0 660 466.69])')'; 
        l8 = (rot_mat*normr([0 -660 -466.69])')'; 
        l9 = (rot_mat*normr([571.6 -330 466.69])')'; 
        l10 = (rot_mat*normr([-571.6 330 -466.69])')'; 
        l11 = (rot_mat*normr([-571.55 -330 466.69])')'; 
        l12 = (rot_mat*normr([571.55 330 -466.69])')';       
       
    ax_Csq = axes('Units','pixels','Position',[-13 690 220 220]);   
        rot_matZ = rotz(45);
        rot_matX = rotx(54.735);
        [v1] = meshgrid(1:7);
        v2 = v1';
        xyz = [v1(:) v2(:) ones(size(v1(:)))];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        daspect([1 1 1])
        xyz = [v1(:) v2(:) ones(size(v1(:))).*7];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        s = surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [v1(:) ones(size(v1(:))) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        smat = s.CData;
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [v1(:) ones(size(v1(:))).*7 v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [ones(size(v1(:))) v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [ones(size(v1(:))).*7 v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,'parula')
        caxis([2 11])
        view(plot_views);
        camproj perspective
        rotate3d on       

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {':',':',':',':',':',':','-','-','-','-','-','-'};    
        orig = [0 0 6.92];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off   

%% tilted lattice schematica and projected axes
    ax_m1 = axes('Units','pixels','Position',[185 693 220 220]);         
        rot_matZ = rotz(45);
        rot_matX = rotx(54.735);
        [v1] = meshgrid(1:7);
        fc = 'w';
        fa = 1;
        v2 = v1';
        xyz = [v1(:) v2(:) ones(size(v1(:)))];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        daspect([1 1 1])
        xyz = [v1(:) v2(:) ones(size(v1(:))).*7];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        s = surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        xyz = [v1(:) ones(size(v1(:))) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        smat = s.CData;
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        xyz = [v1(:) ones(size(v1(:))).*7 v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        xyz = [ones(size(v1(:))) v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        xyz = [ones(size(v1(:))).*7 v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1)),'FaceColor',fc,'FaceAlpha',fa); hold on;
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,'parula')
        caxis([2 11])
        view(plot_views);
        camproj perspective
        rotate3d on    

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {':',':',':',':',':',':','-','-','-','-','-','-'};    
        orig = [0 0 6.92];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off   

        hold on
        tc = [normr([0 660 466.69]); normr([0 -660 -466.69]); normr([571.6 -330 466.69]); normr([-571.6 330 -466.69]); normr([-571.55 -330 466.69]); normr([571.55 330 -466.69])];   
        tc = (rot_mat*tc')'; 

        [X,Y,Z,mlat2] = projectEIGS(tc);  
        ssize = 6;
        X = X*ssize;
        Y = Y*ssize;
        Z = Z*ssize;
        Z = Z+orig(3);

        s = surf(X,Y,Z,mlat2);
        s.EdgeColor = 'none';
        s.FaceAlpha = 0.4;
        axis off vis3d; 
        rotate3d on;
        daspect([1 1 1]); 
        grid on
        axis tight off     
        colormap(gca,jet(256));
        caxis([0 nanmax(mlat2(:))])    
        
%% the predicted map based on these axes
    ax_m1 = axes('Units','pixels','Position',[450 745 120 120]);         
        imagesc(mlat2);
        axis equal tight xy
        ax = gca;
        tc = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0]); normr([0 0 970]); normr([0 0 -970])];    
        [X,Y,Z,mlat2d] = projectEIGS(tc);        
        ax.XTick = [1 size(mlat2d,1)*0.25 size(mlat2d,1)*0.5 size(mlat2d,1)*0.75 size(mlat2d,1)];
        ax.YTick = [1 size(mlat2d,1)*0.25 size(mlat2d,1)*0.5 size(mlat2d,1)*0.75 size(mlat2d,1)];
        ax.XTickLabel = {'-180','-90','0','90','180'};
        ax.YTickLabel = {'-90','-45','0','45','90'};
        ylabel('Pitch (rad)')     
        xlabel('Azimuth (rad)') 
        title('Predicted map','FontSize',fsiz,'FontWeight','normal')

        annotation('arrow',[0.21 0.26],[0.89 0.89])
        annotation('arrow',[0.43 0.48],[0.89 0.89])
        
%% a shuffled predicted map     
    ax_m1 = axes('Units','pixels','Position',[650 745 120 120]);      
        % generate random spherical points
        np = 1000;
        a = 2*pi*rand(np,1);
        e = asin(-1+2*rand(np,1));
        r = ones(np,1);

        % convert to cartesian
        [x,y,z] = sph2cart(a,e,r);
        ts = [x(:) y(:) z(:)];            
        [~,~,~,ms] = projectEIGS(ts);  

        imagesc(ms);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(ms,1)*0.25 size(ms,1)*0.5 size(ms,1)*0.75 size(ms,1)];
        ax.YTick = [1 size(ms,1)*0.25 size(ms,1)*0.5 size(ms,1)*0.75 size(ms,1)];
        ax.XTickLabel = {'-180','-90','0','90','180'};
        ax.YTickLabel = {'-90','-45','0','45','90'};
        ylabel('Pitch (rad)')     
        xlabel('Azimuth (rad)') 
        title('Shuffled map','FontSize',fsiz,'FontWeight','normal')

%% ##################################### %% Maze schematics and axes              
%% square schematic  
    plot_views = [30 22];    
    ax_Csq = axes('Units','pixels','Position',[5 520 180 180]);   
        plotcube([7,7,1],[0 0 0],1,'b');
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,parula)
        view(plot_views);
        camproj perspective
        rotate3d on

        leng = 9;
        l1 = normr([-970 0 0]); 
        l2 = normr([970 0 0]); 
        l3 = normr([0 970 0]); 
        l4 = normr([0 -970 0]); 

        rot_mat = rotz(60);
        l5 = (rot_mat*normr([0 0 970])')'; 
        l6 = (rot_mat*normr([0 0 -970])')'; 
        l7 = (rot_mat*normr([0 660 466.69])')'; 
        l8 = (rot_mat*normr([0 -660 -466.69])')'; 
        l9 = (rot_mat*normr([571.6 -330 466.69])')'; 
        l10 = (rot_mat*normr([-571.6 330 -466.69])')'; 
        l11 = (rot_mat*normr([-571.55 -330 466.69])')'; 
        l12 = (rot_mat*normr([571.55 330 -466.69])')';    

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [3.5 3.5 0.5];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off         
        
        %% add rotated taxt to label
        ax_Csq = axes('Units','pixels','Position',[50 510 180 180]);  
        ax = gca;
        axis(ax,'off')
        ylabel(ax,m1name)
        ax.YLabel.Visible = 'on';
        ax.Color = 'none';

%% lattice schematic  
    ax_Clt = axes('Units','pixels','Position',[-20 330 230 230]);   
        [v1] = meshgrid(1:7);
        surf(v1,v1',ones(size(v1))); hold on;
        surf(v1,v1',ones(size(v1)).*7);
        surf(v1,ones(size(v1)),v1');
        surf(v1,ones(size(v1)).*7,v1',v1');
        surf(ones(size(v1)),v1,v1');
        surf(ones(size(v1)).*7,v1,v1');
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,parula)
        view(plot_views);
        camproj perspective
        rotate3d on

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [4 4 4];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off          

        %% add rotated taxt to label
        ax_Csq = axes('Units','pixels','Position',[50 340 230 230]);  
        ax = gca;
        axis(ax,'off')
        ylabel(ax,m2name)
        ax.YLabel.Visible = 'on';
        ax.Color = 'none';

%% diagonal lattice schematic   
    ax_Cdi = axes('Units','pixels','Position',[-20 180 230 230]);   
        rot_matZ = rotz(45);
        rot_matX = rotx(54.735);
        [v1] = meshgrid(1:7);
        v2 = v1';
        xyz = [v1(:) v2(:) ones(size(v1(:)))];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        daspect([1 1 1])
        xyz = [v1(:) v2(:) ones(size(v1(:))).*7];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        s = surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [v1(:) ones(size(v1(:))) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        smat = s.CData;
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [v1(:) ones(size(v1(:))).*7 v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [ones(size(v1(:))) v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        xyz = [ones(size(v1(:))).*7 v1(:) v2(:)];
        xyz = rot_matZ * xyz';
        xyz = (rot_matX * xyz)';
        surf(reshape(xyz(:,1),size(v1)),reshape(xyz(:,2),size(v1)),reshape(xyz(:,3),size(v1))); hold on;
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,'parula')
        caxis([2 11])
        view(plot_views);
        camproj perspective
        rotate3d on    

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {':',':',':',':',':',':','-','-','-','-','-','-'};        
        orig = [0 0 6.92];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off          
        
        %% add rotated taxt to label
        ax_Csq = axes('Units','pixels','Position',[50 180 230 230]);  
        ax = gca;
        axis(ax,'off')
        ylabel(ax,m3name)
        ax.YLabel.Visible = 'on';
        ax.Color = 'none';   

%% diagonal (rotated) lattice schematic   
    ax_Cdi = axes('Units','pixels','Position',[-20 20 230 230]);         
        [v1] = meshgrid(1:7);
        surf(v1,v1',ones(size(v1))); hold on; % bottom
        surf(v1,v1',ones(size(v1)).*7,rot90(smat)); % top
        surf(v1,ones(size(v1)),v1',rot90(smat,0));
        surf(v1,ones(size(v1)).*7,v1',smat);
        surf(ones(size(v1)),v1,v1',rot90(smat,0));
        surf(ones(size(v1)).*7,v1,v1',rot90(smat,3));
        daspect([1 1 1])
        axis xy tight off
        colormap(gca,parula)
        view(plot_views);
        camproj perspective
        rotate3d on

        adj = 7;
        lcol = 'k';
        lwid = 1;
        hold on;
        lins = {l1 l2 l3 l4 l5 l6 l7 l8 l9 l10 l11 l12};
        lsty = {'-','-','-','-','-','-',':',':',':',':',':',':',};        
        orig = [4 4 4];
        for ll = 1:length(lins)
            lnow = lins{ll};
            line([orig(1) lnow(1)*adj+orig(1)],[orig(2) lnow(2)*adj+orig(2)],[orig(3) lnow(3)*adj+orig(3)],'Color',lcol,'LineStyle',lsty{ll},'LineWidth',lwid) % X left
        end
        axis tight off          

        %% add rotated taxt to label
        ax_Csq = axes('Units','pixels','Position',[50 20 230 230]);  
        ax = gca;
        axis(ax,'off')
        ylabel(ax,'Tilted (rotated)')
        ax.YLabel.Visible = 'on';
        ax.Color = 'none';        
    
%% ##################################### %% Idealised maps to show what would be ideally expected        
%% square idealised map  
    ax_m1 = axes('Units','pixels','Position',[230 540 130 130]);         
        tc = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0])];    
        [X,Y,Z,msq1] = projectEIGS(tc);  
        mx = nanmax(msq1(:));    
        msq1 = (msq1 ./ mx);    
        imagesc(msq1);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(msq1,1)*0.25 size(msq1,1)*0.5 size(msq1,1)*0.75 size(msq1,1)];
        ax.YTick = [1 size(msq1,1)*0.25 size(msq1,1)*0.5 size(msq1,1)*0.75 size(msq1,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {'-\pi/2','-\pi/4','0','\pi/4','\pi/2'};
        ylabel('Pitch (rad)') 
        title('Predicted','FontWeight','normal','FontSize',fsiz)
        
%% lattice idealised map
    ax_m2 = axes('Units','pixels','Position',ax_m1.Position+[0 -155 0 0]);         
        tc = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0]); normr([0 0 970]); normr([0 0 -970])];    
        [X,Y,Z,mlat1] = projectEIGS(tc);  
        mx = nanmax(mlat1(:));    
        mlat1 = (mlat1 ./ mx);    
        imagesc(mlat1);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(mlat1,1)*0.25 size(mlat1,1)*0.5 size(mlat1,1)*0.75 size(mlat1,1)];
        ax.YTick = [1 size(mlat1,1)*0.25 size(mlat1,1)*0.5 size(mlat1,1)*0.75 size(mlat1,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {'-\pi/2','-\pi/4','0','\pi/4','\pi/2'};
        ylabel('Pitch (rad)')    

%% diagonal idealised map
    ax_m3 = axes('Units','pixels','Position',ax_m2.Position+[0 -155 0 0]);   
        tc = [normr([0 660 466.69]); normr([0 -660 -466.69]); normr([571.6 -330 466.69]); normr([-571.6 330 -466.69]); normr([-571.55 -330 466.69]); normr([571.55 330 -466.69])];    
        [X,Y,Z,mlat2] = projectEIGS(tc);  
        mx = nanmax(mlat2(:));    
        mlat2 = fliplr((mlat2 ./ mx));    
        imagesc(mlat2);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(mlat2,1)*0.25 size(mlat2,1)*0.5 size(mlat2,1)*0.75 size(mlat2,1)];
        ax.YTick = [1 size(mlat2,1)*0.25 size(mlat2,1)*0.5 size(mlat2,1)*0.75 size(mlat2,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {'-\pi/2','-\pi/4','0','\pi/4','\pi/2'};
        ylabel('Pitch (rad)') 
        
%% diagonal rotated idealised map
    ax_m4 = axes('Units','pixels','Position',ax_m3.Position+[0 -155 0 0]);   
        tc = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0]); normr([0 0 970]); normr([0 0 -970])];    
        [X,Y,Z,mlat2d] = projectEIGS(tc);  
        mx = nanmax(mlat2d(:));    
        mlat2d = (mlat2d ./ mx);    
        imagesc(mlat2d);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(mlat2d,1)*0.25 size(mlat2d,1)*0.5 size(mlat2d,1)*0.75 size(mlat2d,1)];
        ax.YTick = [1 size(mlat2d,1)*0.25 size(mlat2d,1)*0.5 size(mlat2d,1)*0.75 size(mlat2d,1)];
        ax.XTickLabel = {'-\pi','-\pi/2','0','\pi/2','\pi'};
        ax.YTickLabel = {'-\pi/2','-\pi/4','0','\pi/4','\pi/2'};
        ylabel('Pitch (rad)')     
        xlabel('Azimuth (rad)')    
    
%% ##################################### %% Real maps with actual data                
%% square 3d map  
    ax_m1 = axes('Units','pixels','Position',[380 540 130 130]); 
        V = [fdata.field_eigenvector(pf_idx_sq1,[2 1 3]); -fdata.field_eigenvector(pf_idx_sq1,[2 1 3])];
        [X,Y,Z,dsq1] = projectEIGS(V);  
        mx = nanmax(dsq1(:));    
        dsq1 = (dsq1 ./ mx);    
        imagesc(dsq1);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(dsq1,1)*0.25 size(dsq1,1)*0.5 size(dsq1,1)*0.75 size(dsq1,1)];
        ax.YTick = [1 size(dsq1,1)*0.25 size(dsq1,1)*0.5 size(dsq1,1)*0.75 size(dsq1,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {};
        title('Observed','FontWeight','normal','FontSize',fsiz)
        
%% lattice 3d map
    ax_m2 = axes('Units','pixels','Position',ax_m1.Position+[0 -155 0 0]);     
        V = [fdata.field_eigenvector(pf_idx_la1,[2 1 3]); -fdata.field_eigenvector(pf_idx_la1,[2 1 3])];
        [X,Y,Z,dlat1] = projectEIGS(V);  
        mx = nanmax(dlat1(:));    
        dlat1 = (dlat1 ./ mx);    
        imagesc(dlat1);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(dlat1,1)*0.25 size(dlat1,1)*0.5 size(dlat1,1)*0.75 size(dlat1,1)];
        ax.YTick = [1 size(dlat1,1)*0.25 size(dlat1,1)*0.5 size(dlat1,1)*0.75 size(dlat1,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {};

%% diagonal 3d map
    ax_m3 = axes('Units','pixels','Position',ax_m2.Position+[0 -155 0 0]);   
        V = [fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3]); -fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3])];
        XYZ = AxelRot(V',-35.265,[1 0 0],[]);
        V = AxelRot(XYZ,-45,[0 1 0],[])';    
        [X,Y,Z,dlat2] = projectEIGS(V);  
        mx = nanmax(dlat2(:));    
        dlat2 = (dlat2 ./ mx);
        imagesc(dlat2);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(dlat2,1)*0.25 size(dlat2,1)*0.5 size(dlat2,1)*0.75 size(dlat2,1)];
        ax.YTick = [1 size(dlat2,1)*0.25 size(dlat2,1)*0.5 size(dlat2,1)*0.75 size(dlat2,1)];
        ax.XTickLabel = {};
        ax.YTickLabel = {};
        
%% diagonal rotated 3d map
    ax_m4 = axes('Units','pixels','Position',ax_m3.Position+[0 -155 0 0]);   
        V = [fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3]); -fdata.field_diagonal_eigenvector(pf_idx_la2,[2 1 3])];
        [X,Y,Z,dlat2d] = projectEIGS(V);  
        mx = nanmax(dlat2d(:));    
        dlat2d = dlat2d ./ mx;    
        imagesc(dlat2d);
        axis equal tight xy
        ax = gca;
        ax.XTick = [1 size(dlat2d,1)*0.25 size(dlat2d,1)*0.5 size(dlat2d,1)*0.75 size(dlat2d,1)];
        ax.YTick = [1 size(dlat2d,1)*0.25 size(dlat2d,1)*0.5 size(dlat2d,1)*0.75 size(dlat2d,1)];
        ax.XTickLabel = {'-\pi','-\pi/2','0','\pi/2','\pi'};
        ax.YTickLabel = {};
        xlabel('Azimuth (rad)')
    
%% ##################################### %% Lateral sum of predicted and observed maps    
%% square Lateral sum
    ax_m1 = axes('Units','pixels','Position',[530 540 80 130]);        
        v1 = nansum(dsq1./nansum(dsq1(:)),2);
        v2 = nansum(msq1./nansum(msq1(:)),2);
        v1 = v1/max(v1(:));        
        v2 = v2/max(v2(:));
    
        p1 = plot(v1,1:length(v1),'b'); hold on;
        p2 = plot(v2,1:length(v2),'r');     
    
        ax = gca;
        ax.YTick = [1 size(dsq1,1)*0.25 size(dsq1,1)*0.5 size(dsq1,1)*0.75 size(dsq1,1)];        
        ax.YTickLabel = {};
        ax.XTickLabel = {};
        ax.YLim = [1 length(v1)];
        grid on
        box off
        ax.XColor = 'none';

        ll = legend([p1 p2],{'Observed','Predicted'});
        legend boxoff
        set(ll,'Position',get(ll,'Position')+[0.06 -0.01 -0.05 0]);

%% lattice Lateral sum
    ax_m2 = axes('Units','pixels','Position',ax_m1.Position+[0 -155 0 0]);           
        v1 = nansum(dlat1./nansum(dlat1(:)),2);
        v2 = nansum(mlat1./nansum(mlat1(:)),2);
        v1 = v1/max(v1(:));        
        v2 = v2/max(v2(:));
        
        plot(v1,1:length(v1),'b'); hold on;
        plot(v2,1:length(v2),'r');     
    
        ax = gca;
        ax.YTick = [1 size(dlat1,1)*0.25 size(dlat1,1)*0.5 size(dlat1,1)*0.75 size(dlat1,1)];        
        ax.YTickLabel = {};
        ax.XTickLabel = {};        
        ax.YLim = [1 length(v1)];
        grid on
        box off
        ax.XColor = 'none';
        
%% diagonal Lateral sum
    ax_m3 = axes('Units','pixels','Position',ax_m2.Position+[0 -155 0 0]);           
        v1 = nansum(dlat2./nansum(dlat2(:)),2);
        v2 = nansum(mlat2./nansum(mlat2(:)),2);
        v1 = v1/max(v1(:));        
        v2 = v2/max(v2(:));
        
        plot(v1,1:length(v1),'b'); hold on;
        plot(v2,1:length(v2),'r');     
    
        ax = gca;
        ax.YTick = [1 size(dlat2,1)*0.25 size(dlat2,1)*0.5 size(dlat2,1)*0.75 size(dlat2,1)];        
        ax.YTickLabel = {};
        ax.XTickLabel = {};        
        ax.YLim = [1 length(v1)];
        grid on
        box off
        ax.XColor = 'none';
        
%% diagonal rotated Lateral sum
    ax_m4 = axes('Units','pixels','Position',ax_m3.Position+[0 -155 0 0]);    
        v1 = nansum(dlat2d./nansum(dlat2d(:)),2);
        v2 = nansum(mlat2d./nansum(mlat2d(:)),2);
        v1 = v1/max(v1(:));        
        v2 = v2/max(v2(:));
        
        plot(v1,1:length(v1),'b'); hold on;
        plot(v2,1:length(v2),'r');     
    
        ax = gca;
        ax.YTick = [1 size(dlat2d,1)*0.25 size(dlat2d,1)*0.5 size(dlat2d,1)*0.75 size(dlat2d,1)];        
        ax.YTickLabel = {};
        ax.XTick = [0 0.5 1];      
        ax.YLim = [1 length(v1)];    
        grid on
        box off
        xlabel('Norm. prob.')
        
%% ##################################### %% Color bars
    ax_m4 = axes('Units','pixels','Position',[50 710 100 10]); 
        cmat = 1:256;
        imagesc(cmat);
        axis off
        text(-30,1,'0','FontSize',6)
        text(266,1,'Max','FontSize',6)
        text(128,2,'Height','HorizontalAlignment','center','FontSize',6)        
        colormap(gca,'parula')
        
    ax_m4 = axes('Units','pixels','Position',[250 710 100 10]); 
        cmat = 1:256;
        imagesc(cmat);
        axis off
        text(-30,1,'0','FontSize',6)
        text(266,1,'Max','FontSize',6) 
        text(128,2,'Probability','HorizontalAlignment','center','FontSize',6)                
        colormap(gca,'jet')

%% ##################################### %% Correlations between idealised and real maps  
    ctype = 'Pearson';
    crows = 'Pairwise';
    
%% square correlations
    ax_m1 = axes('Units','pixels','Position',[680 540 100 130]); 
        [r1,p1] = corr(msq1(:),dsq1(:),'type',ctype,'rows',crows);
        [r2,p2] = corr(mlat1(:),dsq1(:),'type',ctype,'rows',crows);
        [r3,p3] = corr(mlat2(:),dsq1(:),'type',ctype,'rows',crows);
    
        stem(1:3,[r1 r2 r3],'Color','k'); hold on;

        box off
        ax = gca;
        ax.XTick = 1:3;
        ax.XTickLabel = {};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = [-1 1];   
        y1 = ax.YLim;
        ylabel(sprintf('Correlation (r)'))
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places
        grid on
        
        % correlations with random maps (completely random vectors)
        shuff = 100;
        np = 10000;
        rvals = NaN(shuff,1);
        for ss = 1:shuff
            % generate random spherical points
            a = 2*pi*rand(np,1);
            e = asin(-1+2*rand(np,1));
            r = ones(np,1);

            % convert to cartesian
            [x,y,z] = sph2cart(a,e,r);
            ts = [x(:) y(:) z(:)];            
            [~,~,~,ms] = projectEIGS(ts);  
            rvals(ss) = corr(ms(:),dsq1(:),'type',ctype,'rows',crows);
        end        
        psR = prctile(rvals,[1 50 99]);
        hold on;
        line(ax.XLim',[psR(3) psR(3)],'Color','r')        

            % stats etc
            disp(sprintf('Square correlation results:'))
            disp(sprintf('\tcorrelation r (p): %.5f (%.5f), %.5f (%.5f), %.5f (%.5f)',r1,p1,r2,p2,r3,p3))
            disp(sprintf('\tshuffle rand correlation 99th: %.5f',psR(3)))

%% lattice correlations
    ax_m2 = axes('Units','pixels','Position',ax_m1.Position+[0 -155 0 0]);     
        [r1,p1] = corr(msq1(:),dlat1(:),'type',ctype,'rows',crows);
        [r2,p2] = corr(mlat1(:),dlat1(:),'type',ctype,'rows',crows);
        [r3,p3] = corr(mlat2(:),dlat1(:),'type',ctype,'rows',crows);
    
        stem(1:3,[r1 r2 r3],'Color','k'); hold on;

        box off
        ax = gca;
        ax.XTick = 1:3;
        ax.XTickLabel = {};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = y1;
        ylabel(sprintf('Correlation (r)'))
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 
        grid on

        % correlations with random maps (completely random vectors)
        shuff = 100;
        np = 10000;
        rvals = NaN(shuff,1);
        for ss = 1:shuff
            % generate random spherical points
            a = 2*pi*rand(np,1);
            e = asin(-1+2*rand(np,1));
            r = ones(np,1);

            % convert to cartesian
            [x,y,z] = sph2cart(a,e,r);
            ts = [x(:) y(:) z(:)];            
            [~,~,~,ms] = projectEIGS(ts);  
            rvals(ss) = corr(ms(:),dlat1(:),'type',ctype,'rows',crows);
        end        
        psR = prctile(rvals,[1 50 99]);
        hold on;
        line(ax.XLim',[psR(3) psR(3)],'Color','r')         
        
            % stats etc
            disp(sprintf('Aligned correlation results:'))
            disp(sprintf('\tcorrelation r (p): %.5f (%.5f), %.5f (%.5f), %.5f (%.5f)',r1,p1,r2,p2,r3,p3))
            disp(sprintf('\tshuffle rand correlation 99th: %.5f',psR(3)))
            
%% diagonal correlations
    ax_m3 = axes('Units','pixels','Position',ax_m2.Position+[0 -155 0 0]);   
        [r1,p1] = corr(msq1(:),dlat2(:),'type',ctype,'rows',crows);
        [r2,p2] = corr(mlat1(:),dlat2(:),'type',ctype,'rows',crows);
        [r3,p3] = corr(mlat2(:),dlat2(:),'type',ctype,'rows',crows);
    
        stem(1:3,[r1 r2 r3],'Color','k'); hold on;

        box off
        ax = gca;
        ax.XTick = 1:3;
        ax.XTickLabel = {};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = y1;
        ylabel(sprintf('Correlation (r)'))
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 
        grid on
        
        % correlations with random maps (completely random vectors)
        shuff = 100;
        np = 10000;
        rvals = NaN(shuff,1);
        for ss = 1:shuff
            % generate random spherical points
            a = 2*pi*rand(np,1);
            e = asin(-1+2*rand(np,1));
            r = ones(np,1);

            % convert to cartesian
            [x,y,z] = sph2cart(a,e,r);
            ts = [x(:) y(:) z(:)];            
            [~,~,~,ms] = projectEIGS(ts);  
            rvals(ss) = corr(ms(:),dlat2(:),'type',ctype,'rows',crows);
        end        
        psR = prctile(rvals,[1 50 99]);
        hold on;
        line(ax.XLim',[psR(3) psR(3)],'Color','r')          
        
            % stats etc
            disp(sprintf('Tilted correlation results:'))
            disp(sprintf('\tcorrelation r (p): %.5f (%.5f), %.5f (%.5f), %.5f (%.5f)',r1,p1,r2,p2,r3,p3))
            disp(sprintf('\tshuffle rand correlation 99th: %.5f',psR(3)))
            
%% diagonal rotated correlations
    ax_m4 = axes('Units','pixels','Position',ax_m3.Position+[0 -155 0 0]);   
        [r1,p1] = corr(msq1(:),dlat2d(:),'type',ctype,'rows',crows);
        [r2,p2] = corr(mlat1(:),dlat2d(:),'type',ctype,'rows',crows);
        [r3,p3] = corr(mlat2(:),dlat2d(:),'type',ctype,'rows',crows);
    
        stem(1:3,[r1 r2 r3],'Color','k'); hold on;

        box off
        ax = gca;
        ax.XTick = 1:3;
        ax.XTickLabel = {'Arena','Aligned','Tilted'};    
        ax.XTickLabelRotation = 45;
        ax.XLim = [0.5 3.5];
        ax.YLim = y1;
        ylabel(sprintf('Correlation (r)'))
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places 
        grid on
        
        % correlations with random maps (completely random vectors)
        shuff = 100;
        np = 10000;
        rvals = NaN(shuff,1);
        for ss = 1:shuff
            % generate random spherical points
            a = 2*pi*rand(np,1);
            e = asin(-1+2*rand(np,1));
            r = ones(np,1);

            % convert to cartesian
            [x,y,z] = sph2cart(a,e,r);
            ts = [x(:) y(:) z(:)];            
            [~,~,~,ms] = projectEIGS(ts);  
            rvals(ss) = corr(ms(:),dlat2d(:),'type',ctype,'rows',crows);
        end        
        psR = prctile(rvals,[1 50 99]);
        hold on;
        line(ax.XLim',[psR(3) psR(3)],'Color','r')        
        
            % stats etc
            disp(sprintf('Tilted (rotated) correlation results:'))
            disp(sprintf('\tcorrelation r (p): %.5f (%.5f), %.5f (%.5f), %.5f (%.5f)',r1,p1,r2,p2,r3,p3))
            disp(sprintf('\tshuffle rand correlation 99th: %.5f',psR(3)))

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    













            
         
