%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Created for
%
%     The place-cell representation of volumetric space in rats
%     Roddy M. Grieves, Selim Jedidi-Ayoub, Karyna Mishchanchuk, Anyi Liu, Sophie Renaudineau and Kate J. Jeffery
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
% FIGS13_spatial_info_field_extents small function to make Fig. S13
% Figure S13 shows the results of an alterbative autocorrelation analysis, spatial information, AUC and field standard deviation
%
% USAGE:
%         Should be run via analysePCELLS
%
% INPUT:
%         No inputs, this is a script that relies on analysePCELLS to load data
%
% OUTPUT:
%    Will save a figure if print_now is set to 1 in analysePCELLS
%
% See also: analysePCELLS

% HISTORY:
% version 1.0.0, Release 30/09/19 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK & FIGURE
    fig2 = figure('visible',fig_vis,'Position',[50,60,651,920.7]);
    set(gcf,'InvertHardCopy','off'); % this stops white lines being plotted black      
    set(gcf,'color','w'); % makes the background colour white
    colormap(jet(256)); % to make sure the colormap is not the horrible default one

    annotation('textbox','Units','pixels','Position',[5, 900, 300, 20],'string','a','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[180, 900, 300, 20],'string','b','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 650, 300, 20],'string','c','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[280, 650, 300, 20],'string','d','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 460, 300, 20],'string','e','FontSize',18,'LineStyle','none','interpreter','none'); 
    annotation('textbox','Units','pixels','Position',[5, 165, 300, 20],'string','f','FontSize',18,'LineStyle','none','interpreter','none'); 

    % main example
    view_plots = [-45,20];
    dirs = {view_plots,[sdir '\850_13032017.mat'],5,4,850,130317};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% Schematic of slices through a ratemap    
%% example ratemap
    ax_A = axes('Units','pixels','Position',[10 690 200 200]);
        cd(sdir);
        load(dirs{2},'-mat','sdata');          
        uci = ['r' sdata.rat_num '_' sdata.date '_t' num2str(dirs{3}) '_c' num2str(dirs{4})]; % the uci
        dat_now = sdata.(uci);
        
        ratemap = dat_now.lattice_3d.ratemap;
        dwellmap = sdata.lattice_3d.dwellmap;
        skaggs = dat_now.lattice_3d.spatial_measures.spatial_information;
        spars = dat_now.lattice_3d.spatial_measures.sparsity;
        MMF = dat_now.lattice_3d.spatial_measures.mean_method_focus;

        lx2 = sdata.lattice_3d.lxrm;
        ly2 = sdata.lattice_3d.lyrm;
        lz2 = sdata.lattice_3d.lzrm;       

        % plot data
        vol3d('cdata',ratemap,'texture','3D');
        alphamap('rampup');
        alphamap([0 0.1 0.1 0.1 0.16 0.25 0.36 0.49 0.64 0.81 1]);
        colormap('jet');
        caxis([0 nanmax(ratemap(:))]);
        hold on
        h = line(lx2,ly2,lz2);
        set(h,'Color',[0.5 0.5 0.5 0.5],'LineWidth',1,'LineStyle','-');
        axis off tight
        view(view_plots)
        daspect([1 1 1])
        xlabel('X');
        ylabel('Y');
        zlabel('Z');
        axis vis3d
        axis([min(lx2)-4,max(lx2)+4,min(ly2)-4,max(ly2)+4,min(lz2)-4,max(lz2)+4]);    
        rotate3d on
        camproj perspective
        cd(sdir);

%% graphic slice Z
    ax_Btop = axes('Units','pixels','Position',[200 685 60 60]);
        % add outlines of a cube
        xpatch = ([0 1 1 0 0 0; 1 1 0 0 1 1; 1 1 0 0 1 1; 0 1 1 0 0 0]);
        ypatch = ([0 0 1 1 0 0; 0 1 1 0 0 0; 0 1 1 0 1 1; 0 0 1 1 1 1]);
        zpatch = ([0 0 0 0 0 1; 0 0 0 0 0 1; 1 1 1 1 0 1; 1 1 1 1 0 1]);

        for vv = 1:6
            h = patch(xpatch(:,vv),ypatch(:,vv),zpatch(:,vv),'w');
            set(h,'edgecolor','k','FaceColor','none')
        end % for vv = 1:6          
        hold on

        % plot the autocorrelation maps onto the sides of the cube
        surf([0 0; 1 1],[0 1; 0 1],[0.5 0.5; 0.5 0.5],'FaceColor',colz);   
        axis off
        view(view_plots)
        daspect([1 1 1])
        axis vis3d
        camproj perspective
        rotate3d on    

%% graphic slice X
    ax_Bmid = axes('Units','pixels','Position',[200 815 60 60]);
        % add outlines of a cube
        for vv = 1:6
            h = patch(xpatch(:,vv),ypatch(:,vv),zpatch(:,vv),'w');
            set(h,'edgecolor','k','FaceColor','none')
        end % for vv = 1:6          
        hold on

        % plot the autocorrelation maps onto the sides of the cube
        surf([0.5 0.5; 0.5 0.5],[0 0; 1 1],[0 1; 0 1],'FaceColor',colx);   
        axis off
        view(view_plots)
        daspect([1 1 1])
        axis vis3d
        camproj perspective
        rotate3d on   

%% graphic slice Y
    ax_Bbot = axes('Units','pixels','Position',[200 750 60 60]);
        % add outlines of a cube
        for vv = 1:6
            h = patch(xpatch(:,vv),ypatch(:,vv),zpatch(:,vv),'w');
            set(h,'edgecolor','k','FaceColor','none')
        end % for vv = 1:6          
        hold on

        % plot the autocorrelation maps onto the sides of the cube
        surf([1 0; 1 0],[0.5 0.5; 0.5 0.5],[0 0; 1 1],'FaceColor',coly);   
        axis off
        view(view_plots)
        daspect([1 1 1])
        axis vis3d
        camproj perspective
        rotate3d on   

%% example 2D slices
        annotation('textbox','Units','pixels','Position',[420, 870, 300, 20],'string','Along X axis','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
        annotation('textbox','Units','pixels','Position',[420, 800, 300, 20],'string','Along Y axis','FontSize',fsiz,'LineStyle','none','interpreter','none'); 
        annotation('textbox','Units','pixels','Position',[420, 728, 300, 20],'string','Along Z axis','FontSize',fsiz,'LineStyle','none','interpreter','none'); 

    % along X
    ax_Bx = axes('Units','pixels','Position',[280 735 350 90]);
        slsnow = dat_now.lattice_3d.slicedata.X.slices;
        longmap = [];
        for i = length(slsnow)-1:-1:2
            longmap = [longmap slsnow{i}];
        end
        im = imagesc(longmap);
        set(im,'alphadata',~isnan(longmap));
        daspect([1 1 1])
        axis off

    % along Y
    ax_By = axes('Units','pixels','Position',[280 805 350 90]);
        slsnow = dat_now.lattice_3d.slicedata.Y.slices;
        longmap = [];
        for i = length(slsnow)-1:-1:2
            longmap = [longmap slsnow{i}];
        end
        im = imagesc(longmap);
        set(im,'alphadata',~isnan(longmap));
        daspect([1 1 1])
        axis off

    % along Z
    ax_Bz = axes('Units','pixels','Position',[280 660 350 90]);
        slsnow = dat_now.lattice_3d.slicedata.Z.slices;
        longmap = [];
        for i = 2:length(slsnow)-1
            longmap = [longmap slsnow{i}];
        end
        im = imagesc(longmap);
        set(im,'alphadata',~isnan(longmap));
        daspect([1 1 1])
        axis off

%% ##################################### %% autocorrelation means/medians boxplot
%% aligned
    ax_D1 = axes('Units','pixels','Position',[50 510 60 110]); 
        sq1X = tdata.med_autocorr_X(pc_idx_sq1,1);
        sq1Y = tdata.med_autocorr_Y(pc_idx_sq1,1);
        la1X = tdata.med_autocorr_X(pc_idx_la1,1);
        la1Y = tdata.med_autocorr_Y(pc_idx_la1,1);
        la1Z = tdata.med_autocorr_Z(pc_idx_la1,1);
        la2A = tdata.med_autocorr_A(pc_idx_la2,1);
        la2B = tdata.med_autocorr_B(pc_idx_la2,1);
        la2C = tdata.med_autocorr_C(pc_idx_la2,1);
        la2X = tdata.med_autocorr_X(pc_idx_la2,1);
        la2Y = tdata.med_autocorr_Y(pc_idx_la2,1);
        la2Z = tdata.med_autocorr_Z(pc_idx_la2,1);

        idx_now = pc_idx_la1;
        rats = unique(tdata.rat(idx_now,1));
        vals = NaN(length(rats),3);
        for rr = 1:length(rats)
            ridx = tdata.rat(:)==rats(rr); % rat index into tdata
            vals(rr,:) = [nanmedian(tdata.med_autocorr_X(ridx,1)) nanmedian(tdata.med_autocorr_Y(ridx,1)) nanmedian(tdata.med_autocorr_Z(ridx,1))];
        end    
        vals = [la1X la1Y la1Z];

        [ds,gs] = vectorDATAGROUP([],vals(:,1),vals(:,2),vals(:,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'X','Y','Z'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        ax.YLim = [-.25 .8];
        y1 = ax.YLim;
        xlabel(m2name)
        ylabel('Median autocorrelation ({\itr})');

        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(gca,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places

        % significance bridges
        [p,a,sts] = friedman(vals,1,'off');
        c = multcompare(sts,'display','off','ctype','bonferroni');
        pindx = c(:,end);
        pvals = c(pindx<=.05,end);
        gvals = c(pindx<=.05,1:2);
        gvals = mat2cell(gvals,ones(size(gvals,1),1),2);
        lh = addSIGBARS(cell2mat(gvals),[max(la1X) max(la1Y) max(la1Z)],pvals,0.1,flnw,fsiz);

            disp('Slice autocoorelations lattice:')    
            disp(sprintf('\tX2(%d) = %.3f, p = %.3f',a{2,3},a{2,5},p))
            disp(sprintf('\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(ds(gs==1)),nanmedian(ds(gs==2)),nanmedian(ds(gs==3))))

%% tilted XYZ        
    ax_D2 = axes('Units','pixels','Position',ax_D1.Position + [70 0 0 0]); 
        idx_now = pc_idx_la2;
        rats = unique(tdata.rat(idx_now,1));
        vals = NaN(length(rats),3);
        for rr = 1:length(rats)
            ridx = tdata.rat(:)==rats(rr); % rat index into tdata
            vals(rr,:) = [nanmedian(tdata.med_autocorr_X(ridx,1)) nanmedian(tdata.med_autocorr_Y(ridx,1)) nanmedian(tdata.med_autocorr_Z(ridx,1))];
        end    
        vals = [la2X la2Y la2Z];

        [ds,gs] = vectorDATAGROUP([],vals(:,1),vals(:,2),vals(:,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'X','Y','Z'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        ax.YLim = y1;
        xlabel(m3name)

        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

        % significance bridges
        [p,a,sts] = friedman(vals,1,'off');
        c = multcompare(sts,'display','off','ctype','bonferroni')
        pindx = c(:,end);
        pvals = c(pindx<=.05,end);
        gvals = c(pindx<=.05,1:2);
        gvals = mat2cell(gvals,ones(size(gvals,1),1),2);
        lh = addSIGBARS(cell2mat(gvals),[max(la2A) max(la2B) max(la2C)],pvals,0.1,flnw,fsiz);

            disp('Slice autocoorelations diagonal:')    
            disp(sprintf('\tX2(%d) = %.3f, p = %.3f',a{2,3},a{2,5},p));
            disp(sprintf('\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(ds(gs==1)),nanmedian(ds(gs==2)),nanmedian(ds(gs==3))))    

%% tilted ABC            
    ax_D3 = axes('Units','pixels','Position',ax_D2.Position + [70 0 0 0]); 
        idx_now = pc_idx_la2;
        rats = unique(tdata.rat(idx_now,1));
        vals = NaN(length(rats),3);
        for rr = 1:length(rats)
            ridx = tdata.rat(:)==rats(rr); % rat index into tdata
            vals(rr,:) = [nanmedian(tdata.med_autocorr_A(ridx,1)) nanmedian(tdata.med_autocorr_B(ridx,1)) nanmedian(tdata.med_autocorr_C(ridx,1))];
        end
        vals = [la2A la2B la2C];

        [ds,gs] = vectorDATAGROUP([],vals(:,1),vals(:,2),vals(:,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'A','B','C'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        ax.YLim = y1;
        xlabel(m3name)

        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

        % significance bridges
        [p,a,sts] = friedman(vals,1,'off');
        c = multcompare(sts,'display','off','ctype','bonferroni');
        pindx = c(:,end);
        pvals = c(pindx<=.05,end);
        gvals = c(pindx<=.05,1:2);
        gvals = mat2cell(gvals,ones(size(gvals,1),1),2);
        lh = addSIGBARS(cell2mat(gvals),[max(la2X) max(la2Y) max(la2Z)],pvals,0.1,flnw,fsiz);

            disp('Slice autocoorelations diagonal:')    
            disp(sprintf('\tX2(%d) = %.3f, p = %.3f',a{2,3},a{2,5},p))
            disp(sprintf('\tMd = %.2f, Md = %.2f, Md = %.2f',nanmedian(ds(gs==1)),nanmedian(ds(gs==2)),nanmedian(ds(gs==3))))  

%% ##################################### %% morphological analysis lattice
%% aligned
    ax_mo1 = axes('Units','pixels','Position',[320 510 140 110]);   
        modata = tdata.morphological_scores(pc_idx_la1,:);
        mx = modata(:,1:3:end);
        my = modata(:,2:3:end);
        mz = modata(:,3:3:end);

        tots = mx+my+mz;
        mx_norm = mx./tots;
        my_norm = my./tots;
        mz_norm = mz./tots;

        x_means = nanmean(mx_norm,1);
        x_sems = nanstd(mx_norm,[],1) ./ sqrt(sum(~isnan(mx_norm),1));
        y_means = nanmean(my_norm,1);
        y_sems = nanstd(my_norm,[],1) ./ sqrt(sum(~isnan(my_norm),1));
        z_means = nanmean(mz_norm,1);
        z_sems = nanstd(mz_norm,[],1) ./ sqrt(sum(~isnan(mz_norm),1));

        hold on
        x_means = x_means(1:19);
        y_means = y_means(1:19);
        z_means = z_means(1:19);
        x_sems = x_sems(1:19);
        y_sems = y_sems(1:19);
        z_sems = z_sems(1:19);
        e1 = errorbar(1:19,x_means,x_sems,'Color',colx,'LineWidth',flnw);
        e2 = errorbar(1:19,y_means,y_sems,'Color',coly,'LineWidth',flnw);
        e3 = errorbar(1:19,z_means,z_sems,'Color',colz,'LineWidth',flnw);    

        ax = gca;
        ylabel('Proportion of voxels')
        xlabel('Element length')
        ax.XLim = [2.5 19.5];
        ax.XTick = 1:2:25;
        ax.YLim = [0 .80];
        y1 = ax.YLim;
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        
       % Observed data
        for i = 1:19
            [dnow,gnow] = vectorDATAGROUP([],mx_norm(:,i),my_norm(:,i),mz_norm(:,i));
            [p,tbl,sts] = kruskalwallis(dnow,gnow,'off');
            if i>6
                if p<=.05/16 && p>.01/16
                    text(i,z_means(i)+z_sems(i)+.05,'*','FontSize',6,'HorizontalAlignment','center')            
                elseif p<.01/16 && p>.001/16
                    text(i,z_means(i)+z_sems(i)+.05,'**','FontSize',6,'HorizontalAlignment','center')
                elseif p<.001/16
                    text(i,z_means(i)+z_sems(i)+.05,'***','FontSize',6,'HorizontalAlignment','center')            
                end
            else
                if p<=.05/16 && p>.01/16
                    text(i,x_means(i)+x_sems(i)+.05,'*','FontSize',6,'HorizontalAlignment','center')            
                elseif p<.01/16 && p>.001/16
                    text(i,x_means(i)+x_sems(i)+.05,'**','FontSize',6,'HorizontalAlignment','center')
                elseif p<.001/16
                    text(i,x_means(i)+x_sems(i)+.05,'***','FontSize',6,'HorizontalAlignment','center')            
                end            
            end
        end

        ll = legend([e1,e2,e3],'X','Y','Z');
        legend boxoff
        pos = get(ll,'Position');
        set(ll,'Position',pos+[-0.11 0.02 0 0]);      

%% tilted
    ax_mo2 = axes('Units','pixels','Position',ax_mo1.Position + [160 0 0 0]);   
        modata = tdata.morphological_scores_diag(pc_idx_la2,:);
        mx = modata(:,1:3:end);
        my = modata(:,2:3:end);
        mz = modata(:,3:3:end);

        tots = mx+my+mz;
        mx_norm = mx./tots;
        my_norm = my./tots;
        mz_norm = mz./tots;

        x_means = nanmean(mx_norm,1);
        x_sems = nanstd(mx_norm,[],1) ./ sqrt(sum(~isnan(mx_norm),1));
        y_means = nanmean(my_norm,1);
        y_sems = nanstd(my_norm,[],1) ./ sqrt(sum(~isnan(my_norm),1));
        z_means = nanmean(mz_norm,1);
        z_sems = nanstd(mz_norm,[],1) ./ sqrt(sum(~isnan(mz_norm),1));

        hold on
        x_means = x_means(1:19);
        y_means = y_means(1:19);
        z_means = z_means(1:19);
        x_sems = x_sems(1:19);
        y_sems = y_sems(1:19);
        z_sems = z_sems(1:19);
        e1 = errorbar(1:19,x_means,x_sems,'Color',cola,'LineWidth',flnw);
        e2 = errorbar(1:19,y_means,y_sems,'Color',colb,'LineWidth',flnw);
        e3 = errorbar(1:19,z_means,z_sems,'Color',colc,'LineWidth',flnw);    

        ax = gca;
        %ylabel('% voxels')
        xlabel('Element length')
        ax.XLim = [2.5 19.5];
        ax.XTick = 1:2:25;
        ax.YLim = y1;
        ax.YTick = [];
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

       % Observed data
        for i = 1:19
            [dnow,gnow] = vectorDATAGROUP([],mx_norm(:,i),my_norm(:,i),mz_norm(:,i));
            [p,tbl,sts] = kruskalwallis(dnow,gnow,'off');
            if i>6
                if p<=.05/16 && p>.01/16
                    text(i,z_means(i)+z_sems(i)+.05,'*','FontSize',6,'HorizontalAlignment','center')            
                elseif p<.01/16 && p>.001/16
                    text(i,z_means(i)+z_sems(i)+.05,'**','FontSize',6,'HorizontalAlignment','center')
                elseif p<.001/16
                    text(i,z_means(i)+z_sems(i)+.05,'***','FontSize',6,'HorizontalAlignment','center')            
                end
            else
                if p<=.05/16 && p>.01/16
                    text(i,x_means(i)+x_sems(i)+.05,'*','FontSize',6,'HorizontalAlignment','center')            
                elseif p<.01/16 && p>.001/16
                    text(i,x_means(i)+x_sems(i)+.05,'**','FontSize',6,'HorizontalAlignment','center')
                elseif p<.001/16
                    text(i,x_means(i)+x_sems(i)+.05,'***','FontSize',6,'HorizontalAlignment','center')            
                end            
            end
        end

        ll = legend([e1,e2,e3],'A','B','C');
        legend boxoff
        pos = get(ll,'Position');
        set(ll,'Position',pos+[-0.12 0.02 0 0]);  

%% ##################################### %% overdispersion (no figure)
        sq1_dat = [];
        la1_dat = [];
        la2_dat = [];
        sq1v_dat = [];
        la1v_dat = [];
        la2v_dat = [];
        for ii = 1:length(sldata.uci)
            dat = sldata.OD_z(ii,:);
            dat = dat{1};
            if isempty(dat) | all(isnan(dat))
                continue
            end
            if sl_idx_sq1(ii)
                sq1_dat = [sq1_dat; dat];
            elseif sl_idx_la1(ii)
                la1_dat = [la1_dat; dat];
            elseif sl_idx_la2(ii)
                la2_dat = [la2_dat; dat];
            end

            dat = sldata.OD_v(ii,:);
            if isempty(dat) | all(isnan(dat))
                continue
            end
            if sl_idx_sq1(ii)
                sq1v_dat = [sq1v_dat; dat];
            elseif sl_idx_la1(ii)
                la1v_dat = [la1v_dat; dat];
            elseif sl_idx_la2(ii)
                la2v_dat = [la2v_dat; dat];
            end    
        end

        [ds,gs] = vectorDATAGROUP([],sq1_dat,la1_dat,la2_dat);
        [p1,stats] = vartestn(ds,gs,'TestType','BrownForsythe','Display','off');
        [~,p2] = vartest2(sq1_dat,la1_dat);
        [~,p3] = vartest2(sq1_dat,la2_dat);
        [~,p4] = vartest2(la1_dat,la2_dat);

        disp(sprintf('Over dispersion'))           
        disp(sprintf('\tF(%d,%d) = %.3f, p = %.3f',stats.df(1),stats.df(1),stats.fstat,p1))
        disp(sprintf('\tSquare vs lattice: p = %.3f',p2))              
        disp(sprintf('\tSquare vs diagonal: p = %.3f',p3))              
        disp(sprintf('\tLattice vs square: p = %.3f',p4))              

%% ##################################### %% field gaussians aligned
        ax_gauss1 = axes('Units','pixels','Position',[50 325 125 110]);   
        ax_gauss2 = axes('Units','pixels','Position',ax_gauss1.Position + [135 0 0 0]);   
        ax_gauss3 = axes('Units','pixels','Position',ax_gauss1.Position + [270 0 0 0]);   

            index_now = pf_idx_la1;
            idx = find(index_now);   
            xsums = NaN(length(idx),1);
            ysums = NaN(length(idx),1);
            zsums = NaN(length(idx),1);
            for ff = 1:length(idx)
                fd_pos = fdata.field_centroid(idx(ff),[1 2 3]);
                fd_frex = fdata.field_valsX(idx(ff),1);  
                fd_frex = fd_frex{1};
                fd_frex = fd_frex./nanmax(fd_frex);
                yd = (((1:length(fd_frex)) - fd_pos(1)) .* 5);
                xsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));
                set(gcf,'CurrentAxes',ax_gauss1)
                patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);

                fd_frex = fdata.field_valsY(idx(ff),1);  
                fd_frex = fd_frex{1};
                fd_frex = fd_frex./nanmax(fd_frex);
                yd = (((1:length(fd_frex)) - fd_pos(2)) .* 5);
                ysums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
                set(gcf,'CurrentAxes',ax_gauss2)
                patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);                

                fd_frex = fdata.field_valsZ(idx(ff),1);  
                fd_frex = fd_frex{1};
                fd_frex = fd_frex./nanmax(fd_frex);
                yd = (((1:length(fd_frex)) - fd_pos(3)) .* 5);
                zsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
                set(gcf,'CurrentAxes',ax_gauss3)
                patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);                 
            end                      

            rcut = .2;
            la1_fvars = [fdata.field_paramsX(pf_idx_la1,3) fdata.field_paramsY(pf_idx_la1,3) fdata.field_paramsZ(pf_idx_la1,3)];
            la1_gvars = [fdata.field_paramsX(pf_idx_la1,4) fdata.field_paramsY(pf_idx_la1,4) fdata.field_paramsZ(pf_idx_la1,4)];
            la1_fvars(la1_gvars<=rcut) = NaN; % remove badly fitted values
            la1_mval = nanmean(la1_fvars,1);

            set(gcf,'CurrentAxes',ax_gauss1)
            x = -100:1:100;
            sds = 3;
            norm = normpdf(x,0,la1_mval(1).*sds);
            norm = norm./nanmax(norm);
            hold on;
            plot(x,norm,'r')

            set(gcf,'CurrentAxes',ax_gauss2)
            x = -100:1:100;
            norm = normpdf(x,0,la1_mval(2).*sds);
            norm = norm./nanmax(norm);
            hold on;
            plot(x,norm,'r')   

            set(gcf,'CurrentAxes',ax_gauss3)
            x = -100:1:100;
            norm = normpdf(x,0,la1_mval(3).*sds);
            norm = norm./nanmax(norm);
            hold on;
            plot(x,norm,'r')               

            ax_gauss1.XLim = [-75 75];
            ax_gauss2.XLim = ax_gauss1.XLim;
            ax_gauss3.XLim = ax_gauss1.XLim;
            ax_gauss1.YLim = [0 1];
            ax_gauss2.YLim = ax_gauss1.YLim;
            ax_gauss3.YLim = ax_gauss1.YLim;            
            ax_gauss1.XTick = [];
            ax_gauss2.XTick = [];
            ax_gauss3.XTick = [];

            set(ax_gauss1,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
            set(ax_gauss1,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places
            ylabel(ax_gauss1,'Normalised firing rate');
            set(ax_gauss2,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
            set(ax_gauss3,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

%% field AUCs aligned
    ax_sd1 = axes('Units','pixels','Position',ax_gauss1.Position + [450 0 0 0]);               
        [ds,gs] = vectorDATAGROUP([],xsums,ysums,zsums);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'X','Y','Z'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        xlabel(m3name)
        ylabel('AUC (rate x distance)')        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % significance bridges
            disp('Lattice AUCs:')
            stats_and_bars(ds,gs,[],flnw,fsiz);  
            
%% ##################################### %% field gaussians tilted
    ax_gauss1 = axes('Units','pixels','Position',[50 200 125 110]);   
    ax_gauss2 = axes('Units','pixels','Position',ax_gauss1.Position + [135 0 0 0]);   
    ax_gauss3 = axes('Units','pixels','Position',ax_gauss1.Position + [270 0 0 0]);   

        index_now = pf_idx_la2;
        idx = find(index_now); 
        asums = NaN(length(idx),1);
        bsums = NaN(length(idx),1);
        csums = NaN(length(idx),1);   

        xsums = NaN(length(idx),1);
        ysums = NaN(length(idx),1);
        zsums = NaN(length(idx),1);            
        for ff = 1:length(idx)
            fd_pos = fdata.field_diagonal_centroid(idx(ff),[1 2 3]);
            fd_frex = fdata.field_diagonal_valsA(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - fd_pos(1)) .* 5);
            asums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
            set(gcf,'CurrentAxes',ax_gauss1)
            patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);

            fd_frex = fdata.field_diagonal_valsB(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - fd_pos(2)) .* 5);
            bsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
            set(gcf,'CurrentAxes',ax_gauss2)
            patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);                

            fd_frex = fdata.field_diagonal_valsC(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            yd = (((1:length(fd_frex)) - fd_pos(3)) .* 5);
            csums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
            set(gcf,'CurrentAxes',ax_gauss3)
            patchline(yd,fd_frex,'edgecolor','k','linewidth',flnw,'edgealpha',0.1);    


            fd_frex = fdata.field_valsX(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            xsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                
            fd_frex = fdata.field_valsY(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            ysums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                               
            fd_frex = fdata.field_valsZ(idx(ff),1);  
            fd_frex = fd_frex{1};
            fd_frex = fd_frex./nanmax(fd_frex);
            zsums(ff,1) = trapz(fd_frex(~isnan(fd_frex)));                                
        end                      

        rcut = .2;
        la2_fvars = [fdata.field_paramsX(pf_idx_la2,3) fdata.field_paramsY(pf_idx_la2,3) fdata.field_paramsZ(pf_idx_la2,3)];
        la2_gvars = [fdata.field_paramsX(pf_idx_la2,4) fdata.field_paramsY(pf_idx_la2,4) fdata.field_paramsZ(pf_idx_la2,4)];
        la2b_fvars = [fdata.field_diagonal_paramsA(pf_idx_la2,3) fdata.field_diagonal_paramsB(pf_idx_la2,3) fdata.field_diagonal_paramsC(pf_idx_la2,3)];
        la2b_gvars = [fdata.field_diagonal_paramsA(pf_idx_la2,4) fdata.field_diagonal_paramsB(pf_idx_la2,4) fdata.field_diagonal_paramsC(pf_idx_la2,4)];
        la2_fvars(la2_gvars<=rcut) = NaN; % remove badly fitted values
        la2b_fvars(la2b_gvars<=rcut) = NaN; % remove badly fitted values            
        la2b_mval = nanmean(la2b_fvars,1);

        set(gcf,'CurrentAxes',ax_gauss1)
        x = -100:1:100;
        norm = normpdf(x,0,la2b_mval(1).*sds);
        norm = norm./nanmax(norm);
        hold on;
        plot(x,norm,'r')

        set(gcf,'CurrentAxes',ax_gauss2)
        x = -100:1:100;
        norm = normpdf(x,0,la2b_mval(2).*sds);
        norm = norm./nanmax(norm);
        hold on;
        plot(x,norm,'r')   

        set(gcf,'CurrentAxes',ax_gauss3)
        x = -100:1:100;
        norm = normpdf(x,0,la2b_mval(3).*sds);
        norm = norm./nanmax(norm);
        hold on;
        plot(x,norm,'r')               

        ax_gauss1.XLim = [-75 75];
        ax_gauss2.XLim = ax_gauss1.XLim;
        ax_gauss3.XLim = ax_gauss1.XLim;
        ax_gauss1.YLim = [0 1];
        ax_gauss2.YLim = ax_gauss1.YLim;
        ax_gauss3.YLim = ax_gauss1.YLim;             

        set(ax_gauss1,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax_gauss1,'yticklabel',num2str(get(gca,'ytick')','%.1f')) % change Ytick labels to have the same number of decimal places
        ylabel(ax_gauss1,'Normalised firing rate');
        set(ax_gauss2,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        set(ax_gauss3,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black
        xlabel(ax_gauss2,'Distance from peak (cm)')
            
%% field AUCs aligned
    ax_sd2 = axes('Units','pixels','Position',ax_gauss1.Position + [450 0 0 0]);               
        [ds,gs] = vectorDATAGROUP([],asums,bsums,csums);
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:6;
        ax.XTickLabel = {'A','B','C'};
        ax.XTickLabelRotation = 0;    
        ax.XLim = [0.5 3.5];
        xlabel('Axis')
        ylabel('AUC (rate x distance)')        
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black

            % significance bridges
            disp('Diagonal AUCs:')
            stats_and_bars(ds,gs,[],flnw,fsiz);                         

%% ##################################### %% place field standard deviation
        sq1_fvars = [fdata.field_paramsX(pf_idx_sq1,3) fdata.field_paramsY(pf_idx_sq1,3) fdata.field_paramsZ(pf_idx_sq1,3)];
        sq1_gvars = [fdata.field_paramsX(pf_idx_sq1,4) fdata.field_paramsY(pf_idx_sq1,4) fdata.field_paramsZ(pf_idx_sq1,4)];
        la1_fvars = [fdata.field_paramsX(pf_idx_la1,3) fdata.field_paramsY(pf_idx_la1,3) fdata.field_paramsZ(pf_idx_la1,3)];
        la1_gvars = [fdata.field_paramsX(pf_idx_la1,4) fdata.field_paramsY(pf_idx_la1,4) fdata.field_paramsZ(pf_idx_la1,4)];
        la2_fvars = [fdata.field_paramsX(pf_idx_la2,3) fdata.field_paramsY(pf_idx_la2,3) fdata.field_paramsZ(pf_idx_la2,3)];
        la2_gvars = [fdata.field_paramsX(pf_idx_la2,4) fdata.field_paramsY(pf_idx_la2,4) fdata.field_paramsZ(pf_idx_la2,4)];
        la2b_fvars = [fdata.field_diagonal_paramsA(pf_idx_la2,3) fdata.field_diagonal_paramsB(pf_idx_la2,3) fdata.field_diagonal_paramsC(pf_idx_la2,3)];
        la2b_gvars = [fdata.field_diagonal_paramsA(pf_idx_la2,4) fdata.field_diagonal_paramsB(pf_idx_la2,4) fdata.field_diagonal_paramsC(pf_idx_la2,4)];

        nsumsXYZ = NaN(length(fdata.field_valsX),3);
        nsumsABC = NaN(length(fdata.field_valsX),3);
        for ff = 1:length(fdata.field_valsX)    
            nsumsXYZ(ff,1) = nansum(fdata.field_valsX{ff} ./ nanmax(fdata.field_valsX{ff}));
            nsumsXYZ(ff,2) = nansum(fdata.field_valsY{ff} ./ nanmax(fdata.field_valsY{ff}));
            nsumsXYZ(ff,3) = nansum(fdata.field_valsZ{ff} ./ nanmax(fdata.field_valsZ{ff}));

            nsumsABC(ff,1) = nansum(fdata.field_diagonal_valsA{ff} ./ nanmax(fdata.field_diagonal_valsA{ff}));
            nsumsABC(ff,2) = nansum(fdata.field_diagonal_valsB{ff} ./ nanmax(fdata.field_diagonal_valsB{ff}));
            nsumsABC(ff,3) = nansum(fdata.field_diagonal_valsC{ff} ./ nanmax(fdata.field_diagonal_valsC{ff}));
        end

        ynow = 40;
%% aligned        
    ax_SD1 = axes('Units','pixels','Position',[50 ynow 80 110]); 
        rcut = 0.2;
        [ds,gs] = vectorDATAGROUP([],la1_fvars(la1_gvars(:,1)>rcut,1),la1_fvars(la1_gvars(:,2)>rcut,2),la1_fvars(la1_gvars(:,3)>rcut,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'X' 'Y' 'Z'};    
        ax.XLim = [0.5 3.5];
        ax.YLim = [0 20];   
        y1 = ax.YLim;
        ylabel(sprintf('Standard deviation (%c)',char(963)))
        xlabel(m2name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','k'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            % significance bridges
            disp('Lattice stdev:')                
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;     

%% tilted XYZ            
    ax_SD2 = axes('Units','pixels','Position',ax_SD1.Position + [90 0 0 0]); 
        [ds,gs] = vectorDATAGROUP([],la2_fvars(la2_gvars(:,1)>rcut,1),la2_fvars(la2_gvars(:,2)>rcut,2),la2_fvars(la2_gvars(:,3)>rcut,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{colx,coly,colz},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{colx,coly,colz},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'X' 'Y' 'Z'};    
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        ax.YLim = y1;
        xlabel(m3name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            % significance bridges
            disp('Diagonal stdev XYZ:')                
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;          

%% tilted ABC            
    ax_SD3 = axes('Units','pixels','Position',ax_SD2.Position + [90 0 0 0]); 
        [ds,gs] = vectorDATAGROUP([],la2b_fvars(la2b_gvars(:,1)>rcut,1),la2b_fvars(la2b_gvars(:,2)>rcut,2),la2b_fvars(la2b_gvars(:,3)>rcut,3));
        boxplot2(ds,gs,'linewidth',flnw,'boxcolor',{cola,colb,colc},'boxalpha',0,'dots',1,'dotsize',10,'dotcolor',{cola,colb,colc},'dotalpha',0.8);

        box off
        ax = gca;
        ax.XTick = 1:8;
        ax.XTickLabel = {'A' 'B' 'C'};    
        ax.XLim = [0.5 3.5];
        ax.YTick = [];
        ax.YLim = y1;
        xlabel(m3name)
        set(gca,'LineWidth',flnw,'layer','top','FontSize',fsiz,'XColor','k','YColor','none'); % set the axes to be on top, set their thickness to flnw, set all fonts to size fsiz and make sure the axis and text are black        

            % significance bridges
            disp('Diagonal stdev ABC:')                
            stats_and_bars(ds,gs,[],flnw,fsiz);
            ax.YLim = y1;   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
%% ################################################################# %% Finish up and save
    paper_FIG_savefig(print_now,print_qual,gcf,sdir,dbstack);
    
















