function boxplot2(ds,gs,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FUNCTION  short descr.
% long descr.
%
% USAGE:
%         [out] = template(in,in2)
%
% INPUT:
%         in - input 1
%         in2 - input 2
%
% OUTPUT:
%    p - output
%
% EXAMPLES:
%
% See also: FUNCTION2 FUNCTION3

% HISTORY:
% version 1.0.0, Release 00/00/00 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2018 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUT ARGUMENTS CHECK
% % if ~exist('in','var') || isempty(in)
% %     in = 
% % end
stk = dbstack;
function_name = stk.name;

validData = @(x) isvector(x) && ~all(isnan(x)) && ~isempty(x);
validScalarPosNum = @(x) isnumeric(x) && isscalar(x) && (x > 0);
validScalarPosNum2 = @(x) isnumeric(x) && isscalar(x);
validLogic = @(x) islogical(x) || x==1 || x==0;

p = inputParser;
addRequired(p,'ds',validData);
addRequired(p,'gs',validData);

addOptional(p,'linecolor',{'k'},@iscell);   
addOptional(p,'linewidth',0.5,validScalarPosNum2);   
addOptional(p,'boxwidth',0.75,validScalarPosNum);
addOptional(p,'boxcolor',{'w'},@iscell);
addOptional(p,'boxalpha',0,validScalarPosNum2);

addOptional(p,'mediancolor','r',@isstring);
addOptional(p,'medianlinewidth',1,validScalarPosNum);
addOptional(p,'whiskercolor',{'k'},@iscell);
addOptional(p,'whiskerlinewidth',0.5,validScalarPosNum);

addOptional(p,'dots',0,validLogic);   
addOptional(p,'dotsize',50,validScalarPosNum);
addOptional(p,'dotcolor',{'k'},@iscell);
addOptional(p,'dotalpha',0.4,validScalarPosNum2);
addOptional(p,'dotsigma',0.12,validScalarPosNum);

parse(p,ds,gs,varargin{:});
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FUNCTION BODY
group_nums = unique(gs);
gnum = numel(group_nums);
gdata = NaN(gnum,5);

for gg = 1:gnum % for every data group
    gdata(gg,1:3) = quantile(ds(gs==group_nums(gg)),[.25 .50 .75]); 
    gdata(gg,4) = nanmin(ds(gs==group_nums(gg)));
    gdata(gg,5) = nanmax(ds(gs==group_nums(gg)));
    
    gnow = group_nums(gg);
    x = [gnow-p.Results.boxwidth/2 gnow-p.Results.boxwidth/2 gnow+p.Results.boxwidth/2 gnow+p.Results.boxwidth/2];
    y = [gdata(gg,1) gdata(gg,3) gdata(gg,3) gdata(gg,1)];
    
    if length(p.Results.boxcolor)==1 || length(p.Results.boxcolor)<gnum
        c = p.Results.boxcolor{1};
    else
        c = p.Results.boxcolor{gg};        
    end
    if ~strcmp(c,'none')
        if length(p.Results.linecolor)==1 || length(p.Results.linecolor)<gnum
            lc = p.Results.linecolor{1};
        else
            lc = p.Results.linecolor{gg};        
        end    
        if length(p.Results.whiskercolor)==1 || length(p.Results.whiskercolor)<gnum
            wc = p.Results.whiskercolor{1};
        else
            wc = p.Results.whiskercolor{gg};        
        end  
        
        % actual IQR boxes
        pp = patch(x,y,c,'LineWidth',p.Results.linewidth,'EdgeColor',lc,'FaceColor',c,'FaceAlpha',p.Results.boxalpha);
        hold on

        % median line
        ll = line([min(x) max(x)],[gdata(gg,2) gdata(gg,2)],'Color',p.Results.mediancolor,'LineWidth',p.Results.medianlinewidth); 

        % whiskers
        ll = line([gnow gnow],[gdata(gg,1) gdata(gg,4)],'Color',wc,'LineWidth',p.Results.whiskerlinewidth);
        ll = line([gnow-p.Results.boxwidth/4 gnow+p.Results.boxwidth/4],[gdata(gg,4) gdata(gg,4)],'Color',wc,'LineWidth',p.Results.whiskerlinewidth);

        ll = line([gnow gnow],[gdata(gg,3) gdata(gg,5)],'Color',wc,'LineWidth',p.Results.whiskerlinewidth);
        ll = line([gnow-p.Results.boxwidth/4 gnow+p.Results.boxwidth/4],[gdata(gg,5) gdata(gg,5)],'Color',wc,'LineWidth',p.Results.whiskerlinewidth);
    end
    hold on;
    
    % data points
    if p.Results.dots
        if length(p.Results.dotcolor)==1 || length(p.Results.dotcolor)<gnum
            dc = p.Results.dotcolor{1};
        else
            dc = p.Results.dotcolor{gg};        
        end          
        
        % jitter the x position of the dots
        nsamp = sum(gs==group_nums(gg));
        gs2 = ones(nsamp,1)*gnow + normrnd(0,p.Results.dotsigma,nsamp,1);
        ds2 = ds(gs==group_nums(gg));
        
        % make sure top and bottom marker are on the xtick
        mandx = find(ds2==nanmax(ds2),1);
        mindx = find(ds2==nanmin(ds2),1);
        gs2(mandx) = gnow;
        gs2(mindx) = gnow;

        ss = scatter(gs2,ds2,p.Results.dotsize,dc,'filled','MarkerFaceColor',dc,'MarkerEdgeColor','none','MarkerFaceAlpha',p.Results.dotalpha);
        uistack(ss,'bottom');
    end    
end



























































