function [phands,shands] = boxplot3(ydata,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
%FUNCTION  short descr.
% long descr.
%
% USAGE:
%         [out] = template(in,in2)
%
% INPUT:
%         in - input 1
%         in2 - input 2
%
% OUTPUT:
%    p - output
%
% EXAMPLES:
%
% See also: FUNCTION2 FUNCTION3

% HISTORY:
% version 1.0.0, Release 00/00/00 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK
%% Prepare default settings
    def_xdata           = repmat(1:size(ydata,2),size(ydata,1),1);
    def_method          = 3;  
    exp_methods         = 1:3;
    def_overlap         = 1; % group overlap, 1 = no overlap, >1 = more overlap             
    def_spacing         = 1;      
    def_gap             = 0.04; % space between dots and density etc    
    def_buffer          = 0.04; % space between groups 
    
    def_dotsize         = 20;  
    def_dotalpha        = 0.5;   
    def_dotcols         = {'k'};
        
    def_kernbw          = 0.03;
    def_kerncols        = {'k'};
    def_showmed         = 1;
    def_medcols         = {'k','r','k'};    
    def_kernalpha       = 0.5;   
    def_kernpoints      = 1000;
    def_kernsupport     = [-inf inf];
    

%% Parse inputs
    p = inputParser;
    addRequired(p,'ydata',@(x) ~isempty(x) && isnumeric(x));  
    addOptional(p,'xdata',def_xdata,@(x) ~isempty(x) && isnumeric(x));     
    addParameter(p,'method',def_method,@(x) ismember(x,exp_methods));  
    
    % general parameters
    addParameter(p,'overlap',def_overlap,@(x) isnumeric(x) && isscalar(x));     
    addParameter(p,'spacing',def_spacing,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'gap',def_gap,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'buffer',def_buffer,@(x) isnumeric(x) && isscalar(x));  
    
    % dot parameters
    addParameter(p,'dotsize',def_dotsize,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'dotalpha',def_dotalpha,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'dotcols',def_dotcols,@(x) iscell(x)); 
    
    % kernel parameters
    addParameter(p,'kernbw',def_kernbw,@(x) isnumeric(x) && isscalar(x));  
    addParameter(p,'kerncols',def_dotcols,@(x) iscell(x)); 
    addParameter(p,'kernalpha',def_kernalpha,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'showmed',def_showmed,@(x) islogical(x)); 
    addParameter(p,'medcols',def_medcols,@(x) iscell(x)); 
    addParameter(p,'kernpoints',def_kernpoints,@(x) isnumeric(x) && isscalar(x)); 
    addParameter(p,'kernsupport',def_kernsupport,@(x) isnumeric(x)); 
    
    % parse
    parse(p,ydata,varargin{:});

%% Retrieve parameters 
    config = p.Results;

%% ##################################### Heading 2
%% #################### Heading 3
%% Heading 4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% FUNCTION BODY
    xpositions = unique(config.xdata);
    if length(config.dotcols) ~= numel(xpositions)
        config.dotcols = repmat(config.dotcols(1),1,numel(xpositions));
    end
    if length(config.kerncols) ~= numel(xpositions)
        config.kerncols = repmat(config.kerncols(1),1,numel(xpositions));
    end    
    if length(config.medcols) ~= 3
        config.medcols = repmat(config.medcols(1),1,3);
    end      
    
    shands = cell(1,length(xpositions));
    phands = cell(1,length(xpositions));
    for gg = 1:length(xpositions) % for every group/xposition
        lx = xpositions(gg)-config.overlap/2+config.buffer;
        ux = xpositions(gg)+config.overlap/2-config.buffer; 

        pindx = linspace(lx,ux,10);
        if config.method==1
            edg_points = [pindx(1)+config.gap pindx(10)-config.gap];
        elseif config.method==2
            edg_points = [pindx(1)+config.gap pindx(5)-config.gap/2 pindx(5)+config.gap/2 pindx(10)-config.gap];
        elseif config.method==3
            edg_points = [pindx(1)+config.gap pindx(5)-config.gap/2 pindx(5)+config.gap/2 pindx(10)-config.gap];
            
%% plot the dots
            npoints = sum(config.xdata(:)==xpositions(gg));
            xnow = edg_points(1) + (edg_points(2)-edg_points(1)).*rand(npoints,1);
            ynow = reshape(config.ydata(config.xdata==xpositions(gg)),[],1);
            shands{gg} = scatter(xnow,ynow,config.dotsize,config.dotcols{gg},'filled','MarkerFaceAlpha',config.dotalpha,'MarkerEdgeColor','none'); hold on;

%% plot the distribution
            rnnge = (max(config.ydata(:))-min(config.ydata(:)))/20;
            xi = linspace(max([min(config.ydata(:))-rnnge config.kernsupport(1)]),min([max(config.ydata(:))+rnnge config.kernsupport(2)]),config.kernpoints);                

            f = ksdensity(ynow,xi,'kernel','normal','bandwidth',config.kernbw);
            xkern = [f zeros(size(f))];
            xkern = (xkern./nanmax(xkern(:))).*(edg_points(4)-edg_points(3));
            xkern = xkern + edg_points(3);
            
            ykern = [xi fliplr(xi)];
            phands{gg} = patch(xkern,ykern,config.kerncols{gg},'EdgeColor','k','FaceAlpha',config.kernalpha); hold on;
            quants = quantile(reshape(config.ydata(config.xdata==xpositions(gg)),[],1),[.25 .5 .75]);
            
            xlin = xkern(xkern~=edg_points(3));
            ylin = ykern(xkern~=edg_points(3));
            v1 = interp1(ylin,xlin,quants(1));
            v2 = interp1(ylin,xlin,quants(2));
            v3 = interp1(ylin,xlin,quants(3));

            if config.showmed
                line([edg_points(3) v1],[quants(1) quants(1)],'Color',config.medcols{1},'LineStyle','-','LineWidth',1.5);
                line([edg_points(3) v2],[quants(2) quants(2)],'Color',config.medcols{2},'LineStyle','-','LineWidth',1.5);
                line([edg_points(3) v3],[quants(3) quants(3)],'Color',config.medcols{3},'LineStyle','-','LineWidth',1.5);                
            end 
        end
    end












