% function paper_3_ANA_fdist
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% DESCRIPTION
%FUNCTION  Test if fields are distributed around zero in 3D mazes
% long descr.
%
% USAGE:
%         [out] = template(in,in2)
%
% INPUT:
%         in - input 1
%         in2 - input 2
%
% OUTPUT:
%    p - output
%
% EXAMPLES:
%
% See also: FUNCTION2 FUNCTION3

% HISTORY:
% version 1.0.0, Release 00/00/00 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2019 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% INPUT ARGUMENTS CHECK
% deal with input variables
% if ~exist('var0','var') || isempty(var0);         error('%s needs input var0... exiting',mfilename);        end
% if ~exist('var1','var') || isempty(var1);         var1 = 10;                                                end
% if ~exist('var2','var') || isempty(var2);         var2 = 10;                                                end
% if ~exist('var3','var') || isempty(var3);         var3 = 10;                                                end

%% ##################################### Heading 2
%% #################### Heading 3
%% Heading 4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ################################################################# %% FUNCTION BODY
    shuff = 1000;
    if maz==1
        index_now = pf_idx_sq1;
        load('square1_frame.mat');  
    elseif maz==2
        index_now = pf_idx_la1;
        load('lattice_frame.mat');    
    elseif maz==3
        index_now = pf_idx_la2;
        load('diag_frame.mat');
    end

    fx1 = fdata.field_lattice_centroid(index_now,1);
    fy1 = fdata.field_lattice_centroid(index_now,2);
    fz1 = fdata.field_lattice_centroid(index_now,3);
 
    lx1 = (lx - nanmean(lx)) ./ 10 + 5;
    ly1 = (ly - nanmean(ly)) ./ 10 + 5;
    lz1 = (lz - nanmean(lz)) ./ 10 -10;      
    cdat = [lx1 ly1 lz1];
    cdat(any(isnan(cdat),2),:) = [];
    k = convhulln(cdat);
    idx = inhull([fx1 fy1 fz1],cdat,k); 
    fx1 = fx1(idx);
    fy1 = fy1(idx);
    fz1 = fz1(idx);
    
    cent = [nanmean([min(lx1(:)) max(lx1)]) nanmean([min(ly1(:)) max(ly1)]) nanmean([min(lz1(:)) max(lz1)])];
    ds = pdist2(cent,[fx1 fy1 fz1]);
    obs_med_dist = median(ds(:));
    obs_pos = median([fx1 fy1 fz1],1) - cent;
    
    nf = sum(idx); % number of fields
    shuff_dists = NaN(shuff,1);
    shuff_pos = NaN(shuff,3);
    loopout = looper(shuff);
    for ss = 1:shuff
        xr = min(lx1) + (max(lx1)-min(lx1)).*rand(nf,1);
        yr = min(ly1) + (max(ly1)-min(ly1)).*rand(nf,1);
        zr = min(lz1) + (max(lz1)-min(lz1)).*rand(nf,1);

        ds = pdist2(cent(1:2),[xr yr]);
        shuff_dists(ss,1) = median(ds(:));
        shuff_pos(ss,:) = median([xr yr zr],1) - cent;         
    end            














