function [prc,arc,pr,ar,cr,idcs] = sphereCHANCE(np,ns,vd)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SPHERECHANCE  calculate chance of observing points aligned with each axis in a sphere
% For the lattice maze data. Generate random points across the surface of a sphere
%
% USAGE:
%         [out] = template(in,in2)
%
% INPUT:
%         in - input 1
%         in2 - input 2
%
% OUTPUT:
%    p - output
%
% EXAMPLES:
%
% See also: FUNCTION2 FUNCTION3

% HISTORY:
% version 1.0.0, Release 00/00/00 Initial release
%
% Author: Roddy Grieves
% UCL, 26 Bedford Way
% eMail: r.grieves@ucl.ac.uk
% Copyright 2018 Roddy Grieves

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUT ARGUMENTS CHECK
% deal with input variables
inps = {'np','ns','vd'};
vals = {'1000','1000','0'};
reqd = [0 0 0];
for ff = 1:length(inps)
    if ~exist(inps{ff},'var')
        if reqd(ff)
            error('ERROR: vargin %s missing... exiting',inps{ff});            
        end        
        eval([inps{ff} '=' vals{ff} ';']);
    end
end
idcs = {};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FUNCTION BODY
if nargin<3 % if function was not given coordinates to test, do a shuffle instead
    % coordinates of sphere axes
    test_coords = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0]); normr([0 0 970]); normr([0 0 -970]); normr([0 660 466.69]); normr([0 -660 -466.69]); normr([571.6 -330 466.69]); normr([-571.6 330 -466.69]); normr([-571.55 -330 466.69]); normr([571.55 330 -466.69])];            
    
    % run shuffle
    cnts = NaN(ns,length(test_coords)); % will contain observed counts for each axis
    for ss = 1:ns
        % generate random spherical points
        a = 2*pi*rand(np,1);
        e = asin(-1+2*rand(np,1));
        r = ones(np,1);

        % convert to cartesian
        [x,y,z] = sph2cart(a,e,r);
        shuff_coords = [x(:) y(:) z(:)];

        % find how many points fall within a set distance of each axis
        for tt = 1:length(test_coords(:,1))
            ds = sqrt(sum((shuff_coords-test_coords(tt,:)).^2,2));
            pindx = ds<0.5;            
            cnts(ss,tt) = sum(pindx); % accumulate data
        end           
    end 

    % sum across antipodes to get one value per axis (in both directions)
    cr = [sum([cnts(:,1) cnts(:,2)],2) sum([cnts(:,3) cnts(:,4)],2) sum([cnts(:,5) cnts(:,6)],2) sum([cnts(:,7) cnts(:,8)],2) sum([cnts(:,9) cnts(:,10)],2) sum([cnts(:,11) cnts(:,12)],2)];
    pr = cr ./ np;
    
    % shuffled axis ratios
%     ar = (sum(pr(:,1:3),2) - sum(pr(:,4:6),2)) ./ (sum(pr(:,1:3),2) + sum(pr(:,4:6),2));   
    ar = sum(cr(:,1:3),2)./sum(cr(:,4:6),2);    
    arc = prctile(ar(:),[0.1 1 2.5 50 97.5 99 99.9]);

    % shuffled axis probabilities
    prc = prctile(pr(:),[0.1 1 5 50 95 99 99.9]);

else % if function was given real points to test
    % coordinates of sphere axes
    test_coords = [normr([-970 0 0]); normr([970 0 0]); normr([0 970 0]); normr([0 -970 0]); normr([0 0 970]); normr([0 0 -970]); normr([0 660 466.69]); normr([0 -660 -466.69]); normr([571.6 -330 466.69]); normr([-571.6 330 -466.69]); normr([-571.55 -330 466.69]); normr([571.55 330 -466.69])];            

    % find how many points fall within a set distance of each axis
    np = length(vd(:,1));
    cnts = NaN(1,length(test_coords)); % will contain observed counts for each axis
    for tt = 1:length(test_coords(:,1))
        ds = sqrt(sum((vd-test_coords(tt,:)).^2,2));
        pindx = ds<0.5;            
        cnts(1,tt) = sum(pindx); % accumulate data
        idcs{tt} = pindx;
    end           

    % sum across antipodes to get one value per axis (in both directions)
    cr = [sum([cnts(:,1) cnts(:,2)],2) sum([cnts(:,3) cnts(:,4)],2) sum([cnts(:,5) cnts(:,6)],2) sum([cnts(:,7) cnts(:,8)],2) sum([cnts(:,9) cnts(:,10)],2) sum([cnts(:,11) cnts(:,12)],2)];
    pr = cr ./ np;

    % axis ratio
%     ar = (sum(pr(:,1:3),2) - sum(pr(:,4:6),2)) ./ (sum(pr(:,1:3),2) + sum(pr(:,4:6),2));    
    ar = sum(cr(:,1:3))./sum(cr(:,4:6));    
    arc = NaN(1,6);

    % axis probabilities
    prc = NaN(1,6);   
end
    
    
    
    
    
    
    
    






