function [dvec,gvec] = vectorDATAGROUP(cgroup,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This function takes a list of data vectors/matrices, concatenates them into one long vector and returns a grouping vector
%   that increments for each one
%   This is primarily useful for preparing unequally sized vectors for boxplot or kruskalwallis functions
%   [dvec,gvec] = vectorDATAGROUP(cgroup,varargin)
%
%%%%%%%% Inputs
%   cgroup = custom group specification, in case you want to group vectors with specific numbers, otherwise leave empty
%   inputs should be vectors, one after the other
%
%%%%%%%% Outputs
%   dvec = all data placed in a single vector in the order it is given
%   gvec = a grouping vector which corresponds to dvec
%
%%%%%%%% Comments
%   18/02/18 created 
%    Roddy Grieves: rmgrieves@gmail.com
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initial variables
if ~exist('cgroup','var') || isempty(cgroup) || all(isnan(cgroup(:)))
    cgroup = 1:length(varargin);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Create vectors
nelements =  cellfun(@(x) numel(x),varargin);
dvec = NaN(sum(nelements),1);
gvec = zeros(sum(nelements),1);
nvec = cumsum([0 nelements]);
for nn = 1:length(varargin)
    dnow = varargin{nn};
    dvec(nvec(nn)+1:nvec(nn+1)) = dnow(:);
    gvec(nvec(nn)+1:nvec(nn+1)) = cgroup(nn);
end































